// {{MadCap}} //////////////////////////////////////////////////////////////////
// Copyright: MadCap Software, Inc - www.madcapsoftware.com ////////////////////
////////////////////////////////////////////////////////////////////////////////
// <version>16.0.7426.25547</version>
////////////////////////////////////////////////////////////////////////////////

//    Syntax:
//    function FMCOpenHelp( id, skinName, searchQuery, firstPick )
//
//    id          - Identifier that was created in Flare. This can be either the identifier name or value. The topic and skin
//                  that is associated with the id will be used. If no skin is associated with the id, skinName will be used.
//                  Alternatively, id may contain a topic path. In this case, the specified topic will be loaded with the skin
//                  that is specified in skinName. Specify null to use the help system's default starting topic.
//    skinName    - This is a string indicating the name of the skin to use when opening the help system. Specify null to use
//                  the default skin or to use the skin that is associated with id. If a skin is associated with id AND a skin
//                  is specified in skinName, skinName will take precedence.
//    searchQuery - This is a string indicating the search query used when opening the help system. If a search query is specified,
//                  the help system will start with the search pane open and the search query executed. Specify null to open
//                  the help system without a search query.
//    firstPick   - This is a boolean indicating whether to automatically open the topic from the first search result that is
//                  returned by the search query (see searchQuery parameter). Use null if no search query was specified.
//
//    Examples:
//
//    In the following example, topic and skin associated with "FILE_NEW" will be used:
//    FMCOpenHelp( 'FILE_NEW', null, null, null );
//
//    In the following example, topic associated with "FILE_NEW" will be used. "BlueSkin" will override the skin associated with "FILE_NEW":
//    FMCOpenHelp( 'FILE_NEW', 'BlueSkin', null, null );
//
//    In the following example, topic and skin associated with identifier value 1 will be used:
//    FMCOpenHelp( 1, null, null, null );
//
//    In the following example, topic associated with identifier value 1 will be used. "BlueSkin" will override the skin associated with identifier value 1:
//    FMCOpenHelp( 1, 'BlueSkin', null, null );
//
//    In the following example, "Company/Employees.htm" will be used with the default skin:
//    FMCOpenHelp( 'Company/Employees.htm', null, null, null );
//
//    In the following example, both the default topic and skin will be used:
//    FMCOpenHelp( null, null, null, null );
//
//    In the following example, the default topic will be used with "BlueSkin":
//    FMCOpenHelp( null, 'BlueSkin', null, null );
//
//    In the following example, both the default topic and skin will be used. The help system will be started with the search pane
//    displaying the search results for the query 'quarterly report'. The topic from the first result will not be opened:
//    FMCOpenHelp( null, null, 'quarterly report', false );
//
//    In the following example, both the default topic and skin will be used. The help system will be started with the search pane
//    displaying the search results for the query 'quarterly report'. The topic from the first result will be opened:
//    FMCOpenHelp( null, null, 'quarterly report', true );

function FMCOpenHelp( id, skinName, searchQuery, firstPick, pathToHelpSystem )
{
    MadCap.OpenHelp(id, skinName, searchQuery, firstPick, pathToHelpSystem);
}

/*!
* Copyright MadCap Software
* http://www.madcapsoftware.com/
*
* v16.0.7426.25547
*/

/*
 RequireJS 2.1.11 Copyright (c) 2010-2014, The Dojo Foundation All Rights Reserved.
 Available via the MIT or new BSD license.
 see: http://github.com/jrburke/requirejs for details
*/
var requirejs, require, define;
(function (ca) {
    function G(b) { return "[object Function]" === M.call(b) } function H(b) { return "[object Array]" === M.call(b) } function v(b, c) { if (b) { var d; for (d = 0; d < b.length && (!b[d] || !c(b[d], d, b)) ; d += 1); } } function U(b, c) { if (b) { var d; for (d = b.length - 1; -1 < d && (!b[d] || !c(b[d], d, b)) ; d -= 1); } } function s(b, c) { return ga.call(b, c) } function j(b, c) { return s(b, c) && b[c] } function B(b, c) { for (var d in b) if (s(b, d) && c(b[d], d)) break } function V(b, c, d, g) {
        c && B(c, function (c, h) {
            if (d || !s(b, h)) g && "object" === typeof c && c && !H(c) && !G(c) && !(c instanceof
            RegExp) ? (b[h] || (b[h] = {}), V(b[h], c, d, g)) : b[h] = c
        }); return b
    } function t(b, c) { return function () { return c.apply(b, arguments) } } function da(b) { throw b; } function ea(b) { if (!b) return b; var c = ca; v(b.split("."), function (b) { c = c[b] }); return c } function C(b, c, d, g) { c = Error(c + "\nhttp://requirejs.org/docs/errors.html#" + b); c.requireType = b; c.requireModules = g; d && (c.originalError = d); return c } function ha(b) {
        function c(a, e, b) {
            var f, n, c, d, g, h, i, I = e && e.split("/"); n = I; var m = l.map, k = m && m["*"]; if (a && "." === a.charAt(0)) if (e) {
                n =
                I.slice(0, I.length - 1); a = a.split("/"); e = a.length - 1; l.nodeIdCompat && R.test(a[e]) && (a[e] = a[e].replace(R, "")); n = a = n.concat(a); d = n.length; for (e = 0; e < d; e++) if (c = n[e], "." === c) n.splice(e, 1), e -= 1; else if (".." === c) if (1 === e && (".." === n[2] || ".." === n[0])) break; else 0 < e && (n.splice(e - 1, 2), e -= 2); a = a.join("/")
            } else 0 === a.indexOf("./") && (a = a.substring(2)); if (b && m && (I || k)) {
                n = a.split("/"); e = n.length; a: for (; 0 < e; e -= 1) {
                    d = n.slice(0, e).join("/"); if (I) for (c = I.length; 0 < c; c -= 1) if (b = j(m, I.slice(0, c).join("/"))) if (b = j(b, d)) {
                        f = b;
                        g = e; break a
                    } !h && (k && j(k, d)) && (h = j(k, d), i = e)
                } !f && h && (f = h, g = i); f && (n.splice(0, g, f), a = n.join("/"))
            } return (f = j(l.pkgs, a)) ? f : a
        } function d(a) { z && v(document.getElementsByTagName("script"), function (e) { if (e.getAttribute("data-requiremodule") === a && e.getAttribute("data-requirecontext") === i.contextName) return e.parentNode.removeChild(e), !0 }) } function g(a) { var e = j(l.paths, a); if (e && H(e) && 1 < e.length) return e.shift(), i.require.undef(a), i.require([a]), !0 } function u(a) {
            var e; return [e, a];
        } function m(a, e, b, f) { var n, d, g = null, h = e ? e.name : null, l = a, m = !0, k = ""; a || (m = !1, a = "_@r" + (M += 1)); a = u(a); g = a[0]; a = a[1]; g && (g = c(g, h, f), d = j(p, g)); a && (g ? k = d && d.normalize ? d.normalize(a, function (a) { return c(a, h, f) }) : c(a, h, f) : (k = c(a, h, f), a = u(k), g = a[0], k = a[1], b = !0, n = i.nameToUrl(k))); b = g && !d && !b ? "_unnormalized" + (Q += 1) : ""; return { prefix: g, name: k, parentMap: e, unnormalized: !!b, url: n, originalName: l, isDefine: m, id: (g ? g + "!" + k : k) + b } } function q(a) {
            var e = a.id, b = j(k, e); b || (b = k[e] = new i.Module(a));
            return b
        } function r(a, e, b) { var f = a.id, n = j(k, f); if (s(p, f) && (!n || n.defineEmitComplete)) "defined" === e && b(p[f]); else if (n = q(a), n.error && "error" === e) b(n.error); else n.on(e, b) } function w(a, e) { var b = a.requireModules, f = !1; if (e) e(a); else if (v(b, function (e) { if (e = j(k, e)) e.error = a, e.events.error && (f = !0, e.emit("error", a)) }), !f) h.onError(a) } function x() { S.length && (ia.apply(A, [A.length, 0].concat(S)), S = []) } function y(a) { delete k[a]; delete W[a] } function F(a, e, b) {
            var f = a.map.id; a.error ? a.emit("error", a.error) : (e[f] =
            !0, v(a.depMaps, function (f, c) { var d = f.id, g = j(k, d); g && (!a.depMatched[c] && !b[d]) && (j(e, d) ? (a.defineDep(c, p[d]), a.check()) : F(g, e, b)) }), b[f] = !0)
        } function D() {
            var a, e, b = (a = 1E3 * l.waitSeconds) && i.startTime + a < (new Date).getTime(), f = [], c = [], h = !1, k = !0; if (!X) {
                X = !0; B(W, function (a) { var i = a.map, m = i.id; if (a.enabled && (i.isDefine || c.push(a), !a.error)) if (!a.inited && b) g(m) ? h = e = !0 : (f.push(m), d(m)); else if (!a.inited && (a.fetched && i.isDefine) && (h = !0, !i.prefix)) return k = !1 }); if (b && f.length) return a = C("timeout", "Load timeout for modules: " +
                f, null, f), a.contextName = i.contextName, w(a); k && v(c, function (a) { F(a, {}, {}) }); if ((!b || e) && h) if ((z || fa) && !Y) Y = setTimeout(function () { Y = 0; D() }, 50); X = !1
            }
        } function E(a) { s(p, a[0]) || q(m(a[0], null, !0)).init(a[1], a[2]) } function K(a) { var a = a.currentTarget || a.srcElement, e = i.onScriptLoad; a.detachEvent && !Z ? a.detachEvent("onreadystatechange", e) : a.removeEventListener("load", e, !1); e = i.onScriptError; (!a.detachEvent || Z) && a.removeEventListener("error", e, !1); return { node: a, id: a && a.getAttribute("data-requiremodule") } } function L() {
            var a;
            for (x() ; A.length;) { a = A.shift(); if (null === a[0]) return w(C("mismatch", "Mismatched anonymous define() module: " + a[a.length - 1])); E(a) }
        } var X, $, i, N, Y, l = { waitSeconds: 7, baseUrl: "./", paths: {}, bundles: {}, pkgs: {}, shim: {}, config: {} }, k = {}, W = {}, aa = {}, A = [], p = {}, T = {}, ba = {}, M = 1, Q = 1; N = {
            require: function (a) { return a.require ? a.require : a.require = i.makeRequire(a.map) }, exports: function (a) { a.usingExports = !0; if (a.map.isDefine) return a.exports ? p[a.map.id] = a.exports : a.exports = p[a.map.id] = {} }, module: function (a) {
                return a.module ?
                a.module : a.module = { id: a.map.id, uri: a.map.url, config: function () { return j(l.config, a.map.id) || {} }, exports: a.exports || (a.exports = {}) }
            }
        }; $ = function (a) { this.events = j(aa, a.id) || {}; this.map = a; this.shim = j(l.shim, a.id); this.depExports = []; this.depMaps = []; this.depMatched = []; this.pluginMaps = {}; this.depCount = 0 }; $.prototype = {
            init: function (a, e, b, f) {
                f = f || {}; if (!this.inited) {
                    this.factory = e; if (b) this.on("error", b); else this.events.error && (b = t(this, function (a) { this.emit("error", a) })); this.depMaps = a && a.slice(0); this.errback =
                    b; this.inited = !0; this.ignore = f.ignore; f.enabled || this.enabled ? this.enable() : this.check()
                }
            }, defineDep: function (a, e) { this.depMatched[a] || (this.depMatched[a] = !0, this.depCount -= 1, this.depExports[a] = e) }, fetch: function () { if (!this.fetched) { this.fetched = !0; i.startTime = (new Date).getTime(); var a = this.map; if (this.shim) i.makeRequire(this.map, { enableBuildCallback: !0 })(this.shim.deps || [], t(this, function () { return a.prefix ? this.callPlugin() : this.load() })); else return a.prefix ? this.callPlugin() : this.load() } }, load: function () {
                var a =
                this.map.url; T[a] || (T[a] = !0, i.load(this.map.id, a))
            }, check: function () {
                if (this.enabled && !this.enabling) {
                    var a, e, b = this.map.id; e = this.depExports; var f = this.exports, c = this.factory; if (this.inited) if (this.error) this.emit("error", this.error); else {
                        if (!this.defining) {
                            this.defining = !0; if (1 > this.depCount && !this.defined) {
                                if (G(c)) {
                                    if (this.events.error && this.map.isDefine || h.onError !== da) try { f = i.execCb(b, c, e, f) } catch (d) { a = d } else f = i.execCb(b, c, e, f); this.map.isDefine && void 0 === f && ((e = this.module) ? f = e.exports : this.usingExports &&
                                    (f = this.exports)); if (a) return a.requireMap = this.map, a.requireModules = this.map.isDefine ? [this.map.id] : null, a.requireType = this.map.isDefine ? "define" : "require", w(this.error = a)
                                } else f = c; this.exports = f; if (this.map.isDefine && !this.ignore && (p[b] = f, h.onResourceLoad)) h.onResourceLoad(i, this.map, this.depMaps); y(b); this.defined = !0
                            } this.defining = !1; this.defined && !this.defineEmitted && (this.defineEmitted = !0, this.emit("defined", this.exports), this.defineEmitComplete = !0)
                        }
                    } else this.fetch()
                }
            }, callPlugin: function () {
                var a =
                this.map, b = a.id, d = m(a.prefix); this.depMaps.push(d); r(d, "defined", t(this, function (f) {
                    var d, g; g = j(ba, this.map.id); var J = this.map.name, u = this.map.parentMap ? this.map.parentMap.name : null, p = i.makeRequire(a.parentMap, { enableBuildCallback: !0 }); if (this.map.unnormalized) {
                        if (f.normalize && (J = f.normalize(J, function (a) { return c(a, u, !0) }) || ""), f = m(a.prefix + "!" + J, this.map.parentMap), r(f, "defined", t(this, function (a) { this.init([], function () { return a }, null, { enabled: !0, ignore: !0 }) })), g = j(k, f.id)) {
                            this.depMaps.push(f);
                            if (this.events.error) g.on("error", t(this, function (a) { this.emit("error", a) })); g.enable()
                        }
                    } else g ? (this.map.url = i.nameToUrl(g), this.load()) : (d = t(this, function (a) { this.init([], function () { return a }, null, { enabled: !0 }) }), d.error = t(this, function (a) { this.inited = !0; this.error = a; a.requireModules = [b]; B(k, function (a) { 0 === a.map.id.indexOf(b + "_unnormalized") && y(a.map.id) }); w(a) }), d.fromText = t(this, function (f, c) {
                        var g = a.name, J = m(g), k = O; c && (f = c); k && (O = !1); q(J); s(l.config, b) && (l.config[g] = l.config[b]); try { h.exec(f) } catch (j) {
                            return w(C("fromtexteval",
                            "fromText eval for " + b + " failed: " + j, j, [b]))
                        } k && (O = !0); this.depMaps.push(J); i.completeLoad(g); p([g], d)
                    }), f.load(a.name, p, d, l))
                })); i.enable(d, this); this.pluginMaps[d.id] = d
            }, enable: function () {
                W[this.map.id] = this; this.enabling = this.enabled = !0; v(this.depMaps, t(this, function (a, b) {
                    var c, f; if ("string" === typeof a) {
                        a = m(a, this.map.isDefine ? this.map : this.map.parentMap, !1, !this.skipMap); this.depMaps[b] = a; if (c = j(N, a.id)) { this.depExports[b] = c(this); return } this.depCount += 1; r(a, "defined", t(this, function (a) {
                            this.defineDep(b,
                            a); this.check()
                        })); this.errback && r(a, "error", t(this, this.errback))
                    } c = a.id; f = k[c]; !s(N, c) && (f && !f.enabled) && i.enable(a, this)
                })); B(this.pluginMaps, t(this, function (a) { var b = j(k, a.id); b && !b.enabled && i.enable(a, this) })); this.enabling = !1; this.check()
            }, on: function (a, b) { var c = this.events[a]; c || (c = this.events[a] = []); c.push(b) }, emit: function (a, b) { v(this.events[a], function (a) { a(b) }); "error" === a && delete this.events[a] }
        }; i = {
            config: l, contextName: b, registry: k, defined: p, urlFetched: T, defQueue: A, Module: $, makeModuleMap: m,
            nextTick: h.nextTick, onError: w, configure: function (a) {
                a.baseUrl && "/" !== a.baseUrl.charAt(a.baseUrl.length - 1) && (a.baseUrl += "/"); var b = l.shim, c = { paths: !0, bundles: !0, config: !0, map: !0 }; B(a, function (a, b) { c[b] ? (l[b] || (l[b] = {}), V(l[b], a, !0, !0)) : l[b] = a }); a.bundles && B(a.bundles, function (a, b) { v(a, function (a) { a !== b && (ba[a] = b) }) }); a.shim && (B(a.shim, function (a, c) { H(a) && (a = { deps: a }); if ((a.exports || a.init) && !a.exportsFn) a.exportsFn = i.makeShimExports(a); b[c] = a }), l.shim = b); a.packages && v(a.packages, function (a) {
                    var b,
                    a = "string" === typeof a ? { name: a } : a; b = a.name; a.location && (l.paths[b] = a.location); l.pkgs[b] = a.name + "/" + (a.main || "main").replace(ja, "").replace(R, "")
                }); B(k, function (a, b) { !a.inited && !a.map.unnormalized && (a.map = m(b)) }); if (a.deps || a.callback) i.require(a.deps || [], a.callback)
            }, makeShimExports: function (a) { return function () { var b; a.init && (b = a.init.apply(ca, arguments)); return b || a.exports && ea(a.exports) } }, makeRequire: function (a, e) {
                function g(f, c, d) {
                    var j, l; e.enableBuildCallback && (c && G(c)) && (c.__requireJsBuild =
                    !0); if ("string" === typeof f) { if (G(c)) return w(C("requireargs", "Invalid require call"), d); if (a && s(N, f)) return N[f](k[a.id]); if (h.get) return h.get(i, f, a, g); j = m(f, a, !1, !0); j = j.id; return !s(p, j) ? w(C("notloaded", 'Module name "' + j + '" has not been loaded yet for context: ' + b + (a ? "" : ". Use require([])"))) : p[j] } L(); i.nextTick(function () { L(); l = q(m(null, a)); l.skipMap = e.skipMap; l.init(f, c, d, { enabled: !0 }); D() }); return g
                } e = e || {}; V(g, {
                    isBrowser: z, toUrl: function (b) {
                        var e, d = b.lastIndexOf("."), g = b.split("/")[0]; if (-1 !==
                        d && (!("." === g || ".." === g) || 1 < d)) e = b.substring(d, b.length), b = b.substring(0, d); return i.nameToUrl(c(b, a && a.id, !0), e, !0)
                    }, defined: function (b) { return s(p, m(b, a, !1, !0).id) }, specified: function (b) { b = m(b, a, !1, !0).id; return s(p, b) || s(k, b) }
                }); a || (g.undef = function (b) { x(); var c = m(b, a, !0), e = j(k, b); d(b); delete p[b]; delete T[c.url]; delete aa[b]; U(A, function (a, c) { a[0] === b && A.splice(c, 1) }); e && (e.events.defined && (aa[b] = e.events), y(b)) }); return g
            }, enable: function (a) { j(k, a.id) && q(a).enable() }, completeLoad: function (a) {
                var b,
                c, f = j(l.shim, a) || {}, d = f.exports; for (x() ; A.length;) { c = A.shift(); if (null === c[0]) { c[0] = a; if (b) break; b = !0 } else c[0] === a && (b = !0); E(c) } c = j(k, a); if (!b && !s(p, a) && c && !c.inited) { if (l.enforceDefine && (!d || !ea(d))) return g(a) ? void 0 : w(C("nodefine", "No define call for " + a, null, [a])); E([a, f.deps || [], f.exportsFn]) } D()
            }, nameToUrl: function (a, b, c) {
                var f, d, g; (f = j(l.pkgs, a)) && (a = f); if (f = j(ba, a)) return i.nameToUrl(f, b, c); if (h.jsExtRegExp.test(a)) f = a + (b || ""); else {
                    f = l.paths; a = a.split("/"); for (d = a.length; 0 < d; d -= 1) if (g = a.slice(0,
                    d).join("/"), g = j(f, g)) { H(g) && (g = g[0]); a.splice(0, d, g); break } f = a.join("/"); f += b || (/^data\:|\?/.test(f) || c ? "" : ".js"); f = ("/" === f.charAt(0) || f.match(/^[\w\+\.\-]+:/) ? "" : l.baseUrl) + f
                } return l.urlArgs ? f + ((-1 === f.indexOf("?") ? "?" : "&") + l.urlArgs) : f
            }, load: function (a, b) { h.load(i, a, b) }, execCb: function (a, b, c, d) { return b.apply(d, c) }, onScriptLoad: function (a) { if ("load" === a.type || ka.test((a.currentTarget || a.srcElement).readyState)) P = null, a = K(a), i.completeLoad(a.id) }, onScriptError: function (a) {
                var b = K(a); if (!g(b.id)) return w(C("scripterror",
                "Script error for: " + b.id, a, [b.id]))
            }
        }; i.require = i.makeRequire(); return i
    } var h, x, y, D, K, E, P, L, q, Q, la = /(\/\*([\s\S]*?)\*\/|([^:]|^)\/\/(.*)$)/mg, ma = /[^.]\s*require\s*\(\s*["']([^'"\s]+)["']\s*\)/g, R = /\.js$/, ja = /^\.\//; x = Object.prototype; var M = x.toString, ga = x.hasOwnProperty, ia = Array.prototype.splice, z = !!("undefined" !== typeof window && "undefined" !== typeof navigator && window.document), fa = !z && "undefined" !== typeof importScripts, ka = z && "PLAYSTATION 3" === navigator.platform ? /^complete$/ : /^(complete|loaded)$/,
    Z = "undefined" !== typeof opera && "[object Opera]" === opera.toString(), F = {}, r = {}, S = [], O = !1; if ("undefined" === typeof define) {
        if ("undefined" !== typeof requirejs) { if (G(requirejs)) return; r = requirejs; requirejs = void 0 } "undefined" !== typeof require && !G(require) && (r = require, require = void 0); h = requirejs = function (b, c, d, g) { var u, m = "_"; !H(b) && "string" !== typeof b && (u = b, H(c) ? (b = c, c = d, d = g) : b = []); u && u.context && (m = u.context); (g = j(F, m)) || (g = F[m] = h.s.newContext(m)); u && g.configure(u); return g.require(b, c, d) }; h.config = function (b) { return h(b) };
        h.nextTick = "undefined" !== typeof setTimeout ? function (b) { setTimeout(b, 4) } : function (b) { b() }; require || (require = h); h.version = "2.1.11"; h.jsExtRegExp = /^\/|:|\?|\.js$/; h.isBrowser = z; x = h.s = { contexts: F, newContext: ha }; h({}); v(["toUrl", "undef", "defined", "specified"], function (b) { h[b] = function () { var c = F._; return c.require[b].apply(c, arguments) } }); if (z && (y = x.head = document.getElementsByTagName("head")[0], D = document.getElementsByTagName("base")[0])) y = x.head = D.parentNode; h.onError = da; h.createNode = function (b) {
            var c =
            b.xhtml ? document.createElementNS("http://www.w3.org/1999/xhtml", "html:script") : document.createElement("script"); c.type = b.scriptType || "text/javascript"; c.charset = "utf-8"; c.async = !0; return c
        }; h.load = function (b, c, d) {
            var g = b && b.config || {}; if (z) return g = h.createNode(g, c, d), g.setAttribute("data-requirecontext", b.contextName), g.setAttribute("data-requiremodule", c), g.attachEvent && !(g.attachEvent.toString && 0 > g.attachEvent.toString().indexOf("[native code")) && !Z ? (O = !0, g.attachEvent("onreadystatechange", b.onScriptLoad)) :
            (g.addEventListener("load", b.onScriptLoad, !1), g.addEventListener("error", b.onScriptError, !1)), g.src = d, L = g, D ? y.insertBefore(g, D) : y.appendChild(g), L = null, g; if (fa) try { importScripts(d), b.completeLoad(c) } catch (j) { b.onError(C("importscripts", "importScripts failed for " + c + " at " + d, j, [c])) }
        }; z && !r.skipDataMain && U(document.getElementsByTagName("script"), function (b) {
            y || (y = b.parentNode); if (K = b.getAttribute("data-main")) return q = K, r.baseUrl || (E = q.split("/"), q = E.pop(), Q = E.length ? E.join("/") + "/" : "./", r.baseUrl =
            Q), q = q.replace(R, ""), h.jsExtRegExp.test(q) && (q = K), r.deps = r.deps ? r.deps.concat(q) : [q], !0
        }); define = function (b, c, d) {
            var g, h; "string" !== typeof b && (d = c, c = b, b = null); H(c) || (d = c, c = null); !c && G(d) && (c = [], d.length && (d.toString().replace(la, "").replace(ma, function (b, d) { c.push(d) }), c = (1 === d.length ? ["require"] : ["require", "exports", "module"]).concat(c))); if (O) {
                if (!(g = L)) P && "interactive" === P.readyState || U(document.getElementsByTagName("script"), function (b) { if ("interactive" === b.readyState) return P = b }), g = P; g && (b ||
                (b = g.getAttribute("data-requiremodule")), h = F[g.getAttribute("data-requirecontext")])
            } (h ? h.defQueue : S).push([b, c, d])
        }; define.amd = { jQuery: !0 }; h.exec = function (b) { return eval(b) }; h(r)
    }
})(this);/* require end */

// `jQuery begin` and `jQuery end` are required for CSH.js (include if updating this file to newer jquery)
/* jQuery begin */
/*! jQuery v3.4.1 | (c) JS Foundation and other contributors | jquery.org/license */
!function(e,t){"use strict";"object"==typeof module&&"object"==typeof module.exports?module.exports=e.document?t(e,!0):function(e){if(!e.document)throw new Error("jQuery requires a window with a document");return t(e)}:t(e)}("undefined"!=typeof window?window:this,function(C,e){"use strict";var t=[],E=C.document,r=Object.getPrototypeOf,s=t.slice,g=t.concat,u=t.push,i=t.indexOf,n={},o=n.toString,v=n.hasOwnProperty,a=v.toString,l=a.call(Object),y={},m=function(e){return"function"==typeof e&&"number"!=typeof e.nodeType},x=function(e){return null!=e&&e===e.window},c={type:!0,src:!0,nonce:!0,noModule:!0};function b(e,t,n){var r,i,o=(n=n||E).createElement("script");if(o.text=e,t)for(r in c)(i=t[r]||t.getAttribute&&t.getAttribute(r))&&o.setAttribute(r,i);n.head.appendChild(o).parentNode.removeChild(o)}function w(e){return null==e?e+"":"object"==typeof e||"function"==typeof e?n[o.call(e)]||"object":typeof e}var f="3.4.1",k=function(e,t){return new k.fn.init(e,t)},p=/^[\s\uFEFF\xA0]+|[\s\uFEFF\xA0]+$/g;function d(e){var t=!!e&&"length"in e&&e.length,n=w(e);return!m(e)&&!x(e)&&("array"===n||0===t||"number"==typeof t&&0<t&&t-1 in e)}k.fn=k.prototype={jquery:f,constructor:k,length:0,toArray:function(){return s.call(this)},get:function(e){return null==e?s.call(this):e<0?this[e+this.length]:this[e]},pushStack:function(e){var t=k.merge(this.constructor(),e);return t.prevObject=this,t},each:function(e){return k.each(this,e)},map:function(n){return this.pushStack(k.map(this,function(e,t){return n.call(e,t,e)}))},slice:function(){return this.pushStack(s.apply(this,arguments))},first:function(){return this.eq(0)},last:function(){return this.eq(-1)},eq:function(e){var t=this.length,n=+e+(e<0?t:0);return this.pushStack(0<=n&&n<t?[this[n]]:[])},end:function(){return this.prevObject||this.constructor()},push:u,sort:t.sort,splice:t.splice},k.extend=k.fn.extend=function(){var e,t,n,r,i,o,a=arguments[0]||{},s=1,u=arguments.length,l=!1;for("boolean"==typeof a&&(l=a,a=arguments[s]||{},s++),"object"==typeof a||m(a)||(a={}),s===u&&(a=this,s--);s<u;s++)if(null!=(e=arguments[s]))for(t in e)r=e[t],"__proto__"!==t&&a!==r&&(l&&r&&(k.isPlainObject(r)||(i=Array.isArray(r)))?(n=a[t],o=i&&!Array.isArray(n)?[]:i||k.isPlainObject(n)?n:{},i=!1,a[t]=k.extend(l,o,r)):void 0!==r&&(a[t]=r));return a},k.extend({expando:"jQuery"+(f+Math.random()).replace(/\D/g,""),isReady:!0,error:function(e){throw new Error(e)},noop:function(){},isPlainObject:function(e){var t,n;return!(!e||"[object Object]"!==o.call(e))&&(!(t=r(e))||"function"==typeof(n=v.call(t,"constructor")&&t.constructor)&&a.call(n)===l)},isEmptyObject:function(e){var t;for(t in e)return!1;return!0},globalEval:function(e,t){b(e,{nonce:t&&t.nonce})},each:function(e,t){var n,r=0;if(d(e)){for(n=e.length;r<n;r++)if(!1===t.call(e[r],r,e[r]))break}else for(r in e)if(!1===t.call(e[r],r,e[r]))break;return e},trim:function(e){return null==e?"":(e+"").replace(p,"")},makeArray:function(e,t){var n=t||[];return null!=e&&(d(Object(e))?k.merge(n,"string"==typeof e?[e]:e):u.call(n,e)),n},inArray:function(e,t,n){return null==t?-1:i.call(t,e,n)},merge:function(e,t){for(var n=+t.length,r=0,i=e.length;r<n;r++)e[i++]=t[r];return e.length=i,e},grep:function(e,t,n){for(var r=[],i=0,o=e.length,a=!n;i<o;i++)!t(e[i],i)!==a&&r.push(e[i]);return r},map:function(e,t,n){var r,i,o=0,a=[];if(d(e))for(r=e.length;o<r;o++)null!=(i=t(e[o],o,n))&&a.push(i);else for(o in e)null!=(i=t(e[o],o,n))&&a.push(i);return g.apply([],a)},guid:1,support:y}),"function"==typeof Symbol&&(k.fn[Symbol.iterator]=t[Symbol.iterator]),k.each("Boolean Number String Function Array Date RegExp Object Error Symbol".split(" "),function(e,t){n["[object "+t+"]"]=t.toLowerCase()});var h=function(n){var e,d,b,o,i,h,f,g,w,u,l,T,C,a,E,v,s,c,y,k="sizzle"+1*new Date,m=n.document,S=0,r=0,p=ue(),x=ue(),N=ue(),A=ue(),D=function(e,t){return e===t&&(l=!0),0},j={}.hasOwnProperty,t=[],q=t.pop,L=t.push,H=t.push,O=t.slice,P=function(e,t){for(var n=0,r=e.length;n<r;n++)if(e[n]===t)return n;return-1},R="checked|selected|async|autofocus|autoplay|controls|defer|disabled|hidden|ismap|loop|multiple|open|readonly|required|scoped",M="[\\x20\\t\\r\\n\\f]",I="(?:\\\\.|[\\w-]|[^\0-\\xa0])+",W="\\["+M+"*("+I+")(?:"+M+"*([*^$|!~]?=)"+M+"*(?:'((?:\\\\.|[^\\\\'])*)'|\"((?:\\\\.|[^\\\\\"])*)\"|("+I+"))|)"+M+"*\\]",$=":("+I+")(?:\\((('((?:\\\\.|[^\\\\'])*)'|\"((?:\\\\.|[^\\\\\"])*)\")|((?:\\\\.|[^\\\\()[\\]]|"+W+")*)|.*)\\)|)",F=new RegExp(M+"+","g"),B=new RegExp("^"+M+"+|((?:^|[^\\\\])(?:\\\\.)*)"+M+"+$","g"),_=new RegExp("^"+M+"*,"+M+"*"),z=new RegExp("^"+M+"*([>+~]|"+M+")"+M+"*"),U=new RegExp(M+"|>"),X=new RegExp($),V=new RegExp("^"+I+"$"),G={ID:new RegExp("^#("+I+")"),CLASS:new RegExp("^\\.("+I+")"),TAG:new RegExp("^("+I+"|[*])"),ATTR:new RegExp("^"+W),PSEUDO:new RegExp("^"+$),CHILD:new RegExp("^:(only|first|last|nth|nth-last)-(child|of-type)(?:\\("+M+"*(even|odd|(([+-]|)(\\d*)n|)"+M+"*(?:([+-]|)"+M+"*(\\d+)|))"+M+"*\\)|)","i"),bool:new RegExp("^(?:"+R+")$","i"),needsContext:new RegExp("^"+M+"*[>+~]|:(even|odd|eq|gt|lt|nth|first|last)(?:\\("+M+"*((?:-\\d)?\\d*)"+M+"*\\)|)(?=[^-]|$)","i")},Y=/HTML$/i,Q=/^(?:input|select|textarea|button)$/i,J=/^h\d$/i,K=/^[^{]+\{\s*\[native \w/,Z=/^(?:#([\w-]+)|(\w+)|\.([\w-]+))$/,ee=/[+~]/,te=new RegExp("\\\\([\\da-f]{1,6}"+M+"?|("+M+")|.)","ig"),ne=function(e,t,n){var r="0x"+t-65536;return r!=r||n?t:r<0?String.fromCharCode(r+65536):String.fromCharCode(r>>10|55296,1023&r|56320)},re=/([\0-\x1f\x7f]|^-?\d)|^-$|[^\0-\x1f\x7f-\uFFFF\w-]/g,ie=function(e,t){return t?"\0"===e?"\ufffd":e.slice(0,-1)+"\\"+e.charCodeAt(e.length-1).toString(16)+" ":"\\"+e},oe=function(){T()},ae=be(function(e){return!0===e.disabled&&"fieldset"===e.nodeName.toLowerCase()},{dir:"parentNode",next:"legend"});try{H.apply(t=O.call(m.childNodes),m.childNodes),t[m.childNodes.length].nodeType}catch(e){H={apply:t.length?function(e,t){L.apply(e,O.call(t))}:function(e,t){var n=e.length,r=0;while(e[n++]=t[r++]);e.length=n-1}}}function se(t,e,n,r){var i,o,a,s,u,l,c,f=e&&e.ownerDocument,p=e?e.nodeType:9;if(n=n||[],"string"!=typeof t||!t||1!==p&&9!==p&&11!==p)return n;if(!r&&((e?e.ownerDocument||e:m)!==C&&T(e),e=e||C,E)){if(11!==p&&(u=Z.exec(t)))if(i=u[1]){if(9===p){if(!(a=e.getElementById(i)))return n;if(a.id===i)return n.push(a),n}else if(f&&(a=f.getElementById(i))&&y(e,a)&&a.id===i)return n.push(a),n}else{if(u[2])return H.apply(n,e.getElementsByTagName(t)),n;if((i=u[3])&&d.getElementsByClassName&&e.getElementsByClassName)return H.apply(n,e.getElementsByClassName(i)),n}if(d.qsa&&!A[t+" "]&&(!v||!v.test(t))&&(1!==p||"object"!==e.nodeName.toLowerCase())){if(c=t,f=e,1===p&&U.test(t)){(s=e.getAttribute("id"))?s=s.replace(re,ie):e.setAttribute("id",s=k),o=(l=h(t)).length;while(o--)l[o]="#"+s+" "+xe(l[o]);c=l.join(","),f=ee.test(t)&&ye(e.parentNode)||e}try{return H.apply(n,f.querySelectorAll(c)),n}catch(e){A(t,!0)}finally{s===k&&e.removeAttribute("id")}}}return g(t.replace(B,"$1"),e,n,r)}function ue(){var r=[];return function e(t,n){return r.push(t+" ")>b.cacheLength&&delete e[r.shift()],e[t+" "]=n}}function le(e){return e[k]=!0,e}function ce(e){var t=C.createElement("fieldset");try{return!!e(t)}catch(e){return!1}finally{t.parentNode&&t.parentNode.removeChild(t),t=null}}function fe(e,t){var n=e.split("|"),r=n.length;while(r--)b.attrHandle[n[r]]=t}function pe(e,t){var n=t&&e,r=n&&1===e.nodeType&&1===t.nodeType&&e.sourceIndex-t.sourceIndex;if(r)return r;if(n)while(n=n.nextSibling)if(n===t)return-1;return e?1:-1}function de(t){return function(e){return"input"===e.nodeName.toLowerCase()&&e.type===t}}function he(n){return function(e){var t=e.nodeName.toLowerCase();return("input"===t||"button"===t)&&e.type===n}}function ge(t){return function(e){return"form"in e?e.parentNode&&!1===e.disabled?"label"in e?"label"in e.parentNode?e.parentNode.disabled===t:e.disabled===t:e.isDisabled===t||e.isDisabled!==!t&&ae(e)===t:e.disabled===t:"label"in e&&e.disabled===t}}function ve(a){return le(function(o){return o=+o,le(function(e,t){var n,r=a([],e.length,o),i=r.length;while(i--)e[n=r[i]]&&(e[n]=!(t[n]=e[n]))})})}function ye(e){return e&&"undefined"!=typeof e.getElementsByTagName&&e}for(e in d=se.support={},i=se.isXML=function(e){var t=e.namespaceURI,n=(e.ownerDocument||e).documentElement;return!Y.test(t||n&&n.nodeName||"HTML")},T=se.setDocument=function(e){var t,n,r=e?e.ownerDocument||e:m;return r!==C&&9===r.nodeType&&r.documentElement&&(a=(C=r).documentElement,E=!i(C),m!==C&&(n=C.defaultView)&&n.top!==n&&(n.addEventListener?n.addEventListener("unload",oe,!1):n.attachEvent&&n.attachEvent("onunload",oe)),d.attributes=ce(function(e){return e.className="i",!e.getAttribute("className")}),d.getElementsByTagName=ce(function(e){return e.appendChild(C.createComment("")),!e.getElementsByTagName("*").length}),d.getElementsByClassName=K.test(C.getElementsByClassName),d.getById=ce(function(e){return a.appendChild(e).id=k,!C.getElementsByName||!C.getElementsByName(k).length}),d.getById?(b.filter.ID=function(e){var t=e.replace(te,ne);return function(e){return e.getAttribute("id")===t}},b.find.ID=function(e,t){if("undefined"!=typeof t.getElementById&&E){var n=t.getElementById(e);return n?[n]:[]}}):(b.filter.ID=function(e){var n=e.replace(te,ne);return function(e){var t="undefined"!=typeof e.getAttributeNode&&e.getAttributeNode("id");return t&&t.value===n}},b.find.ID=function(e,t){if("undefined"!=typeof t.getElementById&&E){var n,r,i,o=t.getElementById(e);if(o){if((n=o.getAttributeNode("id"))&&n.value===e)return[o];i=t.getElementsByName(e),r=0;while(o=i[r++])if((n=o.getAttributeNode("id"))&&n.value===e)return[o]}return[]}}),b.find.TAG=d.getElementsByTagName?function(e,t){return"undefined"!=typeof t.getElementsByTagName?t.getElementsByTagName(e):d.qsa?t.querySelectorAll(e):void 0}:function(e,t){var n,r=[],i=0,o=t.getElementsByTagName(e);if("*"===e){while(n=o[i++])1===n.nodeType&&r.push(n);return r}return o},b.find.CLASS=d.getElementsByClassName&&function(e,t){if("undefined"!=typeof t.getElementsByClassName&&E)return t.getElementsByClassName(e)},s=[],v=[],(d.qsa=K.test(C.querySelectorAll))&&(ce(function(e){a.appendChild(e).innerHTML="<a id='"+k+"'></a><select id='"+k+"-\r\\' msallowcapture=''><option selected=''></option></select>",e.querySelectorAll("[msallowcapture^='']").length&&v.push("[*^$]="+M+"*(?:''|\"\")"),e.querySelectorAll("[selected]").length||v.push("\\["+M+"*(?:value|"+R+")"),e.querySelectorAll("[id~="+k+"-]").length||v.push("~="),e.querySelectorAll(":checked").length||v.push(":checked"),e.querySelectorAll("a#"+k+"+*").length||v.push(".#.+[+~]")}),ce(function(e){e.innerHTML="<a href='' disabled='disabled'></a><select disabled='disabled'><option/></select>";var t=C.createElement("input");t.setAttribute("type","hidden"),e.appendChild(t).setAttribute("name","D"),e.querySelectorAll("[name=d]").length&&v.push("name"+M+"*[*^$|!~]?="),2!==e.querySelectorAll(":enabled").length&&v.push(":enabled",":disabled"),a.appendChild(e).disabled=!0,2!==e.querySelectorAll(":disabled").length&&v.push(":enabled",":disabled"),e.querySelectorAll("*,:x"),v.push(",.*:")})),(d.matchesSelector=K.test(c=a.matches||a.webkitMatchesSelector||a.mozMatchesSelector||a.oMatchesSelector||a.msMatchesSelector))&&ce(function(e){d.disconnectedMatch=c.call(e,"*"),c.call(e,"[s!='']:x"),s.push("!=",$)}),v=v.length&&new RegExp(v.join("|")),s=s.length&&new RegExp(s.join("|")),t=K.test(a.compareDocumentPosition),y=t||K.test(a.contains)?function(e,t){var n=9===e.nodeType?e.documentElement:e,r=t&&t.parentNode;return e===r||!(!r||1!==r.nodeType||!(n.contains?n.contains(r):e.compareDocumentPosition&&16&e.compareDocumentPosition(r)))}:function(e,t){if(t)while(t=t.parentNode)if(t===e)return!0;return!1},D=t?function(e,t){if(e===t)return l=!0,0;var n=!e.compareDocumentPosition-!t.compareDocumentPosition;return n||(1&(n=(e.ownerDocument||e)===(t.ownerDocument||t)?e.compareDocumentPosition(t):1)||!d.sortDetached&&t.compareDocumentPosition(e)===n?e===C||e.ownerDocument===m&&y(m,e)?-1:t===C||t.ownerDocument===m&&y(m,t)?1:u?P(u,e)-P(u,t):0:4&n?-1:1)}:function(e,t){if(e===t)return l=!0,0;var n,r=0,i=e.parentNode,o=t.parentNode,a=[e],s=[t];if(!i||!o)return e===C?-1:t===C?1:i?-1:o?1:u?P(u,e)-P(u,t):0;if(i===o)return pe(e,t);n=e;while(n=n.parentNode)a.unshift(n);n=t;while(n=n.parentNode)s.unshift(n);while(a[r]===s[r])r++;return r?pe(a[r],s[r]):a[r]===m?-1:s[r]===m?1:0}),C},se.matches=function(e,t){return se(e,null,null,t)},se.matchesSelector=function(e,t){if((e.ownerDocument||e)!==C&&T(e),d.matchesSelector&&E&&!A[t+" "]&&(!s||!s.test(t))&&(!v||!v.test(t)))try{var n=c.call(e,t);if(n||d.disconnectedMatch||e.document&&11!==e.document.nodeType)return n}catch(e){A(t,!0)}return 0<se(t,C,null,[e]).length},se.contains=function(e,t){return(e.ownerDocument||e)!==C&&T(e),y(e,t)},se.attr=function(e,t){(e.ownerDocument||e)!==C&&T(e);var n=b.attrHandle[t.toLowerCase()],r=n&&j.call(b.attrHandle,t.toLowerCase())?n(e,t,!E):void 0;return void 0!==r?r:d.attributes||!E?e.getAttribute(t):(r=e.getAttributeNode(t))&&r.specified?r.value:null},se.escape=function(e){return(e+"").replace(re,ie)},se.error=function(e){throw new Error("Syntax error, unrecognized expression: "+e)},se.uniqueSort=function(e){var t,n=[],r=0,i=0;if(l=!d.detectDuplicates,u=!d.sortStable&&e.slice(0),e.sort(D),l){while(t=e[i++])t===e[i]&&(r=n.push(i));while(r--)e.splice(n[r],1)}return u=null,e},o=se.getText=function(e){var t,n="",r=0,i=e.nodeType;if(i){if(1===i||9===i||11===i){if("string"==typeof e.textContent)return e.textContent;for(e=e.firstChild;e;e=e.nextSibling)n+=o(e)}else if(3===i||4===i)return e.nodeValue}else while(t=e[r++])n+=o(t);return n},(b=se.selectors={cacheLength:50,createPseudo:le,match:G,attrHandle:{},find:{},relative:{">":{dir:"parentNode",first:!0}," ":{dir:"parentNode"},"+":{dir:"previousSibling",first:!0},"~":{dir:"previousSibling"}},preFilter:{ATTR:function(e){return e[1]=e[1].replace(te,ne),e[3]=(e[3]||e[4]||e[5]||"").replace(te,ne),"~="===e[2]&&(e[3]=" "+e[3]+" "),e.slice(0,4)},CHILD:function(e){return e[1]=e[1].toLowerCase(),"nth"===e[1].slice(0,3)?(e[3]||se.error(e[0]),e[4]=+(e[4]?e[5]+(e[6]||1):2*("even"===e[3]||"odd"===e[3])),e[5]=+(e[7]+e[8]||"odd"===e[3])):e[3]&&se.error(e[0]),e},PSEUDO:function(e){var t,n=!e[6]&&e[2];return G.CHILD.test(e[0])?null:(e[3]?e[2]=e[4]||e[5]||"":n&&X.test(n)&&(t=h(n,!0))&&(t=n.indexOf(")",n.length-t)-n.length)&&(e[0]=e[0].slice(0,t),e[2]=n.slice(0,t)),e.slice(0,3))}},filter:{TAG:function(e){var t=e.replace(te,ne).toLowerCase();return"*"===e?function(){return!0}:function(e){return e.nodeName&&e.nodeName.toLowerCase()===t}},CLASS:function(e){var t=p[e+" "];return t||(t=new RegExp("(^|"+M+")"+e+"("+M+"|$)"))&&p(e,function(e){return t.test("string"==typeof e.className&&e.className||"undefined"!=typeof e.getAttribute&&e.getAttribute("class")||"")})},ATTR:function(n,r,i){return function(e){var t=se.attr(e,n);return null==t?"!="===r:!r||(t+="","="===r?t===i:"!="===r?t!==i:"^="===r?i&&0===t.indexOf(i):"*="===r?i&&-1<t.indexOf(i):"$="===r?i&&t.slice(-i.length)===i:"~="===r?-1<(" "+t.replace(F," ")+" ").indexOf(i):"|="===r&&(t===i||t.slice(0,i.length+1)===i+"-"))}},CHILD:function(h,e,t,g,v){var y="nth"!==h.slice(0,3),m="last"!==h.slice(-4),x="of-type"===e;return 1===g&&0===v?function(e){return!!e.parentNode}:function(e,t,n){var r,i,o,a,s,u,l=y!==m?"nextSibling":"previousSibling",c=e.parentNode,f=x&&e.nodeName.toLowerCase(),p=!n&&!x,d=!1;if(c){if(y){while(l){a=e;while(a=a[l])if(x?a.nodeName.toLowerCase()===f:1===a.nodeType)return!1;u=l="only"===h&&!u&&"nextSibling"}return!0}if(u=[m?c.firstChild:c.lastChild],m&&p){d=(s=(r=(i=(o=(a=c)[k]||(a[k]={}))[a.uniqueID]||(o[a.uniqueID]={}))[h]||[])[0]===S&&r[1])&&r[2],a=s&&c.childNodes[s];while(a=++s&&a&&a[l]||(d=s=0)||u.pop())if(1===a.nodeType&&++d&&a===e){i[h]=[S,s,d];break}}else if(p&&(d=s=(r=(i=(o=(a=e)[k]||(a[k]={}))[a.uniqueID]||(o[a.uniqueID]={}))[h]||[])[0]===S&&r[1]),!1===d)while(a=++s&&a&&a[l]||(d=s=0)||u.pop())if((x?a.nodeName.toLowerCase()===f:1===a.nodeType)&&++d&&(p&&((i=(o=a[k]||(a[k]={}))[a.uniqueID]||(o[a.uniqueID]={}))[h]=[S,d]),a===e))break;return(d-=v)===g||d%g==0&&0<=d/g}}},PSEUDO:function(e,o){var t,a=b.pseudos[e]||b.setFilters[e.toLowerCase()]||se.error("unsupported pseudo: "+e);return a[k]?a(o):1<a.length?(t=[e,e,"",o],b.setFilters.hasOwnProperty(e.toLowerCase())?le(function(e,t){var n,r=a(e,o),i=r.length;while(i--)e[n=P(e,r[i])]=!(t[n]=r[i])}):function(e){return a(e,0,t)}):a}},pseudos:{not:le(function(e){var r=[],i=[],s=f(e.replace(B,"$1"));return s[k]?le(function(e,t,n,r){var i,o=s(e,null,r,[]),a=e.length;while(a--)(i=o[a])&&(e[a]=!(t[a]=i))}):function(e,t,n){return r[0]=e,s(r,null,n,i),r[0]=null,!i.pop()}}),has:le(function(t){return function(e){return 0<se(t,e).length}}),contains:le(function(t){return t=t.replace(te,ne),function(e){return-1<(e.textContent||o(e)).indexOf(t)}}),lang:le(function(n){return V.test(n||"")||se.error("unsupported lang: "+n),n=n.replace(te,ne).toLowerCase(),function(e){var t;do{if(t=E?e.lang:e.getAttribute("xml:lang")||e.getAttribute("lang"))return(t=t.toLowerCase())===n||0===t.indexOf(n+"-")}while((e=e.parentNode)&&1===e.nodeType);return!1}}),target:function(e){var t=n.location&&n.location.hash;return t&&t.slice(1)===e.id},root:function(e){return e===a},focus:function(e){return e===C.activeElement&&(!C.hasFocus||C.hasFocus())&&!!(e.type||e.href||~e.tabIndex)},enabled:ge(!1),disabled:ge(!0),checked:function(e){var t=e.nodeName.toLowerCase();return"input"===t&&!!e.checked||"option"===t&&!!e.selected},selected:function(e){return e.parentNode&&e.parentNode.selectedIndex,!0===e.selected},empty:function(e){for(e=e.firstChild;e;e=e.nextSibling)if(e.nodeType<6)return!1;return!0},parent:function(e){return!b.pseudos.empty(e)},header:function(e){return J.test(e.nodeName)},input:function(e){return Q.test(e.nodeName)},button:function(e){var t=e.nodeName.toLowerCase();return"input"===t&&"button"===e.type||"button"===t},text:function(e){var t;return"input"===e.nodeName.toLowerCase()&&"text"===e.type&&(null==(t=e.getAttribute("type"))||"text"===t.toLowerCase())},first:ve(function(){return[0]}),last:ve(function(e,t){return[t-1]}),eq:ve(function(e,t,n){return[n<0?n+t:n]}),even:ve(function(e,t){for(var n=0;n<t;n+=2)e.push(n);return e}),odd:ve(function(e,t){for(var n=1;n<t;n+=2)e.push(n);return e}),lt:ve(function(e,t,n){for(var r=n<0?n+t:t<n?t:n;0<=--r;)e.push(r);return e}),gt:ve(function(e,t,n){for(var r=n<0?n+t:n;++r<t;)e.push(r);return e})}}).pseudos.nth=b.pseudos.eq,{radio:!0,checkbox:!0,file:!0,password:!0,image:!0})b.pseudos[e]=de(e);for(e in{submit:!0,reset:!0})b.pseudos[e]=he(e);function me(){}function xe(e){for(var t=0,n=e.length,r="";t<n;t++)r+=e[t].value;return r}function be(s,e,t){var u=e.dir,l=e.next,c=l||u,f=t&&"parentNode"===c,p=r++;return e.first?function(e,t,n){while(e=e[u])if(1===e.nodeType||f)return s(e,t,n);return!1}:function(e,t,n){var r,i,o,a=[S,p];if(n){while(e=e[u])if((1===e.nodeType||f)&&s(e,t,n))return!0}else while(e=e[u])if(1===e.nodeType||f)if(i=(o=e[k]||(e[k]={}))[e.uniqueID]||(o[e.uniqueID]={}),l&&l===e.nodeName.toLowerCase())e=e[u]||e;else{if((r=i[c])&&r[0]===S&&r[1]===p)return a[2]=r[2];if((i[c]=a)[2]=s(e,t,n))return!0}return!1}}function we(i){return 1<i.length?function(e,t,n){var r=i.length;while(r--)if(!i[r](e,t,n))return!1;return!0}:i[0]}function Te(e,t,n,r,i){for(var o,a=[],s=0,u=e.length,l=null!=t;s<u;s++)(o=e[s])&&(n&&!n(o,r,i)||(a.push(o),l&&t.push(s)));return a}function Ce(d,h,g,v,y,e){return v&&!v[k]&&(v=Ce(v)),y&&!y[k]&&(y=Ce(y,e)),le(function(e,t,n,r){var i,o,a,s=[],u=[],l=t.length,c=e||function(e,t,n){for(var r=0,i=t.length;r<i;r++)se(e,t[r],n);return n}(h||"*",n.nodeType?[n]:n,[]),f=!d||!e&&h?c:Te(c,s,d,n,r),p=g?y||(e?d:l||v)?[]:t:f;if(g&&g(f,p,n,r),v){i=Te(p,u),v(i,[],n,r),o=i.length;while(o--)(a=i[o])&&(p[u[o]]=!(f[u[o]]=a))}if(e){if(y||d){if(y){i=[],o=p.length;while(o--)(a=p[o])&&i.push(f[o]=a);y(null,p=[],i,r)}o=p.length;while(o--)(a=p[o])&&-1<(i=y?P(e,a):s[o])&&(e[i]=!(t[i]=a))}}else p=Te(p===t?p.splice(l,p.length):p),y?y(null,t,p,r):H.apply(t,p)})}function Ee(e){for(var i,t,n,r=e.length,o=b.relative[e[0].type],a=o||b.relative[" "],s=o?1:0,u=be(function(e){return e===i},a,!0),l=be(function(e){return-1<P(i,e)},a,!0),c=[function(e,t,n){var r=!o&&(n||t!==w)||((i=t).nodeType?u(e,t,n):l(e,t,n));return i=null,r}];s<r;s++)if(t=b.relative[e[s].type])c=[be(we(c),t)];else{if((t=b.filter[e[s].type].apply(null,e[s].matches))[k]){for(n=++s;n<r;n++)if(b.relative[e[n].type])break;return Ce(1<s&&we(c),1<s&&xe(e.slice(0,s-1).concat({value:" "===e[s-2].type?"*":""})).replace(B,"$1"),t,s<n&&Ee(e.slice(s,n)),n<r&&Ee(e=e.slice(n)),n<r&&xe(e))}c.push(t)}return we(c)}return me.prototype=b.filters=b.pseudos,b.setFilters=new me,h=se.tokenize=function(e,t){var n,r,i,o,a,s,u,l=x[e+" "];if(l)return t?0:l.slice(0);a=e,s=[],u=b.preFilter;while(a){for(o in n&&!(r=_.exec(a))||(r&&(a=a.slice(r[0].length)||a),s.push(i=[])),n=!1,(r=z.exec(a))&&(n=r.shift(),i.push({value:n,type:r[0].replace(B," ")}),a=a.slice(n.length)),b.filter)!(r=G[o].exec(a))||u[o]&&!(r=u[o](r))||(n=r.shift(),i.push({value:n,type:o,matches:r}),a=a.slice(n.length));if(!n)break}return t?a.length:a?se.error(e):x(e,s).slice(0)},f=se.compile=function(e,t){var n,v,y,m,x,r,i=[],o=[],a=N[e+" "];if(!a){t||(t=h(e)),n=t.length;while(n--)(a=Ee(t[n]))[k]?i.push(a):o.push(a);(a=N(e,(v=o,m=0<(y=i).length,x=0<v.length,r=function(e,t,n,r,i){var o,a,s,u=0,l="0",c=e&&[],f=[],p=w,d=e||x&&b.find.TAG("*",i),h=S+=null==p?1:Math.random()||.1,g=d.length;for(i&&(w=t===C||t||i);l!==g&&null!=(o=d[l]);l++){if(x&&o){a=0,t||o.ownerDocument===C||(T(o),n=!E);while(s=v[a++])if(s(o,t||C,n)){r.push(o);break}i&&(S=h)}m&&((o=!s&&o)&&u--,e&&c.push(o))}if(u+=l,m&&l!==u){a=0;while(s=y[a++])s(c,f,t,n);if(e){if(0<u)while(l--)c[l]||f[l]||(f[l]=q.call(r));f=Te(f)}H.apply(r,f),i&&!e&&0<f.length&&1<u+y.length&&se.uniqueSort(r)}return i&&(S=h,w=p),c},m?le(r):r))).selector=e}return a},g=se.select=function(e,t,n,r){var i,o,a,s,u,l="function"==typeof e&&e,c=!r&&h(e=l.selector||e);if(n=n||[],1===c.length){if(2<(o=c[0]=c[0].slice(0)).length&&"ID"===(a=o[0]).type&&9===t.nodeType&&E&&b.relative[o[1].type]){if(!(t=(b.find.ID(a.matches[0].replace(te,ne),t)||[])[0]))return n;l&&(t=t.parentNode),e=e.slice(o.shift().value.length)}i=G.needsContext.test(e)?0:o.length;while(i--){if(a=o[i],b.relative[s=a.type])break;if((u=b.find[s])&&(r=u(a.matches[0].replace(te,ne),ee.test(o[0].type)&&ye(t.parentNode)||t))){if(o.splice(i,1),!(e=r.length&&xe(o)))return H.apply(n,r),n;break}}}return(l||f(e,c))(r,t,!E,n,!t||ee.test(e)&&ye(t.parentNode)||t),n},d.sortStable=k.split("").sort(D).join("")===k,d.detectDuplicates=!!l,T(),d.sortDetached=ce(function(e){return 1&e.compareDocumentPosition(C.createElement("fieldset"))}),ce(function(e){return e.innerHTML="<a href='#'></a>","#"===e.firstChild.getAttribute("href")})||fe("type|href|height|width",function(e,t,n){if(!n)return e.getAttribute(t,"type"===t.toLowerCase()?1:2)}),d.attributes&&ce(function(e){return e.innerHTML="<input/>",e.firstChild.setAttribute("value",""),""===e.firstChild.getAttribute("value")})||fe("value",function(e,t,n){if(!n&&"input"===e.nodeName.toLowerCase())return e.defaultValue}),ce(function(e){return null==e.getAttribute("disabled")})||fe(R,function(e,t,n){var r;if(!n)return!0===e[t]?t.toLowerCase():(r=e.getAttributeNode(t))&&r.specified?r.value:null}),se}(C);k.find=h,k.expr=h.selectors,k.expr[":"]=k.expr.pseudos,k.uniqueSort=k.unique=h.uniqueSort,k.text=h.getText,k.isXMLDoc=h.isXML,k.contains=h.contains,k.escapeSelector=h.escape;var T=function(e,t,n){var r=[],i=void 0!==n;while((e=e[t])&&9!==e.nodeType)if(1===e.nodeType){if(i&&k(e).is(n))break;r.push(e)}return r},S=function(e,t){for(var n=[];e;e=e.nextSibling)1===e.nodeType&&e!==t&&n.push(e);return n},N=k.expr.match.needsContext;function A(e,t){return e.nodeName&&e.nodeName.toLowerCase()===t.toLowerCase()}var D=/^<([a-z][^\/\0>:\x20\t\r\n\f]*)[\x20\t\r\n\f]*\/?>(?:<\/\1>|)$/i;function j(e,n,r){return m(n)?k.grep(e,function(e,t){return!!n.call(e,t,e)!==r}):n.nodeType?k.grep(e,function(e){return e===n!==r}):"string"!=typeof n?k.grep(e,function(e){return-1<i.call(n,e)!==r}):k.filter(n,e,r)}k.filter=function(e,t,n){var r=t[0];return n&&(e=":not("+e+")"),1===t.length&&1===r.nodeType?k.find.matchesSelector(r,e)?[r]:[]:k.find.matches(e,k.grep(t,function(e){return 1===e.nodeType}))},k.fn.extend({find:function(e){var t,n,r=this.length,i=this;if("string"!=typeof e)return this.pushStack(k(e).filter(function(){for(t=0;t<r;t++)if(k.contains(i[t],this))return!0}));for(n=this.pushStack([]),t=0;t<r;t++)k.find(e,i[t],n);return 1<r?k.uniqueSort(n):n},filter:function(e){return this.pushStack(j(this,e||[],!1))},not:function(e){return this.pushStack(j(this,e||[],!0))},is:function(e){return!!j(this,"string"==typeof e&&N.test(e)?k(e):e||[],!1).length}});var q,L=/^(?:\s*(<[\w\W]+>)[^>]*|#([\w-]+))$/;(k.fn.init=function(e,t,n){var r,i;if(!e)return this;if(n=n||q,"string"==typeof e){if(!(r="<"===e[0]&&">"===e[e.length-1]&&3<=e.length?[null,e,null]:L.exec(e))||!r[1]&&t)return!t||t.jquery?(t||n).find(e):this.constructor(t).find(e);if(r[1]){if(t=t instanceof k?t[0]:t,k.merge(this,k.parseHTML(r[1],t&&t.nodeType?t.ownerDocument||t:E,!0)),D.test(r[1])&&k.isPlainObject(t))for(r in t)m(this[r])?this[r](t[r]):this.attr(r,t[r]);return this}return(i=E.getElementById(r[2]))&&(this[0]=i,this.length=1),this}return e.nodeType?(this[0]=e,this.length=1,this):m(e)?void 0!==n.ready?n.ready(e):e(k):k.makeArray(e,this)}).prototype=k.fn,q=k(E);var H=/^(?:parents|prev(?:Until|All))/,O={children:!0,contents:!0,next:!0,prev:!0};function P(e,t){while((e=e[t])&&1!==e.nodeType);return e}k.fn.extend({has:function(e){var t=k(e,this),n=t.length;return this.filter(function(){for(var e=0;e<n;e++)if(k.contains(this,t[e]))return!0})},closest:function(e,t){var n,r=0,i=this.length,o=[],a="string"!=typeof e&&k(e);if(!N.test(e))for(;r<i;r++)for(n=this[r];n&&n!==t;n=n.parentNode)if(n.nodeType<11&&(a?-1<a.index(n):1===n.nodeType&&k.find.matchesSelector(n,e))){o.push(n);break}return this.pushStack(1<o.length?k.uniqueSort(o):o)},index:function(e){return e?"string"==typeof e?i.call(k(e),this[0]):i.call(this,e.jquery?e[0]:e):this[0]&&this[0].parentNode?this.first().prevAll().length:-1},add:function(e,t){return this.pushStack(k.uniqueSort(k.merge(this.get(),k(e,t))))},addBack:function(e){return this.add(null==e?this.prevObject:this.prevObject.filter(e))}}),k.each({parent:function(e){var t=e.parentNode;return t&&11!==t.nodeType?t:null},parents:function(e){return T(e,"parentNode")},parentsUntil:function(e,t,n){return T(e,"parentNode",n)},next:function(e){return P(e,"nextSibling")},prev:function(e){return P(e,"previousSibling")},nextAll:function(e){return T(e,"nextSibling")},prevAll:function(e){return T(e,"previousSibling")},nextUntil:function(e,t,n){return T(e,"nextSibling",n)},prevUntil:function(e,t,n){return T(e,"previousSibling",n)},siblings:function(e){return S((e.parentNode||{}).firstChild,e)},children:function(e){return S(e.firstChild)},contents:function(e){return"undefined"!=typeof e.contentDocument?e.contentDocument:(A(e,"template")&&(e=e.content||e),k.merge([],e.childNodes))}},function(r,i){k.fn[r]=function(e,t){var n=k.map(this,i,e);return"Until"!==r.slice(-5)&&(t=e),t&&"string"==typeof t&&(n=k.filter(t,n)),1<this.length&&(O[r]||k.uniqueSort(n),H.test(r)&&n.reverse()),this.pushStack(n)}});var R=/[^\x20\t\r\n\f]+/g;function M(e){return e}function I(e){throw e}function W(e,t,n,r){var i;try{e&&m(i=e.promise)?i.call(e).done(t).fail(n):e&&m(i=e.then)?i.call(e,t,n):t.apply(void 0,[e].slice(r))}catch(e){n.apply(void 0,[e])}}k.Callbacks=function(r){var e,n;r="string"==typeof r?(e=r,n={},k.each(e.match(R)||[],function(e,t){n[t]=!0}),n):k.extend({},r);var i,t,o,a,s=[],u=[],l=-1,c=function(){for(a=a||r.once,o=i=!0;u.length;l=-1){t=u.shift();while(++l<s.length)!1===s[l].apply(t[0],t[1])&&r.stopOnFalse&&(l=s.length,t=!1)}r.memory||(t=!1),i=!1,a&&(s=t?[]:"")},f={add:function(){return s&&(t&&!i&&(l=s.length-1,u.push(t)),function n(e){k.each(e,function(e,t){m(t)?r.unique&&f.has(t)||s.push(t):t&&t.length&&"string"!==w(t)&&n(t)})}(arguments),t&&!i&&c()),this},remove:function(){return k.each(arguments,function(e,t){var n;while(-1<(n=k.inArray(t,s,n)))s.splice(n,1),n<=l&&l--}),this},has:function(e){return e?-1<k.inArray(e,s):0<s.length},empty:function(){return s&&(s=[]),this},disable:function(){return a=u=[],s=t="",this},disabled:function(){return!s},lock:function(){return a=u=[],t||i||(s=t=""),this},locked:function(){return!!a},fireWith:function(e,t){return a||(t=[e,(t=t||[]).slice?t.slice():t],u.push(t),i||c()),this},fire:function(){return f.fireWith(this,arguments),this},fired:function(){return!!o}};return f},k.extend({Deferred:function(e){var o=[["notify","progress",k.Callbacks("memory"),k.Callbacks("memory"),2],["resolve","done",k.Callbacks("once memory"),k.Callbacks("once memory"),0,"resolved"],["reject","fail",k.Callbacks("once memory"),k.Callbacks("once memory"),1,"rejected"]],i="pending",a={state:function(){return i},always:function(){return s.done(arguments).fail(arguments),this},"catch":function(e){return a.then(null,e)},pipe:function(){var i=arguments;return k.Deferred(function(r){k.each(o,function(e,t){var n=m(i[t[4]])&&i[t[4]];s[t[1]](function(){var e=n&&n.apply(this,arguments);e&&m(e.promise)?e.promise().progress(r.notify).done(r.resolve).fail(r.reject):r[t[0]+"With"](this,n?[e]:arguments)})}),i=null}).promise()},then:function(t,n,r){var u=0;function l(i,o,a,s){return function(){var n=this,r=arguments,e=function(){var e,t;if(!(i<u)){if((e=a.apply(n,r))===o.promise())throw new TypeError("Thenable self-resolution");t=e&&("object"==typeof e||"function"==typeof e)&&e.then,m(t)?s?t.call(e,l(u,o,M,s),l(u,o,I,s)):(u++,t.call(e,l(u,o,M,s),l(u,o,I,s),l(u,o,M,o.notifyWith))):(a!==M&&(n=void 0,r=[e]),(s||o.resolveWith)(n,r))}},t=s?e:function(){try{e()}catch(e){k.Deferred.exceptionHook&&k.Deferred.exceptionHook(e,t.stackTrace),u<=i+1&&(a!==I&&(n=void 0,r=[e]),o.rejectWith(n,r))}};i?t():(k.Deferred.getStackHook&&(t.stackTrace=k.Deferred.getStackHook()),C.setTimeout(t))}}return k.Deferred(function(e){o[0][3].add(l(0,e,m(r)?r:M,e.notifyWith)),o[1][3].add(l(0,e,m(t)?t:M)),o[2][3].add(l(0,e,m(n)?n:I))}).promise()},promise:function(e){return null!=e?k.extend(e,a):a}},s={};return k.each(o,function(e,t){var n=t[2],r=t[5];a[t[1]]=n.add,r&&n.add(function(){i=r},o[3-e][2].disable,o[3-e][3].disable,o[0][2].lock,o[0][3].lock),n.add(t[3].fire),s[t[0]]=function(){return s[t[0]+"With"](this===s?void 0:this,arguments),this},s[t[0]+"With"]=n.fireWith}),a.promise(s),e&&e.call(s,s),s},when:function(e){var n=arguments.length,t=n,r=Array(t),i=s.call(arguments),o=k.Deferred(),a=function(t){return function(e){r[t]=this,i[t]=1<arguments.length?s.call(arguments):e,--n||o.resolveWith(r,i)}};if(n<=1&&(W(e,o.done(a(t)).resolve,o.reject,!n),"pending"===o.state()||m(i[t]&&i[t].then)))return o.then();while(t--)W(i[t],a(t),o.reject);return o.promise()}});var $=/^(Eval|Internal|Range|Reference|Syntax|Type|URI)Error$/;k.Deferred.exceptionHook=function(e,t){C.console&&C.console.warn&&e&&$.test(e.name)&&C.console.warn("jQuery.Deferred exception: "+e.message,e.stack,t)},k.readyException=function(e){C.setTimeout(function(){throw e})};var F=k.Deferred();function B(){E.removeEventListener("DOMContentLoaded",B),C.removeEventListener("load",B),k.ready()}k.fn.ready=function(e){return F.then(e)["catch"](function(e){k.readyException(e)}),this},k.extend({isReady:!1,readyWait:1,ready:function(e){(!0===e?--k.readyWait:k.isReady)||(k.isReady=!0)!==e&&0<--k.readyWait||F.resolveWith(E,[k])}}),k.ready.then=F.then,"complete"===E.readyState||"loading"!==E.readyState&&!E.documentElement.doScroll?C.setTimeout(k.ready):(E.addEventListener("DOMContentLoaded",B),C.addEventListener("load",B));var _=function(e,t,n,r,i,o,a){var s=0,u=e.length,l=null==n;if("object"===w(n))for(s in i=!0,n)_(e,t,s,n[s],!0,o,a);else if(void 0!==r&&(i=!0,m(r)||(a=!0),l&&(a?(t.call(e,r),t=null):(l=t,t=function(e,t,n){return l.call(k(e),n)})),t))for(;s<u;s++)t(e[s],n,a?r:r.call(e[s],s,t(e[s],n)));return i?e:l?t.call(e):u?t(e[0],n):o},z=/^-ms-/,U=/-([a-z])/g;function X(e,t){return t.toUpperCase()}function V(e){return e.replace(z,"ms-").replace(U,X)}var G=function(e){return 1===e.nodeType||9===e.nodeType||!+e.nodeType};function Y(){this.expando=k.expando+Y.uid++}Y.uid=1,Y.prototype={cache:function(e){var t=e[this.expando];return t||(t={},G(e)&&(e.nodeType?e[this.expando]=t:Object.defineProperty(e,this.expando,{value:t,configurable:!0}))),t},set:function(e,t,n){var r,i=this.cache(e);if("string"==typeof t)i[V(t)]=n;else for(r in t)i[V(r)]=t[r];return i},get:function(e,t){return void 0===t?this.cache(e):e[this.expando]&&e[this.expando][V(t)]},access:function(e,t,n){return void 0===t||t&&"string"==typeof t&&void 0===n?this.get(e,t):(this.set(e,t,n),void 0!==n?n:t)},remove:function(e,t){var n,r=e[this.expando];if(void 0!==r){if(void 0!==t){n=(t=Array.isArray(t)?t.map(V):(t=V(t))in r?[t]:t.match(R)||[]).length;while(n--)delete r[t[n]]}(void 0===t||k.isEmptyObject(r))&&(e.nodeType?e[this.expando]=void 0:delete e[this.expando])}},hasData:function(e){var t=e[this.expando];return void 0!==t&&!k.isEmptyObject(t)}};var Q=new Y,J=new Y,K=/^(?:\{[\w\W]*\}|\[[\w\W]*\])$/,Z=/[A-Z]/g;function ee(e,t,n){var r,i;if(void 0===n&&1===e.nodeType)if(r="data-"+t.replace(Z,"-$&").toLowerCase(),"string"==typeof(n=e.getAttribute(r))){try{n="true"===(i=n)||"false"!==i&&("null"===i?null:i===+i+""?+i:K.test(i)?JSON.parse(i):i)}catch(e){}J.set(e,t,n)}else n=void 0;return n}k.extend({hasData:function(e){return J.hasData(e)||Q.hasData(e)},data:function(e,t,n){return J.access(e,t,n)},removeData:function(e,t){J.remove(e,t)},_data:function(e,t,n){return Q.access(e,t,n)},_removeData:function(e,t){Q.remove(e,t)}}),k.fn.extend({data:function(n,e){var t,r,i,o=this[0],a=o&&o.attributes;if(void 0===n){if(this.length&&(i=J.get(o),1===o.nodeType&&!Q.get(o,"hasDataAttrs"))){t=a.length;while(t--)a[t]&&0===(r=a[t].name).indexOf("data-")&&(r=V(r.slice(5)),ee(o,r,i[r]));Q.set(o,"hasDataAttrs",!0)}return i}return"object"==typeof n?this.each(function(){J.set(this,n)}):_(this,function(e){var t;if(o&&void 0===e)return void 0!==(t=J.get(o,n))?t:void 0!==(t=ee(o,n))?t:void 0;this.each(function(){J.set(this,n,e)})},null,e,1<arguments.length,null,!0)},removeData:function(e){return this.each(function(){J.remove(this,e)})}}),k.extend({queue:function(e,t,n){var r;if(e)return t=(t||"fx")+"queue",r=Q.get(e,t),n&&(!r||Array.isArray(n)?r=Q.access(e,t,k.makeArray(n)):r.push(n)),r||[]},dequeue:function(e,t){t=t||"fx";var n=k.queue(e,t),r=n.length,i=n.shift(),o=k._queueHooks(e,t);"inprogress"===i&&(i=n.shift(),r--),i&&("fx"===t&&n.unshift("inprogress"),delete o.stop,i.call(e,function(){k.dequeue(e,t)},o)),!r&&o&&o.empty.fire()},_queueHooks:function(e,t){var n=t+"queueHooks";return Q.get(e,n)||Q.access(e,n,{empty:k.Callbacks("once memory").add(function(){Q.remove(e,[t+"queue",n])})})}}),k.fn.extend({queue:function(t,n){var e=2;return"string"!=typeof t&&(n=t,t="fx",e--),arguments.length<e?k.queue(this[0],t):void 0===n?this:this.each(function(){var e=k.queue(this,t,n);k._queueHooks(this,t),"fx"===t&&"inprogress"!==e[0]&&k.dequeue(this,t)})},dequeue:function(e){return this.each(function(){k.dequeue(this,e)})},clearQueue:function(e){return this.queue(e||"fx",[])},promise:function(e,t){var n,r=1,i=k.Deferred(),o=this,a=this.length,s=function(){--r||i.resolveWith(o,[o])};"string"!=typeof e&&(t=e,e=void 0),e=e||"fx";while(a--)(n=Q.get(o[a],e+"queueHooks"))&&n.empty&&(r++,n.empty.add(s));return s(),i.promise(t)}});var te=/[+-]?(?:\d*\.|)\d+(?:[eE][+-]?\d+|)/.source,ne=new RegExp("^(?:([+-])=|)("+te+")([a-z%]*)$","i"),re=["Top","Right","Bottom","Left"],ie=E.documentElement,oe=function(e){return k.contains(e.ownerDocument,e)},ae={composed:!0};ie.getRootNode&&(oe=function(e){return k.contains(e.ownerDocument,e)||e.getRootNode(ae)===e.ownerDocument});var se=function(e,t){return"none"===(e=t||e).style.display||""===e.style.display&&oe(e)&&"none"===k.css(e,"display")},ue=function(e,t,n,r){var i,o,a={};for(o in t)a[o]=e.style[o],e.style[o]=t[o];for(o in i=n.apply(e,r||[]),t)e.style[o]=a[o];return i};function le(e,t,n,r){var i,o,a=20,s=r?function(){return r.cur()}:function(){return k.css(e,t,"")},u=s(),l=n&&n[3]||(k.cssNumber[t]?"":"px"),c=e.nodeType&&(k.cssNumber[t]||"px"!==l&&+u)&&ne.exec(k.css(e,t));if(c&&c[3]!==l){u/=2,l=l||c[3],c=+u||1;while(a--)k.style(e,t,c+l),(1-o)*(1-(o=s()/u||.5))<=0&&(a=0),c/=o;c*=2,k.style(e,t,c+l),n=n||[]}return n&&(c=+c||+u||0,i=n[1]?c+(n[1]+1)*n[2]:+n[2],r&&(r.unit=l,r.start=c,r.end=i)),i}var ce={};function fe(e,t){for(var n,r,i,o,a,s,u,l=[],c=0,f=e.length;c<f;c++)(r=e[c]).style&&(n=r.style.display,t?("none"===n&&(l[c]=Q.get(r,"display")||null,l[c]||(r.style.display="")),""===r.style.display&&se(r)&&(l[c]=(u=a=o=void 0,a=(i=r).ownerDocument,s=i.nodeName,(u=ce[s])||(o=a.body.appendChild(a.createElement(s)),u=k.css(o,"display"),o.parentNode.removeChild(o),"none"===u&&(u="block"),ce[s]=u)))):"none"!==n&&(l[c]="none",Q.set(r,"display",n)));for(c=0;c<f;c++)null!=l[c]&&(e[c].style.display=l[c]);return e}k.fn.extend({show:function(){return fe(this,!0)},hide:function(){return fe(this)},toggle:function(e){return"boolean"==typeof e?e?this.show():this.hide():this.each(function(){se(this)?k(this).show():k(this).hide()})}});var pe=/^(?:checkbox|radio)$/i,de=/<([a-z][^\/\0>\x20\t\r\n\f]*)/i,he=/^$|^module$|\/(?:java|ecma)script/i,ge={option:[1,"<select multiple='multiple'>","</select>"],thead:[1,"<table>","</table>"],col:[2,"<table><colgroup>","</colgroup></table>"],tr:[2,"<table><tbody>","</tbody></table>"],td:[3,"<table><tbody><tr>","</tr></tbody></table>"],_default:[0,"",""]};function ve(e,t){var n;return n="undefined"!=typeof e.getElementsByTagName?e.getElementsByTagName(t||"*"):"undefined"!=typeof e.querySelectorAll?e.querySelectorAll(t||"*"):[],void 0===t||t&&A(e,t)?k.merge([e],n):n}function ye(e,t){for(var n=0,r=e.length;n<r;n++)Q.set(e[n],"globalEval",!t||Q.get(t[n],"globalEval"))}ge.optgroup=ge.option,ge.tbody=ge.tfoot=ge.colgroup=ge.caption=ge.thead,ge.th=ge.td;var me,xe,be=/<|&#?\w+;/;function we(e,t,n,r,i){for(var o,a,s,u,l,c,f=t.createDocumentFragment(),p=[],d=0,h=e.length;d<h;d++)if((o=e[d])||0===o)if("object"===w(o))k.merge(p,o.nodeType?[o]:o);else if(be.test(o)){a=a||f.appendChild(t.createElement("div")),s=(de.exec(o)||["",""])[1].toLowerCase(),u=ge[s]||ge._default,a.innerHTML=u[1]+k.htmlPrefilter(o)+u[2],c=u[0];while(c--)a=a.lastChild;k.merge(p,a.childNodes),(a=f.firstChild).textContent=""}else p.push(t.createTextNode(o));f.textContent="",d=0;while(o=p[d++])if(r&&-1<k.inArray(o,r))i&&i.push(o);else if(l=oe(o),a=ve(f.appendChild(o),"script"),l&&ye(a),n){c=0;while(o=a[c++])he.test(o.type||"")&&n.push(o)}return f}me=E.createDocumentFragment().appendChild(E.createElement("div")),(xe=E.createElement("input")).setAttribute("type","radio"),xe.setAttribute("checked","checked"),xe.setAttribute("name","t"),me.appendChild(xe),y.checkClone=me.cloneNode(!0).cloneNode(!0).lastChild.checked,me.innerHTML="<textarea>x</textarea>",y.noCloneChecked=!!me.cloneNode(!0).lastChild.defaultValue;var Te=/^key/,Ce=/^(?:mouse|pointer|contextmenu|drag|drop)|click/,Ee=/^([^.]*)(?:\.(.+)|)/;function ke(){return!0}function Se(){return!1}function Ne(e,t){return e===function(){try{return E.activeElement}catch(e){}}()==("focus"===t)}function Ae(e,t,n,r,i,o){var a,s;if("object"==typeof t){for(s in"string"!=typeof n&&(r=r||n,n=void 0),t)Ae(e,s,n,r,t[s],o);return e}if(null==r&&null==i?(i=n,r=n=void 0):null==i&&("string"==typeof n?(i=r,r=void 0):(i=r,r=n,n=void 0)),!1===i)i=Se;else if(!i)return e;return 1===o&&(a=i,(i=function(e){return k().off(e),a.apply(this,arguments)}).guid=a.guid||(a.guid=k.guid++)),e.each(function(){k.event.add(this,t,i,r,n)})}function De(e,i,o){o?(Q.set(e,i,!1),k.event.add(e,i,{namespace:!1,handler:function(e){var t,n,r=Q.get(this,i);if(1&e.isTrigger&&this[i]){if(r.length)(k.event.special[i]||{}).delegateType&&e.stopPropagation();else if(r=s.call(arguments),Q.set(this,i,r),t=o(this,i),this[i](),r!==(n=Q.get(this,i))||t?Q.set(this,i,!1):n={},r!==n)return e.stopImmediatePropagation(),e.preventDefault(),n.value}else r.length&&(Q.set(this,i,{value:k.event.trigger(k.extend(r[0],k.Event.prototype),r.slice(1),this)}),e.stopImmediatePropagation())}})):void 0===Q.get(e,i)&&k.event.add(e,i,ke)}k.event={global:{},add:function(t,e,n,r,i){var o,a,s,u,l,c,f,p,d,h,g,v=Q.get(t);if(v){n.handler&&(n=(o=n).handler,i=o.selector),i&&k.find.matchesSelector(ie,i),n.guid||(n.guid=k.guid++),(u=v.events)||(u=v.events={}),(a=v.handle)||(a=v.handle=function(e){return"undefined"!=typeof k&&k.event.triggered!==e.type?k.event.dispatch.apply(t,arguments):void 0}),l=(e=(e||"").match(R)||[""]).length;while(l--)d=g=(s=Ee.exec(e[l])||[])[1],h=(s[2]||"").split(".").sort(),d&&(f=k.event.special[d]||{},d=(i?f.delegateType:f.bindType)||d,f=k.event.special[d]||{},c=k.extend({type:d,origType:g,data:r,handler:n,guid:n.guid,selector:i,needsContext:i&&k.expr.match.needsContext.test(i),namespace:h.join(".")},o),(p=u[d])||((p=u[d]=[]).delegateCount=0,f.setup&&!1!==f.setup.call(t,r,h,a)||t.addEventListener&&t.addEventListener(d,a)),f.add&&(f.add.call(t,c),c.handler.guid||(c.handler.guid=n.guid)),i?p.splice(p.delegateCount++,0,c):p.push(c),k.event.global[d]=!0)}},remove:function(e,t,n,r,i){var o,a,s,u,l,c,f,p,d,h,g,v=Q.hasData(e)&&Q.get(e);if(v&&(u=v.events)){l=(t=(t||"").match(R)||[""]).length;while(l--)if(d=g=(s=Ee.exec(t[l])||[])[1],h=(s[2]||"").split(".").sort(),d){f=k.event.special[d]||{},p=u[d=(r?f.delegateType:f.bindType)||d]||[],s=s[2]&&new RegExp("(^|\\.)"+h.join("\\.(?:.*\\.|)")+"(\\.|$)"),a=o=p.length;while(o--)c=p[o],!i&&g!==c.origType||n&&n.guid!==c.guid||s&&!s.test(c.namespace)||r&&r!==c.selector&&("**"!==r||!c.selector)||(p.splice(o,1),c.selector&&p.delegateCount--,f.remove&&f.remove.call(e,c));a&&!p.length&&(f.teardown&&!1!==f.teardown.call(e,h,v.handle)||k.removeEvent(e,d,v.handle),delete u[d])}else for(d in u)k.event.remove(e,d+t[l],n,r,!0);k.isEmptyObject(u)&&Q.remove(e,"handle events")}},dispatch:function(e){var t,n,r,i,o,a,s=k.event.fix(e),u=new Array(arguments.length),l=(Q.get(this,"events")||{})[s.type]||[],c=k.event.special[s.type]||{};for(u[0]=s,t=1;t<arguments.length;t++)u[t]=arguments[t];if(s.delegateTarget=this,!c.preDispatch||!1!==c.preDispatch.call(this,s)){a=k.event.handlers.call(this,s,l),t=0;while((i=a[t++])&&!s.isPropagationStopped()){s.currentTarget=i.elem,n=0;while((o=i.handlers[n++])&&!s.isImmediatePropagationStopped())s.rnamespace&&!1!==o.namespace&&!s.rnamespace.test(o.namespace)||(s.handleObj=o,s.data=o.data,void 0!==(r=((k.event.special[o.origType]||{}).handle||o.handler).apply(i.elem,u))&&!1===(s.result=r)&&(s.preventDefault(),s.stopPropagation()))}return c.postDispatch&&c.postDispatch.call(this,s),s.result}},handlers:function(e,t){var n,r,i,o,a,s=[],u=t.delegateCount,l=e.target;if(u&&l.nodeType&&!("click"===e.type&&1<=e.button))for(;l!==this;l=l.parentNode||this)if(1===l.nodeType&&("click"!==e.type||!0!==l.disabled)){for(o=[],a={},n=0;n<u;n++)void 0===a[i=(r=t[n]).selector+" "]&&(a[i]=r.needsContext?-1<k(i,this).index(l):k.find(i,this,null,[l]).length),a[i]&&o.push(r);o.length&&s.push({elem:l,handlers:o})}return l=this,u<t.length&&s.push({elem:l,handlers:t.slice(u)}),s},addProp:function(t,e){Object.defineProperty(k.Event.prototype,t,{enumerable:!0,configurable:!0,get:m(e)?function(){if(this.originalEvent)return e(this.originalEvent)}:function(){if(this.originalEvent)return this.originalEvent[t]},set:function(e){Object.defineProperty(this,t,{enumerable:!0,configurable:!0,writable:!0,value:e})}})},fix:function(e){return e[k.expando]?e:new k.Event(e)},special:{load:{noBubble:!0},click:{setup:function(e){var t=this||e;return pe.test(t.type)&&t.click&&A(t,"input")&&De(t,"click",ke),!1},trigger:function(e){var t=this||e;return pe.test(t.type)&&t.click&&A(t,"input")&&De(t,"click"),!0},_default:function(e){var t=e.target;return pe.test(t.type)&&t.click&&A(t,"input")&&Q.get(t,"click")||A(t,"a")}},beforeunload:{postDispatch:function(e){void 0!==e.result&&e.originalEvent&&(e.originalEvent.returnValue=e.result)}}}},k.removeEvent=function(e,t,n){e.removeEventListener&&e.removeEventListener(t,n)},k.Event=function(e,t){if(!(this instanceof k.Event))return new k.Event(e,t);e&&e.type?(this.originalEvent=e,this.type=e.type,this.isDefaultPrevented=e.defaultPrevented||void 0===e.defaultPrevented&&!1===e.returnValue?ke:Se,this.target=e.target&&3===e.target.nodeType?e.target.parentNode:e.target,this.currentTarget=e.currentTarget,this.relatedTarget=e.relatedTarget):this.type=e,t&&k.extend(this,t),this.timeStamp=e&&e.timeStamp||Date.now(),this[k.expando]=!0},k.Event.prototype={constructor:k.Event,isDefaultPrevented:Se,isPropagationStopped:Se,isImmediatePropagationStopped:Se,isSimulated:!1,preventDefault:function(){var e=this.originalEvent;this.isDefaultPrevented=ke,e&&!this.isSimulated&&e.preventDefault()},stopPropagation:function(){var e=this.originalEvent;this.isPropagationStopped=ke,e&&!this.isSimulated&&e.stopPropagation()},stopImmediatePropagation:function(){var e=this.originalEvent;this.isImmediatePropagationStopped=ke,e&&!this.isSimulated&&e.stopImmediatePropagation(),this.stopPropagation()}},k.each({altKey:!0,bubbles:!0,cancelable:!0,changedTouches:!0,ctrlKey:!0,detail:!0,eventPhase:!0,metaKey:!0,pageX:!0,pageY:!0,shiftKey:!0,view:!0,"char":!0,code:!0,charCode:!0,key:!0,keyCode:!0,button:!0,buttons:!0,clientX:!0,clientY:!0,offsetX:!0,offsetY:!0,pointerId:!0,pointerType:!0,screenX:!0,screenY:!0,targetTouches:!0,toElement:!0,touches:!0,which:function(e){var t=e.button;return null==e.which&&Te.test(e.type)?null!=e.charCode?e.charCode:e.keyCode:!e.which&&void 0!==t&&Ce.test(e.type)?1&t?1:2&t?3:4&t?2:0:e.which}},k.event.addProp),k.each({focus:"focusin",blur:"focusout"},function(e,t){k.event.special[e]={setup:function(){return De(this,e,Ne),!1},trigger:function(){return De(this,e),!0},delegateType:t}}),k.each({mouseenter:"mouseover",mouseleave:"mouseout",pointerenter:"pointerover",pointerleave:"pointerout"},function(e,i){k.event.special[e]={delegateType:i,bindType:i,handle:function(e){var t,n=e.relatedTarget,r=e.handleObj;return n&&(n===this||k.contains(this,n))||(e.type=r.origType,t=r.handler.apply(this,arguments),e.type=i),t}}}),k.fn.extend({on:function(e,t,n,r){return Ae(this,e,t,n,r)},one:function(e,t,n,r){return Ae(this,e,t,n,r,1)},off:function(e,t,n){var r,i;if(e&&e.preventDefault&&e.handleObj)return r=e.handleObj,k(e.delegateTarget).off(r.namespace?r.origType+"."+r.namespace:r.origType,r.selector,r.handler),this;if("object"==typeof e){for(i in e)this.off(i,t,e[i]);return this}return!1!==t&&"function"!=typeof t||(n=t,t=void 0),!1===n&&(n=Se),this.each(function(){k.event.remove(this,e,n,t)})}});var je=/<(?!area|br|col|embed|hr|img|input|link|meta|param)(([a-z][^\/\0>\x20\t\r\n\f]*)[^>]*)\/>/gi,qe=/<script|<style|<link/i,Le=/checked\s*(?:[^=]|=\s*.checked.)/i,He=/^\s*<!(?:\[CDATA\[|--)|(?:\]\]|--)>\s*$/g;function Oe(e,t){return A(e,"table")&&A(11!==t.nodeType?t:t.firstChild,"tr")&&k(e).children("tbody")[0]||e}function Pe(e){return e.type=(null!==e.getAttribute("type"))+"/"+e.type,e}function Re(e){return"true/"===(e.type||"").slice(0,5)?e.type=e.type.slice(5):e.removeAttribute("type"),e}function Me(e,t){var n,r,i,o,a,s,u,l;if(1===t.nodeType){if(Q.hasData(e)&&(o=Q.access(e),a=Q.set(t,o),l=o.events))for(i in delete a.handle,a.events={},l)for(n=0,r=l[i].length;n<r;n++)k.event.add(t,i,l[i][n]);J.hasData(e)&&(s=J.access(e),u=k.extend({},s),J.set(t,u))}}function Ie(n,r,i,o){r=g.apply([],r);var e,t,a,s,u,l,c=0,f=n.length,p=f-1,d=r[0],h=m(d);if(h||1<f&&"string"==typeof d&&!y.checkClone&&Le.test(d))return n.each(function(e){var t=n.eq(e);h&&(r[0]=d.call(this,e,t.html())),Ie(t,r,i,o)});if(f&&(t=(e=we(r,n[0].ownerDocument,!1,n,o)).firstChild,1===e.childNodes.length&&(e=t),t||o)){for(s=(a=k.map(ve(e,"script"),Pe)).length;c<f;c++)u=e,c!==p&&(u=k.clone(u,!0,!0),s&&k.merge(a,ve(u,"script"))),i.call(n[c],u,c);if(s)for(l=a[a.length-1].ownerDocument,k.map(a,Re),c=0;c<s;c++)u=a[c],he.test(u.type||"")&&!Q.access(u,"globalEval")&&k.contains(l,u)&&(u.src&&"module"!==(u.type||"").toLowerCase()?k._evalUrl&&!u.noModule&&k._evalUrl(u.src,{nonce:u.nonce||u.getAttribute("nonce")}):b(u.textContent.replace(He,""),u,l))}return n}function We(e,t,n){for(var r,i=t?k.filter(t,e):e,o=0;null!=(r=i[o]);o++)n||1!==r.nodeType||k.cleanData(ve(r)),r.parentNode&&(n&&oe(r)&&ye(ve(r,"script")),r.parentNode.removeChild(r));return e}k.extend({htmlPrefilter:function(e){return e.replace(je,"<$1></$2>")},clone:function(e,t,n){var r,i,o,a,s,u,l,c=e.cloneNode(!0),f=oe(e);if(!(y.noCloneChecked||1!==e.nodeType&&11!==e.nodeType||k.isXMLDoc(e)))for(a=ve(c),r=0,i=(o=ve(e)).length;r<i;r++)s=o[r],u=a[r],void 0,"input"===(l=u.nodeName.toLowerCase())&&pe.test(s.type)?u.checked=s.checked:"input"!==l&&"textarea"!==l||(u.defaultValue=s.defaultValue);if(t)if(n)for(o=o||ve(e),a=a||ve(c),r=0,i=o.length;r<i;r++)Me(o[r],a[r]);else Me(e,c);return 0<(a=ve(c,"script")).length&&ye(a,!f&&ve(e,"script")),c},cleanData:function(e){for(var t,n,r,i=k.event.special,o=0;void 0!==(n=e[o]);o++)if(G(n)){if(t=n[Q.expando]){if(t.events)for(r in t.events)i[r]?k.event.remove(n,r):k.removeEvent(n,r,t.handle);n[Q.expando]=void 0}n[J.expando]&&(n[J.expando]=void 0)}}}),k.fn.extend({detach:function(e){return We(this,e,!0)},remove:function(e){return We(this,e)},text:function(e){return _(this,function(e){return void 0===e?k.text(this):this.empty().each(function(){1!==this.nodeType&&11!==this.nodeType&&9!==this.nodeType||(this.textContent=e)})},null,e,arguments.length)},append:function(){return Ie(this,arguments,function(e){1!==this.nodeType&&11!==this.nodeType&&9!==this.nodeType||Oe(this,e).appendChild(e)})},prepend:function(){return Ie(this,arguments,function(e){if(1===this.nodeType||11===this.nodeType||9===this.nodeType){var t=Oe(this,e);t.insertBefore(e,t.firstChild)}})},before:function(){return Ie(this,arguments,function(e){this.parentNode&&this.parentNode.insertBefore(e,this)})},after:function(){return Ie(this,arguments,function(e){this.parentNode&&this.parentNode.insertBefore(e,this.nextSibling)})},empty:function(){for(var e,t=0;null!=(e=this[t]);t++)1===e.nodeType&&(k.cleanData(ve(e,!1)),e.textContent="");return this},clone:function(e,t){return e=null!=e&&e,t=null==t?e:t,this.map(function(){return k.clone(this,e,t)})},html:function(e){return _(this,function(e){var t=this[0]||{},n=0,r=this.length;if(void 0===e&&1===t.nodeType)return t.innerHTML;if("string"==typeof e&&!qe.test(e)&&!ge[(de.exec(e)||["",""])[1].toLowerCase()]){e=k.htmlPrefilter(e);try{for(;n<r;n++)1===(t=this[n]||{}).nodeType&&(k.cleanData(ve(t,!1)),t.innerHTML=e);t=0}catch(e){}}t&&this.empty().append(e)},null,e,arguments.length)},replaceWith:function(){var n=[];return Ie(this,arguments,function(e){var t=this.parentNode;k.inArray(this,n)<0&&(k.cleanData(ve(this)),t&&t.replaceChild(e,this))},n)}}),k.each({appendTo:"append",prependTo:"prepend",insertBefore:"before",insertAfter:"after",replaceAll:"replaceWith"},function(e,a){k.fn[e]=function(e){for(var t,n=[],r=k(e),i=r.length-1,o=0;o<=i;o++)t=o===i?this:this.clone(!0),k(r[o])[a](t),u.apply(n,t.get());return this.pushStack(n)}});var $e=new RegExp("^("+te+")(?!px)[a-z%]+$","i"),Fe=function(e){var t=e.ownerDocument.defaultView;return t&&t.opener||(t=C),t.getComputedStyle(e)},Be=new RegExp(re.join("|"),"i");function _e(e,t,n){var r,i,o,a,s=e.style;return(n=n||Fe(e))&&(""!==(a=n.getPropertyValue(t)||n[t])||oe(e)||(a=k.style(e,t)),!y.pixelBoxStyles()&&$e.test(a)&&Be.test(t)&&(r=s.width,i=s.minWidth,o=s.maxWidth,s.minWidth=s.maxWidth=s.width=a,a=n.width,s.width=r,s.minWidth=i,s.maxWidth=o)),void 0!==a?a+"":a}function ze(e,t){return{get:function(){if(!e())return(this.get=t).apply(this,arguments);delete this.get}}}!function(){function e(){if(u){s.style.cssText="position:absolute;left:-11111px;width:60px;margin-top:1px;padding:0;border:0",u.style.cssText="position:relative;display:block;box-sizing:border-box;overflow:scroll;margin:auto;border:1px;padding:1px;width:60%;top:1%",ie.appendChild(s).appendChild(u);var e=C.getComputedStyle(u);n="1%"!==e.top,a=12===t(e.marginLeft),u.style.right="60%",o=36===t(e.right),r=36===t(e.width),u.style.position="absolute",i=12===t(u.offsetWidth/3),ie.removeChild(s),u=null}}function t(e){return Math.round(parseFloat(e))}var n,r,i,o,a,s=E.createElement("div"),u=E.createElement("div");u.style&&(u.style.backgroundClip="content-box",u.cloneNode(!0).style.backgroundClip="",y.clearCloneStyle="content-box"===u.style.backgroundClip,k.extend(y,{boxSizingReliable:function(){return e(),r},pixelBoxStyles:function(){return e(),o},pixelPosition:function(){return e(),n},reliableMarginLeft:function(){return e(),a},scrollboxSize:function(){return e(),i}}))}();var Ue=["Webkit","Moz","ms"],Xe=E.createElement("div").style,Ve={};function Ge(e){var t=k.cssProps[e]||Ve[e];return t||(e in Xe?e:Ve[e]=function(e){var t=e[0].toUpperCase()+e.slice(1),n=Ue.length;while(n--)if((e=Ue[n]+t)in Xe)return e}(e)||e)}var Ye=/^(none|table(?!-c[ea]).+)/,Qe=/^--/,Je={position:"absolute",visibility:"hidden",display:"block"},Ke={letterSpacing:"0",fontWeight:"400"};function Ze(e,t,n){var r=ne.exec(t);return r?Math.max(0,r[2]-(n||0))+(r[3]||"px"):t}function et(e,t,n,r,i,o){var a="width"===t?1:0,s=0,u=0;if(n===(r?"border":"content"))return 0;for(;a<4;a+=2)"margin"===n&&(u+=k.css(e,n+re[a],!0,i)),r?("content"===n&&(u-=k.css(e,"padding"+re[a],!0,i)),"margin"!==n&&(u-=k.css(e,"border"+re[a]+"Width",!0,i))):(u+=k.css(e,"padding"+re[a],!0,i),"padding"!==n?u+=k.css(e,"border"+re[a]+"Width",!0,i):s+=k.css(e,"border"+re[a]+"Width",!0,i));return!r&&0<=o&&(u+=Math.max(0,Math.ceil(e["offset"+t[0].toUpperCase()+t.slice(1)]-o-u-s-.5))||0),u}function tt(e,t,n){var r=Fe(e),i=(!y.boxSizingReliable()||n)&&"border-box"===k.css(e,"boxSizing",!1,r),o=i,a=_e(e,t,r),s="offset"+t[0].toUpperCase()+t.slice(1);if($e.test(a)){if(!n)return a;a="auto"}return(!y.boxSizingReliable()&&i||"auto"===a||!parseFloat(a)&&"inline"===k.css(e,"display",!1,r))&&e.getClientRects().length&&(i="border-box"===k.css(e,"boxSizing",!1,r),(o=s in e)&&(a=e[s])),(a=parseFloat(a)||0)+et(e,t,n||(i?"border":"content"),o,r,a)+"px"}function nt(e,t,n,r,i){return new nt.prototype.init(e,t,n,r,i)}k.extend({cssHooks:{opacity:{get:function(e,t){if(t){var n=_e(e,"opacity");return""===n?"1":n}}}},cssNumber:{animationIterationCount:!0,columnCount:!0,fillOpacity:!0,flexGrow:!0,flexShrink:!0,fontWeight:!0,gridArea:!0,gridColumn:!0,gridColumnEnd:!0,gridColumnStart:!0,gridRow:!0,gridRowEnd:!0,gridRowStart:!0,lineHeight:!0,opacity:!0,order:!0,orphans:!0,widows:!0,zIndex:!0,zoom:!0},cssProps:{},style:function(e,t,n,r){if(e&&3!==e.nodeType&&8!==e.nodeType&&e.style){var i,o,a,s=V(t),u=Qe.test(t),l=e.style;if(u||(t=Ge(s)),a=k.cssHooks[t]||k.cssHooks[s],void 0===n)return a&&"get"in a&&void 0!==(i=a.get(e,!1,r))?i:l[t];"string"===(o=typeof n)&&(i=ne.exec(n))&&i[1]&&(n=le(e,t,i),o="number"),null!=n&&n==n&&("number"!==o||u||(n+=i&&i[3]||(k.cssNumber[s]?"":"px")),y.clearCloneStyle||""!==n||0!==t.indexOf("background")||(l[t]="inherit"),a&&"set"in a&&void 0===(n=a.set(e,n,r))||(u?l.setProperty(t,n):l[t]=n))}},css:function(e,t,n,r){var i,o,a,s=V(t);return Qe.test(t)||(t=Ge(s)),(a=k.cssHooks[t]||k.cssHooks[s])&&"get"in a&&(i=a.get(e,!0,n)),void 0===i&&(i=_e(e,t,r)),"normal"===i&&t in Ke&&(i=Ke[t]),""===n||n?(o=parseFloat(i),!0===n||isFinite(o)?o||0:i):i}}),k.each(["height","width"],function(e,u){k.cssHooks[u]={get:function(e,t,n){if(t)return!Ye.test(k.css(e,"display"))||e.getClientRects().length&&e.getBoundingClientRect().width?tt(e,u,n):ue(e,Je,function(){return tt(e,u,n)})},set:function(e,t,n){var r,i=Fe(e),o=!y.scrollboxSize()&&"absolute"===i.position,a=(o||n)&&"border-box"===k.css(e,"boxSizing",!1,i),s=n?et(e,u,n,a,i):0;return a&&o&&(s-=Math.ceil(e["offset"+u[0].toUpperCase()+u.slice(1)]-parseFloat(i[u])-et(e,u,"border",!1,i)-.5)),s&&(r=ne.exec(t))&&"px"!==(r[3]||"px")&&(e.style[u]=t,t=k.css(e,u)),Ze(0,t,s)}}}),k.cssHooks.marginLeft=ze(y.reliableMarginLeft,function(e,t){if(t)return(parseFloat(_e(e,"marginLeft"))||e.getBoundingClientRect().left-ue(e,{marginLeft:0},function(){return e.getBoundingClientRect().left}))+"px"}),k.each({margin:"",padding:"",border:"Width"},function(i,o){k.cssHooks[i+o]={expand:function(e){for(var t=0,n={},r="string"==typeof e?e.split(" "):[e];t<4;t++)n[i+re[t]+o]=r[t]||r[t-2]||r[0];return n}},"margin"!==i&&(k.cssHooks[i+o].set=Ze)}),k.fn.extend({css:function(e,t){return _(this,function(e,t,n){var r,i,o={},a=0;if(Array.isArray(t)){for(r=Fe(e),i=t.length;a<i;a++)o[t[a]]=k.css(e,t[a],!1,r);return o}return void 0!==n?k.style(e,t,n):k.css(e,t)},e,t,1<arguments.length)}}),((k.Tween=nt).prototype={constructor:nt,init:function(e,t,n,r,i,o){this.elem=e,this.prop=n,this.easing=i||k.easing._default,this.options=t,this.start=this.now=this.cur(),this.end=r,this.unit=o||(k.cssNumber[n]?"":"px")},cur:function(){var e=nt.propHooks[this.prop];return e&&e.get?e.get(this):nt.propHooks._default.get(this)},run:function(e){var t,n=nt.propHooks[this.prop];return this.options.duration?this.pos=t=k.easing[this.easing](e,this.options.duration*e,0,1,this.options.duration):this.pos=t=e,this.now=(this.end-this.start)*t+this.start,this.options.step&&this.options.step.call(this.elem,this.now,this),n&&n.set?n.set(this):nt.propHooks._default.set(this),this}}).init.prototype=nt.prototype,(nt.propHooks={_default:{get:function(e){var t;return 1!==e.elem.nodeType||null!=e.elem[e.prop]&&null==e.elem.style[e.prop]?e.elem[e.prop]:(t=k.css(e.elem,e.prop,""))&&"auto"!==t?t:0},set:function(e){k.fx.step[e.prop]?k.fx.step[e.prop](e):1!==e.elem.nodeType||!k.cssHooks[e.prop]&&null==e.elem.style[Ge(e.prop)]?e.elem[e.prop]=e.now:k.style(e.elem,e.prop,e.now+e.unit)}}}).scrollTop=nt.propHooks.scrollLeft={set:function(e){e.elem.nodeType&&e.elem.parentNode&&(e.elem[e.prop]=e.now)}},k.easing={linear:function(e){return e},swing:function(e){return.5-Math.cos(e*Math.PI)/2},_default:"swing"},k.fx=nt.prototype.init,k.fx.step={};var rt,it,ot,at,st=/^(?:toggle|show|hide)$/,ut=/queueHooks$/;function lt(){it&&(!1===E.hidden&&C.requestAnimationFrame?C.requestAnimationFrame(lt):C.setTimeout(lt,k.fx.interval),k.fx.tick())}function ct(){return C.setTimeout(function(){rt=void 0}),rt=Date.now()}function ft(e,t){var n,r=0,i={height:e};for(t=t?1:0;r<4;r+=2-t)i["margin"+(n=re[r])]=i["padding"+n]=e;return t&&(i.opacity=i.width=e),i}function pt(e,t,n){for(var r,i=(dt.tweeners[t]||[]).concat(dt.tweeners["*"]),o=0,a=i.length;o<a;o++)if(r=i[o].call(n,t,e))return r}function dt(o,e,t){var n,a,r=0,i=dt.prefilters.length,s=k.Deferred().always(function(){delete u.elem}),u=function(){if(a)return!1;for(var e=rt||ct(),t=Math.max(0,l.startTime+l.duration-e),n=1-(t/l.duration||0),r=0,i=l.tweens.length;r<i;r++)l.tweens[r].run(n);return s.notifyWith(o,[l,n,t]),n<1&&i?t:(i||s.notifyWith(o,[l,1,0]),s.resolveWith(o,[l]),!1)},l=s.promise({elem:o,props:k.extend({},e),opts:k.extend(!0,{specialEasing:{},easing:k.easing._default},t),originalProperties:e,originalOptions:t,startTime:rt||ct(),duration:t.duration,tweens:[],createTween:function(e,t){var n=k.Tween(o,l.opts,e,t,l.opts.specialEasing[e]||l.opts.easing);return l.tweens.push(n),n},stop:function(e){var t=0,n=e?l.tweens.length:0;if(a)return this;for(a=!0;t<n;t++)l.tweens[t].run(1);return e?(s.notifyWith(o,[l,1,0]),s.resolveWith(o,[l,e])):s.rejectWith(o,[l,e]),this}}),c=l.props;for(!function(e,t){var n,r,i,o,a;for(n in e)if(i=t[r=V(n)],o=e[n],Array.isArray(o)&&(i=o[1],o=e[n]=o[0]),n!==r&&(e[r]=o,delete e[n]),(a=k.cssHooks[r])&&"expand"in a)for(n in o=a.expand(o),delete e[r],o)n in e||(e[n]=o[n],t[n]=i);else t[r]=i}(c,l.opts.specialEasing);r<i;r++)if(n=dt.prefilters[r].call(l,o,c,l.opts))return m(n.stop)&&(k._queueHooks(l.elem,l.opts.queue).stop=n.stop.bind(n)),n;return k.map(c,pt,l),m(l.opts.start)&&l.opts.start.call(o,l),l.progress(l.opts.progress).done(l.opts.done,l.opts.complete).fail(l.opts.fail).always(l.opts.always),k.fx.timer(k.extend(u,{elem:o,anim:l,queue:l.opts.queue})),l}k.Animation=k.extend(dt,{tweeners:{"*":[function(e,t){var n=this.createTween(e,t);return le(n.elem,e,ne.exec(t),n),n}]},tweener:function(e,t){m(e)?(t=e,e=["*"]):e=e.match(R);for(var n,r=0,i=e.length;r<i;r++)n=e[r],dt.tweeners[n]=dt.tweeners[n]||[],dt.tweeners[n].unshift(t)},prefilters:[function(e,t,n){var r,i,o,a,s,u,l,c,f="width"in t||"height"in t,p=this,d={},h=e.style,g=e.nodeType&&se(e),v=Q.get(e,"fxshow");for(r in n.queue||(null==(a=k._queueHooks(e,"fx")).unqueued&&(a.unqueued=0,s=a.empty.fire,a.empty.fire=function(){a.unqueued||s()}),a.unqueued++,p.always(function(){p.always(function(){a.unqueued--,k.queue(e,"fx").length||a.empty.fire()})})),t)if(i=t[r],st.test(i)){if(delete t[r],o=o||"toggle"===i,i===(g?"hide":"show")){if("show"!==i||!v||void 0===v[r])continue;g=!0}d[r]=v&&v[r]||k.style(e,r)}if((u=!k.isEmptyObject(t))||!k.isEmptyObject(d))for(r in f&&1===e.nodeType&&(n.overflow=[h.overflow,h.overflowX,h.overflowY],null==(l=v&&v.display)&&(l=Q.get(e,"display")),"none"===(c=k.css(e,"display"))&&(l?c=l:(fe([e],!0),l=e.style.display||l,c=k.css(e,"display"),fe([e]))),("inline"===c||"inline-block"===c&&null!=l)&&"none"===k.css(e,"float")&&(u||(p.done(function(){h.display=l}),null==l&&(c=h.display,l="none"===c?"":c)),h.display="inline-block")),n.overflow&&(h.overflow="hidden",p.always(function(){h.overflow=n.overflow[0],h.overflowX=n.overflow[1],h.overflowY=n.overflow[2]})),u=!1,d)u||(v?"hidden"in v&&(g=v.hidden):v=Q.access(e,"fxshow",{display:l}),o&&(v.hidden=!g),g&&fe([e],!0),p.done(function(){for(r in g||fe([e]),Q.remove(e,"fxshow"),d)k.style(e,r,d[r])})),u=pt(g?v[r]:0,r,p),r in v||(v[r]=u.start,g&&(u.end=u.start,u.start=0))}],prefilter:function(e,t){t?dt.prefilters.unshift(e):dt.prefilters.push(e)}}),k.speed=function(e,t,n){var r=e&&"object"==typeof e?k.extend({},e):{complete:n||!n&&t||m(e)&&e,duration:e,easing:n&&t||t&&!m(t)&&t};return k.fx.off?r.duration=0:"number"!=typeof r.duration&&(r.duration in k.fx.speeds?r.duration=k.fx.speeds[r.duration]:r.duration=k.fx.speeds._default),null!=r.queue&&!0!==r.queue||(r.queue="fx"),r.old=r.complete,r.complete=function(){m(r.old)&&r.old.call(this),r.queue&&k.dequeue(this,r.queue)},r},k.fn.extend({fadeTo:function(e,t,n,r){return this.filter(se).css("opacity",0).show().end().animate({opacity:t},e,n,r)},animate:function(t,e,n,r){var i=k.isEmptyObject(t),o=k.speed(e,n,r),a=function(){var e=dt(this,k.extend({},t),o);(i||Q.get(this,"finish"))&&e.stop(!0)};return a.finish=a,i||!1===o.queue?this.each(a):this.queue(o.queue,a)},stop:function(i,e,o){var a=function(e){var t=e.stop;delete e.stop,t(o)};return"string"!=typeof i&&(o=e,e=i,i=void 0),e&&!1!==i&&this.queue(i||"fx",[]),this.each(function(){var e=!0,t=null!=i&&i+"queueHooks",n=k.timers,r=Q.get(this);if(t)r[t]&&r[t].stop&&a(r[t]);else for(t in r)r[t]&&r[t].stop&&ut.test(t)&&a(r[t]);for(t=n.length;t--;)n[t].elem!==this||null!=i&&n[t].queue!==i||(n[t].anim.stop(o),e=!1,n.splice(t,1));!e&&o||k.dequeue(this,i)})},finish:function(a){return!1!==a&&(a=a||"fx"),this.each(function(){var e,t=Q.get(this),n=t[a+"queue"],r=t[a+"queueHooks"],i=k.timers,o=n?n.length:0;for(t.finish=!0,k.queue(this,a,[]),r&&r.stop&&r.stop.call(this,!0),e=i.length;e--;)i[e].elem===this&&i[e].queue===a&&(i[e].anim.stop(!0),i.splice(e,1));for(e=0;e<o;e++)n[e]&&n[e].finish&&n[e].finish.call(this);delete t.finish})}}),k.each(["toggle","show","hide"],function(e,r){var i=k.fn[r];k.fn[r]=function(e,t,n){return null==e||"boolean"==typeof e?i.apply(this,arguments):this.animate(ft(r,!0),e,t,n)}}),k.each({slideDown:ft("show"),slideUp:ft("hide"),slideToggle:ft("toggle"),fadeIn:{opacity:"show"},fadeOut:{opacity:"hide"},fadeToggle:{opacity:"toggle"}},function(e,r){k.fn[e]=function(e,t,n){return this.animate(r,e,t,n)}}),k.timers=[],k.fx.tick=function(){var e,t=0,n=k.timers;for(rt=Date.now();t<n.length;t++)(e=n[t])()||n[t]!==e||n.splice(t--,1);n.length||k.fx.stop(),rt=void 0},k.fx.timer=function(e){k.timers.push(e),k.fx.start()},k.fx.interval=13,k.fx.start=function(){it||(it=!0,lt())},k.fx.stop=function(){it=null},k.fx.speeds={slow:600,fast:200,_default:400},k.fn.delay=function(r,e){return r=k.fx&&k.fx.speeds[r]||r,e=e||"fx",this.queue(e,function(e,t){var n=C.setTimeout(e,r);t.stop=function(){C.clearTimeout(n)}})},ot=E.createElement("input"),at=E.createElement("select").appendChild(E.createElement("option")),ot.type="checkbox",y.checkOn=""!==ot.value,y.optSelected=at.selected,(ot=E.createElement("input")).value="t",ot.type="radio",y.radioValue="t"===ot.value;var ht,gt=k.expr.attrHandle;k.fn.extend({attr:function(e,t){return _(this,k.attr,e,t,1<arguments.length)},removeAttr:function(e){return this.each(function(){k.removeAttr(this,e)})}}),k.extend({attr:function(e,t,n){var r,i,o=e.nodeType;if(3!==o&&8!==o&&2!==o)return"undefined"==typeof e.getAttribute?k.prop(e,t,n):(1===o&&k.isXMLDoc(e)||(i=k.attrHooks[t.toLowerCase()]||(k.expr.match.bool.test(t)?ht:void 0)),void 0!==n?null===n?void k.removeAttr(e,t):i&&"set"in i&&void 0!==(r=i.set(e,n,t))?r:(e.setAttribute(t,n+""),n):i&&"get"in i&&null!==(r=i.get(e,t))?r:null==(r=k.find.attr(e,t))?void 0:r)},attrHooks:{type:{set:function(e,t){if(!y.radioValue&&"radio"===t&&A(e,"input")){var n=e.value;return e.setAttribute("type",t),n&&(e.value=n),t}}}},removeAttr:function(e,t){var n,r=0,i=t&&t.match(R);if(i&&1===e.nodeType)while(n=i[r++])e.removeAttribute(n)}}),ht={set:function(e,t,n){return!1===t?k.removeAttr(e,n):e.setAttribute(n,n),n}},k.each(k.expr.match.bool.source.match(/\w+/g),function(e,t){var a=gt[t]||k.find.attr;gt[t]=function(e,t,n){var r,i,o=t.toLowerCase();return n||(i=gt[o],gt[o]=r,r=null!=a(e,t,n)?o:null,gt[o]=i),r}});var vt=/^(?:input|select|textarea|button)$/i,yt=/^(?:a|area)$/i;function mt(e){return(e.match(R)||[]).join(" ")}function xt(e){return e.getAttribute&&e.getAttribute("class")||""}function bt(e){return Array.isArray(e)?e:"string"==typeof e&&e.match(R)||[]}k.fn.extend({prop:function(e,t){return _(this,k.prop,e,t,1<arguments.length)},removeProp:function(e){return this.each(function(){delete this[k.propFix[e]||e]})}}),k.extend({prop:function(e,t,n){var r,i,o=e.nodeType;if(3!==o&&8!==o&&2!==o)return 1===o&&k.isXMLDoc(e)||(t=k.propFix[t]||t,i=k.propHooks[t]),void 0!==n?i&&"set"in i&&void 0!==(r=i.set(e,n,t))?r:e[t]=n:i&&"get"in i&&null!==(r=i.get(e,t))?r:e[t]},propHooks:{tabIndex:{get:function(e){var t=k.find.attr(e,"tabindex");return t?parseInt(t,10):vt.test(e.nodeName)||yt.test(e.nodeName)&&e.href?0:-1}}},propFix:{"for":"htmlFor","class":"className"}}),y.optSelected||(k.propHooks.selected={get:function(e){var t=e.parentNode;return t&&t.parentNode&&t.parentNode.selectedIndex,null},set:function(e){var t=e.parentNode;t&&(t.selectedIndex,t.parentNode&&t.parentNode.selectedIndex)}}),k.each(["tabIndex","readOnly","maxLength","cellSpacing","cellPadding","rowSpan","colSpan","useMap","frameBorder","contentEditable"],function(){k.propFix[this.toLowerCase()]=this}),k.fn.extend({addClass:function(t){var e,n,r,i,o,a,s,u=0;if(m(t))return this.each(function(e){k(this).addClass(t.call(this,e,xt(this)))});if((e=bt(t)).length)while(n=this[u++])if(i=xt(n),r=1===n.nodeType&&" "+mt(i)+" "){a=0;while(o=e[a++])r.indexOf(" "+o+" ")<0&&(r+=o+" ");i!==(s=mt(r))&&n.setAttribute("class",s)}return this},removeClass:function(t){var e,n,r,i,o,a,s,u=0;if(m(t))return this.each(function(e){k(this).removeClass(t.call(this,e,xt(this)))});if(!arguments.length)return this.attr("class","");if((e=bt(t)).length)while(n=this[u++])if(i=xt(n),r=1===n.nodeType&&" "+mt(i)+" "){a=0;while(o=e[a++])while(-1<r.indexOf(" "+o+" "))r=r.replace(" "+o+" "," ");i!==(s=mt(r))&&n.setAttribute("class",s)}return this},toggleClass:function(i,t){var o=typeof i,a="string"===o||Array.isArray(i);return"boolean"==typeof t&&a?t?this.addClass(i):this.removeClass(i):m(i)?this.each(function(e){k(this).toggleClass(i.call(this,e,xt(this),t),t)}):this.each(function(){var e,t,n,r;if(a){t=0,n=k(this),r=bt(i);while(e=r[t++])n.hasClass(e)?n.removeClass(e):n.addClass(e)}else void 0!==i&&"boolean"!==o||((e=xt(this))&&Q.set(this,"__className__",e),this.setAttribute&&this.setAttribute("class",e||!1===i?"":Q.get(this,"__className__")||""))})},hasClass:function(e){var t,n,r=0;t=" "+e+" ";while(n=this[r++])if(1===n.nodeType&&-1<(" "+mt(xt(n))+" ").indexOf(t))return!0;return!1}});var wt=/\r/g;k.fn.extend({val:function(n){var r,e,i,t=this[0];return arguments.length?(i=m(n),this.each(function(e){var t;1===this.nodeType&&(null==(t=i?n.call(this,e,k(this).val()):n)?t="":"number"==typeof t?t+="":Array.isArray(t)&&(t=k.map(t,function(e){return null==e?"":e+""})),(r=k.valHooks[this.type]||k.valHooks[this.nodeName.toLowerCase()])&&"set"in r&&void 0!==r.set(this,t,"value")||(this.value=t))})):t?(r=k.valHooks[t.type]||k.valHooks[t.nodeName.toLowerCase()])&&"get"in r&&void 0!==(e=r.get(t,"value"))?e:"string"==typeof(e=t.value)?e.replace(wt,""):null==e?"":e:void 0}}),k.extend({valHooks:{option:{get:function(e){var t=k.find.attr(e,"value");return null!=t?t:mt(k.text(e))}},select:{get:function(e){var t,n,r,i=e.options,o=e.selectedIndex,a="select-one"===e.type,s=a?null:[],u=a?o+1:i.length;for(r=o<0?u:a?o:0;r<u;r++)if(((n=i[r]).selected||r===o)&&!n.disabled&&(!n.parentNode.disabled||!A(n.parentNode,"optgroup"))){if(t=k(n).val(),a)return t;s.push(t)}return s},set:function(e,t){var n,r,i=e.options,o=k.makeArray(t),a=i.length;while(a--)((r=i[a]).selected=-1<k.inArray(k.valHooks.option.get(r),o))&&(n=!0);return n||(e.selectedIndex=-1),o}}}}),k.each(["radio","checkbox"],function(){k.valHooks[this]={set:function(e,t){if(Array.isArray(t))return e.checked=-1<k.inArray(k(e).val(),t)}},y.checkOn||(k.valHooks[this].get=function(e){return null===e.getAttribute("value")?"on":e.value})}),y.focusin="onfocusin"in C;var Tt=/^(?:focusinfocus|focusoutblur)$/,Ct=function(e){e.stopPropagation()};k.extend(k.event,{trigger:function(e,t,n,r){var i,o,a,s,u,l,c,f,p=[n||E],d=v.call(e,"type")?e.type:e,h=v.call(e,"namespace")?e.namespace.split("."):[];if(o=f=a=n=n||E,3!==n.nodeType&&8!==n.nodeType&&!Tt.test(d+k.event.triggered)&&(-1<d.indexOf(".")&&(d=(h=d.split(".")).shift(),h.sort()),u=d.indexOf(":")<0&&"on"+d,(e=e[k.expando]?e:new k.Event(d,"object"==typeof e&&e)).isTrigger=r?2:3,e.namespace=h.join("."),e.rnamespace=e.namespace?new RegExp("(^|\\.)"+h.join("\\.(?:.*\\.|)")+"(\\.|$)"):null,e.result=void 0,e.target||(e.target=n),t=null==t?[e]:k.makeArray(t,[e]),c=k.event.special[d]||{},r||!c.trigger||!1!==c.trigger.apply(n,t))){if(!r&&!c.noBubble&&!x(n)){for(s=c.delegateType||d,Tt.test(s+d)||(o=o.parentNode);o;o=o.parentNode)p.push(o),a=o;a===(n.ownerDocument||E)&&p.push(a.defaultView||a.parentWindow||C)}i=0;while((o=p[i++])&&!e.isPropagationStopped())f=o,e.type=1<i?s:c.bindType||d,(l=(Q.get(o,"events")||{})[e.type]&&Q.get(o,"handle"))&&l.apply(o,t),(l=u&&o[u])&&l.apply&&G(o)&&(e.result=l.apply(o,t),!1===e.result&&e.preventDefault());return e.type=d,r||e.isDefaultPrevented()||c._default&&!1!==c._default.apply(p.pop(),t)||!G(n)||u&&m(n[d])&&!x(n)&&((a=n[u])&&(n[u]=null),k.event.triggered=d,e.isPropagationStopped()&&f.addEventListener(d,Ct),n[d](),e.isPropagationStopped()&&f.removeEventListener(d,Ct),k.event.triggered=void 0,a&&(n[u]=a)),e.result}},simulate:function(e,t,n){var r=k.extend(new k.Event,n,{type:e,isSimulated:!0});k.event.trigger(r,null,t)}}),k.fn.extend({trigger:function(e,t){return this.each(function(){k.event.trigger(e,t,this)})},triggerHandler:function(e,t){var n=this[0];if(n)return k.event.trigger(e,t,n,!0)}}),y.focusin||k.each({focus:"focusin",blur:"focusout"},function(n,r){var i=function(e){k.event.simulate(r,e.target,k.event.fix(e))};k.event.special[r]={setup:function(){var e=this.ownerDocument||this,t=Q.access(e,r);t||e.addEventListener(n,i,!0),Q.access(e,r,(t||0)+1)},teardown:function(){var e=this.ownerDocument||this,t=Q.access(e,r)-1;t?Q.access(e,r,t):(e.removeEventListener(n,i,!0),Q.remove(e,r))}}});var Et=C.location,kt=Date.now(),St=/\?/;k.parseXML=function(e){var t;if(!e||"string"!=typeof e)return null;try{t=(new C.DOMParser).parseFromString(e,"text/xml")}catch(e){t=void 0}return t&&!t.getElementsByTagName("parsererror").length||k.error("Invalid XML: "+e),t};var Nt=/\[\]$/,At=/\r?\n/g,Dt=/^(?:submit|button|image|reset|file)$/i,jt=/^(?:input|select|textarea|keygen)/i;function qt(n,e,r,i){var t;if(Array.isArray(e))k.each(e,function(e,t){r||Nt.test(n)?i(n,t):qt(n+"["+("object"==typeof t&&null!=t?e:"")+"]",t,r,i)});else if(r||"object"!==w(e))i(n,e);else for(t in e)qt(n+"["+t+"]",e[t],r,i)}k.param=function(e,t){var n,r=[],i=function(e,t){var n=m(t)?t():t;r[r.length]=encodeURIComponent(e)+"="+encodeURIComponent(null==n?"":n)};if(null==e)return"";if(Array.isArray(e)||e.jquery&&!k.isPlainObject(e))k.each(e,function(){i(this.name,this.value)});else for(n in e)qt(n,e[n],t,i);return r.join("&")},k.fn.extend({serialize:function(){return k.param(this.serializeArray())},serializeArray:function(){return this.map(function(){var e=k.prop(this,"elements");return e?k.makeArray(e):this}).filter(function(){var e=this.type;return this.name&&!k(this).is(":disabled")&&jt.test(this.nodeName)&&!Dt.test(e)&&(this.checked||!pe.test(e))}).map(function(e,t){var n=k(this).val();return null==n?null:Array.isArray(n)?k.map(n,function(e){return{name:t.name,value:e.replace(At,"\r\n")}}):{name:t.name,value:n.replace(At,"\r\n")}}).get()}});var Lt=/%20/g,Ht=/#.*$/,Ot=/([?&])_=[^&]*/,Pt=/^(.*?):[ \t]*([^\r\n]*)$/gm,Rt=/^(?:GET|HEAD)$/,Mt=/^\/\//,It={},Wt={},$t="*/".concat("*"),Ft=E.createElement("a");function Bt(o){return function(e,t){"string"!=typeof e&&(t=e,e="*");var n,r=0,i=e.toLowerCase().match(R)||[];if(m(t))while(n=i[r++])"+"===n[0]?(n=n.slice(1)||"*",(o[n]=o[n]||[]).unshift(t)):(o[n]=o[n]||[]).push(t)}}function _t(t,i,o,a){var s={},u=t===Wt;function l(e){var r;return s[e]=!0,k.each(t[e]||[],function(e,t){var n=t(i,o,a);return"string"!=typeof n||u||s[n]?u?!(r=n):void 0:(i.dataTypes.unshift(n),l(n),!1)}),r}return l(i.dataTypes[0])||!s["*"]&&l("*")}function zt(e,t){var n,r,i=k.ajaxSettings.flatOptions||{};for(n in t)void 0!==t[n]&&((i[n]?e:r||(r={}))[n]=t[n]);return r&&k.extend(!0,e,r),e}Ft.href=Et.href,k.extend({active:0,lastModified:{},etag:{},ajaxSettings:{url:Et.href,type:"GET",isLocal:/^(?:about|app|app-storage|.+-extension|file|res|widget):$/.test(Et.protocol),global:!0,processData:!0,async:!0,contentType:"application/x-www-form-urlencoded; charset=UTF-8",accepts:{"*":$t,text:"text/plain",html:"text/html",xml:"application/xml, text/xml",json:"application/json, text/javascript"},contents:{xml:/\bxml\b/,html:/\bhtml/,json:/\bjson\b/},responseFields:{xml:"responseXML",text:"responseText",json:"responseJSON"},converters:{"* text":String,"text html":!0,"text json":JSON.parse,"text xml":k.parseXML},flatOptions:{url:!0,context:!0}},ajaxSetup:function(e,t){return t?zt(zt(e,k.ajaxSettings),t):zt(k.ajaxSettings,e)},ajaxPrefilter:Bt(It),ajaxTransport:Bt(Wt),ajax:function(e,t){"object"==typeof e&&(t=e,e=void 0),t=t||{};var c,f,p,n,d,r,h,g,i,o,v=k.ajaxSetup({},t),y=v.context||v,m=v.context&&(y.nodeType||y.jquery)?k(y):k.event,x=k.Deferred(),b=k.Callbacks("once memory"),w=v.statusCode||{},a={},s={},u="canceled",T={readyState:0,getResponseHeader:function(e){var t;if(h){if(!n){n={};while(t=Pt.exec(p))n[t[1].toLowerCase()+" "]=(n[t[1].toLowerCase()+" "]||[]).concat(t[2])}t=n[e.toLowerCase()+" "]}return null==t?null:t.join(", ")},getAllResponseHeaders:function(){return h?p:null},setRequestHeader:function(e,t){return null==h&&(e=s[e.toLowerCase()]=s[e.toLowerCase()]||e,a[e]=t),this},overrideMimeType:function(e){return null==h&&(v.mimeType=e),this},statusCode:function(e){var t;if(e)if(h)T.always(e[T.status]);else for(t in e)w[t]=[w[t],e[t]];return this},abort:function(e){var t=e||u;return c&&c.abort(t),l(0,t),this}};if(x.promise(T),v.url=((e||v.url||Et.href)+"").replace(Mt,Et.protocol+"//"),v.type=t.method||t.type||v.method||v.type,v.dataTypes=(v.dataType||"*").toLowerCase().match(R)||[""],null==v.crossDomain){r=E.createElement("a");try{r.href=v.url,r.href=r.href,v.crossDomain=Ft.protocol+"//"+Ft.host!=r.protocol+"//"+r.host}catch(e){v.crossDomain=!0}}if(v.data&&v.processData&&"string"!=typeof v.data&&(v.data=k.param(v.data,v.traditional)),_t(It,v,t,T),h)return T;for(i in(g=k.event&&v.global)&&0==k.active++&&k.event.trigger("ajaxStart"),v.type=v.type.toUpperCase(),v.hasContent=!Rt.test(v.type),f=v.url.replace(Ht,""),v.hasContent?v.data&&v.processData&&0===(v.contentType||"").indexOf("application/x-www-form-urlencoded")&&(v.data=v.data.replace(Lt,"+")):(o=v.url.slice(f.length),v.data&&(v.processData||"string"==typeof v.data)&&(f+=(St.test(f)?"&":"?")+v.data,delete v.data),!1===v.cache&&(f=f.replace(Ot,"$1"),o=(St.test(f)?"&":"?")+"_="+kt+++o),v.url=f+o),v.ifModified&&(k.lastModified[f]&&T.setRequestHeader("If-Modified-Since",k.lastModified[f]),k.etag[f]&&T.setRequestHeader("If-None-Match",k.etag[f])),(v.data&&v.hasContent&&!1!==v.contentType||t.contentType)&&T.setRequestHeader("Content-Type",v.contentType),T.setRequestHeader("Accept",v.dataTypes[0]&&v.accepts[v.dataTypes[0]]?v.accepts[v.dataTypes[0]]+("*"!==v.dataTypes[0]?", "+$t+"; q=0.01":""):v.accepts["*"]),v.headers)T.setRequestHeader(i,v.headers[i]);if(v.beforeSend&&(!1===v.beforeSend.call(y,T,v)||h))return T.abort();if(u="abort",b.add(v.complete),T.done(v.success),T.fail(v.error),c=_t(Wt,v,t,T)){if(T.readyState=1,g&&m.trigger("ajaxSend",[T,v]),h)return T;v.async&&0<v.timeout&&(d=C.setTimeout(function(){T.abort("timeout")},v.timeout));try{h=!1,c.send(a,l)}catch(e){if(h)throw e;l(-1,e)}}else l(-1,"No Transport");function l(e,t,n,r){var i,o,a,s,u,l=t;h||(h=!0,d&&C.clearTimeout(d),c=void 0,p=r||"",T.readyState=0<e?4:0,i=200<=e&&e<300||304===e,n&&(s=function(e,t,n){var r,i,o,a,s=e.contents,u=e.dataTypes;while("*"===u[0])u.shift(),void 0===r&&(r=e.mimeType||t.getResponseHeader("Content-Type"));if(r)for(i in s)if(s[i]&&s[i].test(r)){u.unshift(i);break}if(u[0]in n)o=u[0];else{for(i in n){if(!u[0]||e.converters[i+" "+u[0]]){o=i;break}a||(a=i)}o=o||a}if(o)return o!==u[0]&&u.unshift(o),n[o]}(v,T,n)),s=function(e,t,n,r){var i,o,a,s,u,l={},c=e.dataTypes.slice();if(c[1])for(a in e.converters)l[a.toLowerCase()]=e.converters[a];o=c.shift();while(o)if(e.responseFields[o]&&(n[e.responseFields[o]]=t),!u&&r&&e.dataFilter&&(t=e.dataFilter(t,e.dataType)),u=o,o=c.shift())if("*"===o)o=u;else if("*"!==u&&u!==o){if(!(a=l[u+" "+o]||l["* "+o]))for(i in l)if((s=i.split(" "))[1]===o&&(a=l[u+" "+s[0]]||l["* "+s[0]])){!0===a?a=l[i]:!0!==l[i]&&(o=s[0],c.unshift(s[1]));break}if(!0!==a)if(a&&e["throws"])t=a(t);else try{t=a(t)}catch(e){return{state:"parsererror",error:a?e:"No conversion from "+u+" to "+o}}}return{state:"success",data:t}}(v,s,T,i),i?(v.ifModified&&((u=T.getResponseHeader("Last-Modified"))&&(k.lastModified[f]=u),(u=T.getResponseHeader("etag"))&&(k.etag[f]=u)),204===e||"HEAD"===v.type?l="nocontent":304===e?l="notmodified":(l=s.state,o=s.data,i=!(a=s.error))):(a=l,!e&&l||(l="error",e<0&&(e=0))),T.status=e,T.statusText=(t||l)+"",i?x.resolveWith(y,[o,l,T]):x.rejectWith(y,[T,l,a]),T.statusCode(w),w=void 0,g&&m.trigger(i?"ajaxSuccess":"ajaxError",[T,v,i?o:a]),b.fireWith(y,[T,l]),g&&(m.trigger("ajaxComplete",[T,v]),--k.active||k.event.trigger("ajaxStop")))}return T},getJSON:function(e,t,n){return k.get(e,t,n,"json")},getScript:function(e,t){return k.get(e,void 0,t,"script")}}),k.each(["get","post"],function(e,i){k[i]=function(e,t,n,r){return m(t)&&(r=r||n,n=t,t=void 0),k.ajax(k.extend({url:e,type:i,dataType:r,data:t,success:n},k.isPlainObject(e)&&e))}}),k._evalUrl=function(e,t){return k.ajax({url:e,type:"GET",dataType:"script",cache:!0,async:!1,global:!1,converters:{"text script":function(){}},dataFilter:function(e){k.globalEval(e,t)}})},k.fn.extend({wrapAll:function(e){var t;return this[0]&&(m(e)&&(e=e.call(this[0])),t=k(e,this[0].ownerDocument).eq(0).clone(!0),this[0].parentNode&&t.insertBefore(this[0]),t.map(function(){var e=this;while(e.firstElementChild)e=e.firstElementChild;return e}).append(this)),this},wrapInner:function(n){return m(n)?this.each(function(e){k(this).wrapInner(n.call(this,e))}):this.each(function(){var e=k(this),t=e.contents();t.length?t.wrapAll(n):e.append(n)})},wrap:function(t){var n=m(t);return this.each(function(e){k(this).wrapAll(n?t.call(this,e):t)})},unwrap:function(e){return this.parent(e).not("body").each(function(){k(this).replaceWith(this.childNodes)}),this}}),k.expr.pseudos.hidden=function(e){return!k.expr.pseudos.visible(e)},k.expr.pseudos.visible=function(e){return!!(e.offsetWidth||e.offsetHeight||e.getClientRects().length)},k.ajaxSettings.xhr=function(){try{return new C.XMLHttpRequest}catch(e){}};var Ut={0:200,1223:204},Xt=k.ajaxSettings.xhr();y.cors=!!Xt&&"withCredentials"in Xt,y.ajax=Xt=!!Xt,k.ajaxTransport(function(i){var o,a;if(y.cors||Xt&&!i.crossDomain)return{send:function(e,t){var n,r=i.xhr();if(r.open(i.type,i.url,i.async,i.username,i.password),i.xhrFields)for(n in i.xhrFields)r[n]=i.xhrFields[n];for(n in i.mimeType&&r.overrideMimeType&&r.overrideMimeType(i.mimeType),i.crossDomain||e["X-Requested-With"]||(e["X-Requested-With"]="XMLHttpRequest"),e)r.setRequestHeader(n,e[n]);o=function(e){return function(){o&&(o=a=r.onload=r.onerror=r.onabort=r.ontimeout=r.onreadystatechange=null,"abort"===e?r.abort():"error"===e?"number"!=typeof r.status?t(0,"error"):t(r.status,r.statusText):t(Ut[r.status]||r.status,r.statusText,"text"!==(r.responseType||"text")||"string"!=typeof r.responseText?{binary:r.response}:{text:r.responseText},r.getAllResponseHeaders()))}},r.onload=o(),a=r.onerror=r.ontimeout=o("error"),void 0!==r.onabort?r.onabort=a:r.onreadystatechange=function(){4===r.readyState&&C.setTimeout(function(){o&&a()})},o=o("abort");try{r.send(i.hasContent&&i.data||null)}catch(e){if(o)throw e}},abort:function(){o&&o()}}}),k.ajaxPrefilter(function(e){e.crossDomain&&(e.contents.script=!1)}),k.ajaxSetup({accepts:{script:"text/javascript, application/javascript, application/ecmascript, application/x-ecmascript"},contents:{script:/\b(?:java|ecma)script\b/},converters:{"text script":function(e){return k.globalEval(e),e}}}),k.ajaxPrefilter("script",function(e){void 0===e.cache&&(e.cache=!1),e.crossDomain&&(e.type="GET")}),k.ajaxTransport("script",function(n){var r,i;if(n.crossDomain||n.scriptAttrs)return{send:function(e,t){r=k("<script>").attr(n.scriptAttrs||{}).prop({charset:n.scriptCharset,src:n.url}).on("load error",i=function(e){r.remove(),i=null,e&&t("error"===e.type?404:200,e.type)}),E.head.appendChild(r[0])},abort:function(){i&&i()}}});var Vt,Gt=[],Yt=/(=)\?(?=&|$)|\?\?/;k.ajaxSetup({jsonp:"callback",jsonpCallback:function(){var e=Gt.pop()||k.expando+"_"+kt++;return this[e]=!0,e}}),k.ajaxPrefilter("json jsonp",function(e,t,n){var r,i,o,a=!1!==e.jsonp&&(Yt.test(e.url)?"url":"string"==typeof e.data&&0===(e.contentType||"").indexOf("application/x-www-form-urlencoded")&&Yt.test(e.data)&&"data");if(a||"jsonp"===e.dataTypes[0])return r=e.jsonpCallback=m(e.jsonpCallback)?e.jsonpCallback():e.jsonpCallback,a?e[a]=e[a].replace(Yt,"$1"+r):!1!==e.jsonp&&(e.url+=(St.test(e.url)?"&":"?")+e.jsonp+"="+r),e.converters["script json"]=function(){return o||k.error(r+" was not called"),o[0]},e.dataTypes[0]="json",i=C[r],C[r]=function(){o=arguments},n.always(function(){void 0===i?k(C).removeProp(r):C[r]=i,e[r]&&(e.jsonpCallback=t.jsonpCallback,Gt.push(r)),o&&m(i)&&i(o[0]),o=i=void 0}),"script"}),y.createHTMLDocument=((Vt=E.implementation.createHTMLDocument("").body).innerHTML="<form></form><form></form>",2===Vt.childNodes.length),k.parseHTML=function(e,t,n){return"string"!=typeof e?[]:("boolean"==typeof t&&(n=t,t=!1),t||(y.createHTMLDocument?((r=(t=E.implementation.createHTMLDocument("")).createElement("base")).href=E.location.href,t.head.appendChild(r)):t=E),o=!n&&[],(i=D.exec(e))?[t.createElement(i[1])]:(i=we([e],t,o),o&&o.length&&k(o).remove(),k.merge([],i.childNodes)));var r,i,o},k.fn.load=function(e,t,n){var r,i,o,a=this,s=e.indexOf(" ");return-1<s&&(r=mt(e.slice(s)),e=e.slice(0,s)),m(t)?(n=t,t=void 0):t&&"object"==typeof t&&(i="POST"),0<a.length&&k.ajax({url:e,type:i||"GET",dataType:"html",data:t}).done(function(e){o=arguments,a.html(r?k("<div>").append(k.parseHTML(e)).find(r):e)}).always(n&&function(e,t){a.each(function(){n.apply(this,o||[e.responseText,t,e])})}),this},k.each(["ajaxStart","ajaxStop","ajaxComplete","ajaxError","ajaxSuccess","ajaxSend"],function(e,t){k.fn[t]=function(e){return this.on(t,e)}}),k.expr.pseudos.animated=function(t){return k.grep(k.timers,function(e){return t===e.elem}).length},k.offset={setOffset:function(e,t,n){var r,i,o,a,s,u,l=k.css(e,"position"),c=k(e),f={};"static"===l&&(e.style.position="relative"),s=c.offset(),o=k.css(e,"top"),u=k.css(e,"left"),("absolute"===l||"fixed"===l)&&-1<(o+u).indexOf("auto")?(a=(r=c.position()).top,i=r.left):(a=parseFloat(o)||0,i=parseFloat(u)||0),m(t)&&(t=t.call(e,n,k.extend({},s))),null!=t.top&&(f.top=t.top-s.top+a),null!=t.left&&(f.left=t.left-s.left+i),"using"in t?t.using.call(e,f):c.css(f)}},k.fn.extend({offset:function(t){if(arguments.length)return void 0===t?this:this.each(function(e){k.offset.setOffset(this,t,e)});var e,n,r=this[0];return r?r.getClientRects().length?(e=r.getBoundingClientRect(),n=r.ownerDocument.defaultView,{top:e.top+n.pageYOffset,left:e.left+n.pageXOffset}):{top:0,left:0}:void 0},position:function(){if(this[0]){var e,t,n,r=this[0],i={top:0,left:0};if("fixed"===k.css(r,"position"))t=r.getBoundingClientRect();else{t=this.offset(),n=r.ownerDocument,e=r.offsetParent||n.documentElement;while(e&&(e===n.body||e===n.documentElement)&&"static"===k.css(e,"position"))e=e.parentNode;e&&e!==r&&1===e.nodeType&&((i=k(e).offset()).top+=k.css(e,"borderTopWidth",!0),i.left+=k.css(e,"borderLeftWidth",!0))}return{top:t.top-i.top-k.css(r,"marginTop",!0),left:t.left-i.left-k.css(r,"marginLeft",!0)}}},offsetParent:function(){return this.map(function(){var e=this.offsetParent;while(e&&"static"===k.css(e,"position"))e=e.offsetParent;return e||ie})}}),k.each({scrollLeft:"pageXOffset",scrollTop:"pageYOffset"},function(t,i){var o="pageYOffset"===i;k.fn[t]=function(e){return _(this,function(e,t,n){var r;if(x(e)?r=e:9===e.nodeType&&(r=e.defaultView),void 0===n)return r?r[i]:e[t];r?r.scrollTo(o?r.pageXOffset:n,o?n:r.pageYOffset):e[t]=n},t,e,arguments.length)}}),k.each(["top","left"],function(e,n){k.cssHooks[n]=ze(y.pixelPosition,function(e,t){if(t)return t=_e(e,n),$e.test(t)?k(e).position()[n]+"px":t})}),k.each({Height:"height",Width:"width"},function(a,s){k.each({padding:"inner"+a,content:s,"":"outer"+a},function(r,o){k.fn[o]=function(e,t){var n=arguments.length&&(r||"boolean"!=typeof e),i=r||(!0===e||!0===t?"margin":"border");return _(this,function(e,t,n){var r;return x(e)?0===o.indexOf("outer")?e["inner"+a]:e.document.documentElement["client"+a]:9===e.nodeType?(r=e.documentElement,Math.max(e.body["scroll"+a],r["scroll"+a],e.body["offset"+a],r["offset"+a],r["client"+a])):void 0===n?k.css(e,t,i):k.style(e,t,n,i)},s,n?e:void 0,n)}})}),k.each("blur focus focusin focusout resize scroll click dblclick mousedown mouseup mousemove mouseover mouseout mouseenter mouseleave change select submit keydown keypress keyup contextmenu".split(" "),function(e,n){k.fn[n]=function(e,t){return 0<arguments.length?this.on(n,null,e,t):this.trigger(n)}}),k.fn.extend({hover:function(e,t){return this.mouseenter(e).mouseleave(t||e)}}),k.fn.extend({bind:function(e,t,n){return this.on(e,null,t,n)},unbind:function(e,t){return this.off(e,null,t)},delegate:function(e,t,n,r){return this.on(t,e,n,r)},undelegate:function(e,t,n){return 1===arguments.length?this.off(e,"**"):this.off(t,e||"**",n)}}),k.proxy=function(e,t){var n,r,i;if("string"==typeof t&&(n=e[t],t=e,e=n),m(e))return r=s.call(arguments,2),(i=function(){return e.apply(t||this,r.concat(s.call(arguments)))}).guid=e.guid=e.guid||k.guid++,i},k.holdReady=function(e){e?k.readyWait++:k.ready(!0)},k.isArray=Array.isArray,k.parseJSON=JSON.parse,k.nodeName=A,k.isFunction=m,k.isWindow=x,k.camelCase=V,k.type=w,k.now=Date.now,k.isNumeric=function(e){var t=k.type(e);return("number"===t||"string"===t)&&!isNaN(e-parseFloat(e))},"function"==typeof define&&define.amd&&define("jquery",[],function(){return k});var Qt=C.jQuery,Jt=C.$;return k.noConflict=function(e){return C.$===k&&(C.$=Jt),e&&C.jQuery===k&&(C.jQuery=Qt),k},e||(C.jQuery=C.$=k),k});
/* jQuery end */

/*
* Copyright MadCap Software
* http://www.madcapsoftware.com/
 * Unlicensed use is strictly prohibited
*
 * v16.0.7426.25547
*/
window.MadCap={};MadCap.CreateNamespace=function(c){var d=c.split(".");var e=MadCap;for(var a=0,b=d.length;a<b;a++){var c=d[a];if(c=="MadCap"){continue}if(typeof(e[c])!="undefined"){e=e[c];continue}e[c]={};e=e[c]}return e};if(!Object.create){Object.create=function(b){if(arguments.length>1){throw new Error("Object.create implementation only accepts the first parameter.")}function a(){}a.prototype=b;return new a()}}if(typeof String.prototype.trim!=="function"){String.prototype.trim=function(){return this.replace(/^\s+|\s+$/g,"")}}if(!Array.prototype.indexOf){Array.prototype.indexOf=function(a){var c=this.length>>>0;var b=Number(arguments[1])||0;b=(b<0)?Math.ceil(b):Math.floor(b);if(b<0){b+=c}for(;b<c;b++){if(b in this&&this[b]===a){return b}}return -1}}MadCap.Extend=function(a,b){b.prototype=Object.create(a.prototype);b.prototype.constructor=b;b.prototype.base=a.prototype};MadCap.Exception=function(b,a){this.Number=b;this.Message=a};MadCap.IsIOS=function(){return MadCap.String.Contains(navigator.userAgent,"iphone")||MadCap.String.Contains(navigator.userAgent,"ipad")};MadCap.IsIBooks=function(){return MadCap.HasEpubReadingSystem()&&navigator.epubReadingSystem.name=="iBooks"};MadCap.HasEpubReadingSystem=function(){return"epubReadingSystem" in navigator};MadCap.IsSafari=function(){return MadCap.String.Contains(navigator.userAgent,"safari")&&!MadCap.String.Contains(navigator.userAgent,"chrome")};(function(){var a=MadCap.CreateNamespace("String");a.IsNullOrEmpty=function(b){if(b==null){return true}if(b.length==0){return true}return false};a.StartsWith=function(c,d,b){if(d==null){return false}if(c.length<d.length){return false}var e=c;var f=d;if(!b){e=e.toLowerCase();f=f.toLowerCase()}if(e.substring(0,f.length)==f){return true}else{return false}};a.EndsWith=function(c,d,b){if(d==null){return false}if(c.length<d.length){return false}var e=c;var f=d;if(!b){e=e.toLowerCase();f=f.toLowerCase()}if(e.substring(e.length-f.length)==f){return true}else{return false}};a.Contains=function(e,f,b){var g=b?e:e.toLowerCase();if($.isArray(f)){for(var c=0,d=f.length;c<d;c++){var h=b?f[c]:f[c].toLowerCase();if(g.indexOf(h)!=-1){return true}}return false}var h=b?f:f.toLowerCase();return g.indexOf(h)!=-1};a.Trim=function(b){return a.TrimRight(a.TrimLeft(b))};a.TrimLeft=function(d){var b=0;var c=d.length;for(b=0;b<c&&d.charAt(b)==" ";b++){}return d.substring(b,d.length)};a.TrimRight=function(c){var b=0;for(b=c.length-1;b>=0&&c.charAt(b)==" ";b--){}return c.substring(0,b+1)};a.ToBool=function(d,c){var b=c;if(d!=null){var e=d.toLowerCase();if(e!="true"&&e!="false"&&e!="1"&&e!="0"&&e!="yes"&&e!="no"){throw new MadCap.Exception(-1,"The string can not be converted to a boolean value.")}b=e=="true"||e=="1"||e=="yes"}return b};a.ToInt=function(d,b){var c=b;if(d!=null){c=parseInt(d)}return c};a.ToDashed=function(b){return b.replace(/([A-Z])/g,function(c){return"-"+c.toLowerCase()})};a.LocaleCompare=function(d,e,c){if(c){if(typeof Intl!=="undefined"&&typeof Intl.Collator!=="undefined"){var b=new Intl.Collator(c);if(b){return b.compare(d,e)}}if(String.prototype.localeCompare){return d.localeCompare(e,c)}}return d<e?-1:d>e?1:0};a.Compare=function(g,h){var e=g.length;var f=h.length;for(var d=0;d<e&&d<f;d++){var b=g.charCodeAt(d);var c=h.charCodeAt(d);if(b<c){return -1}else{if(b>c){return 1}}}if(e<f){return -1}else{if(e>f){return 1}else{return 0}}};a.IsPunctuation=function(d){var b=d.charCodeAt(0);return(b>=33&&b<=35)||(b>=37&&b<=42)||(b>=44&&b<=47)||(b==58||b==59)||(b==63||b==64)||(b>=91&&b<=93)||(b==95)||(b==123)||(b==125)||(b==161)||(b==171)||(b==173)||(b==183)||(b==187)||(b==191)||(b==894)||(b==903)||(b>=1370&&b<=1375)||(b==1417||b==1418)||(b==1470)||(b==1472)||(b==1475)||(b==1478)||(b==1523||b==1524)||(b==1548||b==1549)||(b==1563)||(b==1566||b==1567)||(b>=1642&&b<=1645)||(b==1748)||(b>=1792&&b<=1805)||(b>=2039&&b<=2041)||(b==2404||b==2405)||(b==2416)||(b==3572)||(b>=3663&&b<=3675)||(b>=3844&&b<=3858)||(b>=3898&&b<=3901)||(b==3973)||(b==4048||b==4049)||(b>=4170&&b<=4175)||(b==4347)||(b>=4961&&b<=4968)||(b==5741||b==5742)||(b==5787||b==5788)||(b>=5867&&b<=5869)||(b==5941||b==5942)||(b>=6100&&b<=6102)||(b>=6104&&b<=6106)||(b>=6144&&b<=6154)||(b==6468||b==6469)||(b==6622||b==6623)||(b==6686||b==6687)||(b>=7002&&b<=7008)||(b>=8208&&b<=8231)||(b>=8240&&b<=8259)||(b>=8261&&b<=8273)||(b>=8275&&b<=8286)||(b==8317||b==8318)||(b==8333||b==8334)||(b==9001||b==9002)||(b>=10088&&b<=10101)||(b>=10181&&b<=10182)||(b>=10214&&b<=10219)||(b>=10627&&b<=10648)||(b>=10712&&b<=10715)||(b==10748||b==10749)||(b>=11513&&b<=11516)||(b==11518||b==11519)||(b>=11776&&b<=11799)||(b==11804||b==11805)||(b>=12289&&b<=12291)||(b>=12296&&b<=12305)||(b>=12308&&b<=12319)||(b==12336)||(b==12349)||(b==12448)||(b==12539)||(b>=43124&&b<=43127)||(b==64830||b==64831)||(b>=65040&&b<=65049)||(b>=65072&&b<=65106)||(b>=65108&&b<=65121)||(b==65123)||(b==65128)||(b==65130||b==65131)||(b>=65281&&b<=65283)||(b>=65285&&b<=65290)||(b>=65292&&b<=65295)||(b==65306||b==65307)||(b==65311||b==65312)||(b>=65339&&b<=65341)||(b==65343)||(b==65371)||(b==65373)||(b>=65375&&b<=65381)};a.Split=function(h,g){var e=h.length;var f=[];var b=-1,c=-1;for(var d=0;d<=e;d++){if(d==e||g(h.charAt(d))){if(b>-1){f.push(h.slice(b,c));b=-1}}else{if(b==-1){b=d}c=d+1}}return f}})();(function(){MadCap.CreateNamespace("DEBUG");var a=MadCap.DEBUG;a.Log={};a.Log.Create=function(){var c=document.createElement("div");c.setAttribute("id","DEBUG_Log");var f=document.createElement("div");$(f).addClass("MCDebugLogHeader");f.appendChild(document.createTextNode("Log Console"));c.appendChild(f);var b=document.createElement("div");$(b).addClass("MCDebugLogBody");c.appendChild(b);var e=document.createElement("div");$(e).addClass("MCDebugLogFooter");c.appendChild(e);document.body.appendChild(c);var d=new MadCap.DragDrop(c,f)};a.Log._LoadTime=new Date();a.Log.AddLine=function(f){if(parent!=window){MadCap.Utilities.MessageBus.PostMessageRequest(parent,"DEBUG-AddLine",[f],null);return}var e=document.getElementById("DEBUG_Log");if(e==null){return}var g=new Date();var h=g-a.Log._LoadTime;var c=document.createElement("p");$(c).addClass("MCDebugLogEntryTime");c.appendChild(document.createTextNode(h+"ms "+g.toLocaleTimeString()));var b=document.createElement("div");$(b).addClass("MCDebugLogEntry");b.appendChild(c);b.appendChild(document.createTextNode(f));var d=MadCap.Dom.GetElementsByClassName("MCDebugLogBody","div",e)[0];d.insertBefore(b,d.firstChild)}})();/*
 * Copyright MadCap Software
 * http://www.madcapsoftware.com/
 * Unlicensed use is strictly prohibited
 *
 * v16.0.7426.25547
 */
(function(){MadCap.CreateNamespace("Dom");var a=MadCap.Dom;a.Dataset=function(b,c){return b.getAttribute("data-"+MadCap.String.ToDashed(c))};a.GetElementsByClassName=function(b,j,h){j=j||"*";h=h||document;var g=new Array();var d=h.getElementsByTagName(j);for(var e=0,f=d.length;e<f;e++){var c=d[e];if($(c).hasClass(b)){g[g.length]=c}}return g};a.GetElementsByAttribute=function(b,c,k,j){k=k||"*";j=j||document;var h=new Array();var e=j.getElementsByTagName(k);for(var f=0,g=e.length;f<g;f++){var d=e[f];var l=a.GetAttribute(d,b);if(l==c){h[h.length]=d}}return h};a.GetChildNodeByTagName=function(f,g,d){var c=null;var e=-1;for(var b=f.firstChild;b!=null;b=b.nextSibling){if(b.nodeName.toLowerCase()==g.toLowerCase()){e++;if(e==d){c=b;break}}}return c};a.GetAncestorNodeByTagName=function(d,f,e){e=e||document.body;var c=null;var b=d.parentNode;while(b!=null&&b!=e){if(b.nodeName.toLowerCase()==f.toLowerCase()){c=b;break}b=b.parentNode}return c};a.GetAttribute=function(c,b){var e=c.getAttribute(b);if(e==null){e=c.getAttribute(b.toLowerCase());if(e==null){var d=b.indexOf(":");if(d!=-1){e=c.getAttribute(b.substring(d+1,b.length))}}}return e};a.GetAttributeInt=function(e,b,c){var d=c;var f=a.GetAttribute(e,b);if(f!=null){d=parseInt(f)}return d};a.GetAttributeBool=function(e,b,d){var c=d;var f=a.GetAttribute(e,b);if(f!=null){c=MadCap.String.ToBool(f,d)}return c};a.GetScrollPosition=function(){var b=0;var c=0;if(typeof(window.pageYOffset)!="undefined"){b=window.pageXOffset;c=window.pageYOffset}else{if(typeof(document.documentElement.scrollTop)!="undefined"&&document.documentElement.scrollTop>0){b=document.documentElement.scrollLeft;c=document.documentElement.scrollTop}}return{X:b,Y:c}}})();/*
 * Copyright MadCap Software
 * http://www.madcapsoftware.com/
 * Unlicensed use is strictly prohibited
 *
 * v16.0.7426.25547
 */
(function(){MadCap.CreateNamespace("Utilities");MadCap.Utilities.Dictionary=function(e){this._Map=new Object();this._Overflows=new Array();this._Length=0;this._IgnoreCase=e==true};var b=MadCap.Utilities.Dictionary;b.prototype.GetLength=function(e){return this._Length};b.prototype.ForEach=function(e){var k=this._Map;for(var h in k){var n=k[h];var m=e(h,n);if(m!=undefined&&!m){return}}var l=this._Overflows;for(var f=0,j=l.length;f<j;f++){var g=l[f];var m=e(g.Key,g.Value);if(m!=undefined&&!m){return}}};b.prototype.GetItem=function(g){if(this._IgnoreCase){g=g.toLowerCase()}var f=null;if(typeof(this._Map[g])=="function"){var e=this.GetItemOverflowIndex(g);if(e>=0){f=this._Overflows[e].Value}}else{f=this._Map[g];if(typeof(f)=="undefined"){f=null}}return f};b.prototype.GetItemOverflowIndex=function(f){if(this._IgnoreCase){f=f.toLowerCase()}var h=this._Overflows;for(var e=0,g=h.length;e<g;e++){if(h[e].Key==f){return e}}return -1};b.prototype.Remove=function(f){if(this._IgnoreCase){f=f.toLowerCase()}if(typeof(this._Map[f])=="function"){var e=this.GetItemOverflowIndex(f);if(e>=0){this._Overflows.splice(e,1);this._Length--}}else{if(typeof(this._Map[f])!="undefined"){delete (this._Map[f]);this._Length--}}};b.prototype.Add=function(f,g){if(this._IgnoreCase){f=f.toLowerCase()}if(typeof(this._Map[f])=="function"){var e=this.GetItem(f);if(e!=null){this.Remove(f)}this._Overflows[this._Overflows.length]={Key:f,Value:g}}else{this._Map[f]=g}this._Length++};b.prototype.AddUnique=function(e,g){if(this._IgnoreCase){e=e.toLowerCase()}var f=this.GetItem(e);if(typeof(f)=="undefined"||!f){this.Add(e,g)}};MadCap.Utilities.DateTime=function(g){var f=/\/Date\(([0-9]+)\)\//i;var e=f.exec(g);if(e!=null){this.Date=new Date(parseInt(e[1]))}else{this.Date=new Date(g)}};var a=MadCap.Utilities.DateTime;a.Months=["Jan","Feb","Mar","Apr","May","Jun","Jul","Aug","Sep","Oct","Nov","Dec"];MadCap.Utilities.TimeSpan=function(e,f){if(typeof e=="undefined"){e=new Date()}if(typeof f=="undefined"){f=new Date()}if(e>f){this.FromDate=f;this.ToDate=e}else{this.FromDate=e;this.ToDate=f}this.Ticks=this.ToDate-this.FromDate;this.Seconds=this.Ticks/1000;this.Minutes=this.Seconds/60;this.Hours=this.Minutes/60;this.Days=this.Hours/24};var c=MadCap.Utilities.TimeSpan;c.prototype.ToDurationString=function(){if(this.Minutes<1){return"Just now"}if(this.Hours<1){return parseInt(this.Minutes)+" minutes ago"}if(this.Days<1){return parseInt(this.Hours)+" hours ago"}if(this.Days<30){return parseInt(this.Days)+" days ago"}var e=a.Months[this.FromDate.getMonth()]+" "+this.FromDate.getDate();if(this.FromDate.getFullYear()!=this.ToDate.getFullYear()){e+=", "+this.FromDate.getFullYear()}return e};MadCap.Utilities.Url=function(g){var f=this;var e=/^(?:([A-Za-z]+):)?(\/{0,3})([0-9.\-A-Za-z]+)(?::(\d+))?(?:\/([^?#]*))?(?:\?([^#]*))?(?:#(.*))?$/;this._Segments=[];this.FullPath=null;this.Path=null;this.PlainPath=null;this.Name=null;this.Extension=null;this.NameWithExtension=null;this.FullFragment=null;this.Fragment=null;this.Query=null;this.Origin=null;this.LocalPath=null;this.IsAbsolute=false;this.IsRootRelative=false;this.IsFolder=false;this.QueryMap=new MadCap.Utilities.Dictionary(true);this.HashMap=new MadCap.Utilities.Dictionary(true);(function(){var i="";var k="";var v="";var p="";var j=g.indexOf("#");var w=g.indexOf("?");if(j!=-1){k=g.substring(j);if(j>w){i=g.substring(j)}else{i=g.substring(j,w)}}if(w!=-1){if(w>j){v=g.substring(w)}else{v=g.substring(w,j)}}var u=j>-1?(w>-1?Math.min(j,w):j):w;var t=g.substring(0,u==-1?g.length:u);u=t.lastIndexOf("/");var s=t.substring(0,u+1);var o=t.substring(u+1);u=o.lastIndexOf(".");var n=o.substring(0,u);var h=o.substring(u+1);var x="";u=t.indexOf(":");if(u>=0){x=t.substring(0,u)}var m=!MadCap.String.IsNullOrEmpty(x);if(!MadCap.String.IsNullOrEmpty(g)){var z=g;if(MadCap.String.EndsWith(z,"/")){z=z.substring(0,z.length-1)}f._Segments=z.split("/");if(m){var r=g.match(e);if(r){if(r[4]){p=r[1]+":"+r[2]+r[3]+":"+r[4]}else{p=r[1]+":"+r[2]+r[3]}f.Origin=p}}f.LocalPath=g.substring(p.length)}f.FullPath=g;f.Path=s;f.PlainPath=t;f.Name=n;f.Extension=h;f.NameWithExtension=o;f.Scheme=x;f.IsAbsolute=m;f.IsRootRelative=MadCap.String.StartsWith(t,"/",false);f.IsFolder=MadCap.String.EndsWith(t,"/");f.FullFragment=k;f.Fragment=i;f.Query=v;var y=f.Query;if(!MadCap.String.IsNullOrEmpty(y)){y=y.substring(1);y=y.replace(/\+/g," ");q(y,"&",f.QueryMap)}var l=f.Fragment;if(!MadCap.String.IsNullOrEmpty(l)){l=l.substring(1);q(l,"&",f.HashMap)}function q(D,A,G){var I=D.split(A);for(var B=0,F=I.length;B<F;B++){var H=I[B];var C=H.indexOf("=");var E=null;var J=null;if(C>=0){E=decodeURIComponent(H.substring(0,C));J=decodeURIComponent(H.substring(C+1))}else{E=H}G.Add(E,J)}}})()};var d=MadCap.Utilities.Url;d.GetDocumentUrl=function(){return new d(document.location.href)};d.GetAbsolutePath=function(f){var e=d.GetDocumentUrl();var g=new MadCap.Utilities.Url(e.PlainPath);if(!g.IsFolder){g=g.ToFolder()}return g.CombinePath(f).FullPath};d.StripInvalidCharacters=function(e){return e.replace(/(javascript:|data:|[<>])/gi,"")};d.SanitizeHash=function(){var e=MadCap.Utilities.Url.CurrentHash();if(e){var f=decodeURIComponent(e.slice(1));var g=MadCap.Utilities.Url.StripInvalidCharacters(f);if(f!=g){document.location.hash=encodeURI(g)}}};d.ReplaceReservedCharacters=function(j,g){var h=/[ ()&;,!'$]/;var e=j.split("");for(var f=0;f<e.length;f++){if(e[f].charCodeAt(0)>127||e[f].match(h)){e[f]=g}}return e.join("")};d.Navigate=function(e){document.location=d.StripInvalidCharacters(e)};d.GenerateNavigateTopicPath=function(g){var e=g.IsRootRelative?g.PlainPath:d.GetAbsolutePath(g.PlainPath);var f=d.GetDocumentUrl().QueryMap.GetItem("skinName")||g.QueryMap.GetItem("skinName");if(f!=null){e+=("?skinName="+f)}if(g.FullFragment.indexOf("#search-")==0){e+=g.FullFragment}else{if(g.QueryMap.GetLength()>0){e+=(f==null)?"?":"&";g.QueryMap.ForEach(function(h,j){var i=["skinName","highlight"];if(j&&i.indexOf(h)==-1){e+=(h+"="+encodeURIComponent(j)+"&")}});e=e.slice(0,-1)}e+=g.Fragment}return e};d.NavigateTopic=function(f){var e=d.GenerateNavigateTopicPath(f);d.Navigate(e)};d.OnNavigateTopic=function(f){var g=$(this).attr("href");if(typeof g!="undefined"){var j=new d(g);if(!MadCap.String.IsNullOrEmpty(g)&&!j.IsAbsolute&&j.PlainPath){var h=d.GenerateNavigateTopicPath(j);var i=new MadCap.Utilities.Url(h);var g=new MadCap.Utilities.Url(document.location.href);if(decodeURI(i.PlainPath)==decodeURI(g.PlainPath)&&j.HashMap.GetLength()>0){d.NavigateHash(j.Fragment);$(window).trigger("hashchange");f.preventDefault()}else{if(h!=d.GetAbsolutePath(j.PlainPath)){MadCap.Utilities.PreventDefault(f);d.Navigate(h)}}}else{if(j.HashMap.GetLength()>0&&j.Fragment!="#"){d.NavigateHash(j.Fragment);$(window).trigger("hashchange");f.preventDefault()}}}};d.NavigateHash=function(e){document.location.hash=d.StripInvalidCharacters(e)};d.CurrentHash=function(){return new MadCap.Utilities.Url(document.location.href).FullFragment};d.prototype.AddFile=function(h){if(typeof(h)=="string"){h=new d(h)}if(h.IsAbsolute){return h}var g=h.FullPath;if(g.charAt(0)=="/"){var f=document.location;var i=f.href.lastIndexOf(f.pathname);var j=f.href.substring(0,i);return new d(j+g)}var e=this.FullPath;if(!MadCap.String.EndsWith(e,"/")){e=e+"/"}return new d(e+g)};d.prototype.CombinePath=function(j){if(typeof(j)=="string"){j=new d(j)}if(j.IsAbsolute){throw new MadCap.Exception(-1,"Cannot combine two absolute paths.")}var h=j.FullPath;var n=j.FullPath.split("/");var e=this.FullPath;var l="";if(this.Origin&&j.IsRootRelative){return new d(this.Origin+h)}if(this.Scheme=="mk"){var k=e.indexOf("::");l=e.substring(0,k+"::".length);e=e.substring(k+"::".length)}for(var f=0,g=n.length;f<g;f++){var m=n[f];if(e.length>1&&MadCap.String.EndsWith(e,"/")){e=e.substring(0,e.length-1)}if(m=="."){e+="/"}else{if(m==".."){e=e.substring(0,e.lastIndexOf("/")+1)}else{if(e!=""&&!MadCap.String.EndsWith(e,"/")){e+="/"}e+=m}}}e=l+e;return new d(e)};d.prototype.ToQuery=function(f){var e=this.PlainPath+"?"+f+this.Fragment;return new d(e)};d.prototype.ToFolder=function(){var e=this.PlainPath;if(MadCap.String.EndsWith(e,"/")){e=e.substring(0,e.length-1)}var g=e.lastIndexOf("/");var f=e.substring(0,g+1);return new d(f)};d.prototype.ToRelative=function(k){if(typeof(k)=="string"){k=new d(k)}if(this.IsAbsolute!=k.IsAbsolute){return this}var e=0;var g=k._Segments.length;for(;e<g;e++){var m=this._Segments[e];var n=k._Segments[e];if(m!=n){break}}var l="";var h=MadCap.String.EndsWith(k.FullPath,"/")?0:1;for(var f=0;f<g-e-h;f++){l+="../"}for(var f=e;f<this._Segments.length;f++){if(f>e){l+="/"}l+=this._Segments[f]}return new d(l)};d.prototype.ToExtension=function(f){var h=this.FullPath;var i=h.lastIndexOf(".");var e=h.substring(0,i);var g=e+"."+f;return new d(g)};d.prototype.ToScheme=function(f){var g=this.FullPath;pos=g.indexOf(":");if(pos<0){return this}var e=f+":"+g.substring(pos);return new d(e)};d.prototype.ToPath=function(){return new d(this.Path)};d.prototype.ToPlainPath=function(){return new d(this.PlainPath)};d.prototype.ToNoQuery=function(){return new d(this.PlainPath+this.Fragment)};d.prototype.ToNoFragment=function(){return new d(this.PlainPath+this.Query)};MadCap.Utilities.PreventDefault=function(f){f.preventDefault?f.preventDefault():event.returnValue=false};MadCap.Utilities.EncodeHtml=function(e){var f=document.createElement("textarea");f.textContent=e;return f.innerHTML};MadCap.Utilities.DecodeHtml=function(e){var f=document.createElement("textarea");f.innerHTML=e;return f.textContent};MadCap.Utilities.GenerateRandomGUID=function(){return"xxxxxxxx-xxxx-4xxx-yxxx-xxxxxxxxxxxx".replace(/[xy]/g,function(e){var f=Math.random()*16|0,g=e=="x"?f:(f&3|8);return g.toString(16)})};MadCap.Utilities.AsyncForeach=function(e,g,f){e=e.slice(0);function h(){var i=e.shift();g(i,function(j){if(e.length>0){h()}else{f()}})}if(e.length>0){h()}else{f()}};MadCap.Utilities.CopyToClipboard=function(e){var f=$("<div>");var g=f.html(e.html().replace(/<br>/g,"\n")).text();f=$("<textarea>");e.parent().append(f);f.val(g).select();document.execCommand("copy");f.remove()};MadCap.Utilities.Now=Date.now||function(){return new Date().getTime()};MadCap.Utilities.Has=function(f,e){return f!=null&&Object.prototype.hasOwnProperty.call(f,e)};MadCap.Utilities.CreateEvent=function(f,g){var e;if(typeof(CustomEvent)==="function"){e=new CustomEvent(f,g)}else{e=document.createEvent("Event");e.initEvent(f,true,true);for(var h in g){e[h]=g[h]}}return e};MadCap.Utilities.Debounce=function(g,m,h){var k,e,f,l,j;var i=function(){var n=MadCap.Utilities.Now()-l;if(n<m&&n>0){k=setTimeout(i,m-n)}else{k=null;if(!h){j=g.apply(f,e);if(!k){f=e=null}}}};return function(){f=this;e=arguments;l=MadCap.Utilities.Now();var n=h&&!k;if(!k){k=setTimeout(i,m)}if(n){j=g.apply(f,e);f=e=null}return j}};MadCap.Utilities.Memoize=function(e,f){var g=function(j){var i=g.cache;var h=""+(f?f.apply(this,arguments):j);if(!MadCap.Utilities.Has(i,h)){i[h]=e.apply(this,arguments)}return i[h]};g.cache={};return g};MadCap.Utilities.Get=function(h,i,e){var j=undefined;if(h!=null){i=i.split(".");var f=0,g=i.length;while(h!=null&&f<g){h=h[i[f++]]}j=(f&&f==g)?h:undefined}return j===undefined?e:j};MadCap.Utilities.IsRuntimeFileType=function(e){return MadCap.Dom.Dataset(document.documentElement,"mcRuntimeFileType")==e};MadCap.Utilities.HasRuntimeFileType=function(f){var e=MadCap.Dom.Dataset(document.documentElement,"mcRuntimeFileType");return e&&e.split(";").indexOf(f)>-1};MadCap.Utilities.CreateStylesheet=function(f,g){var e=f||document,i;var h=e.createElement("style");if(g){h.setAttribute("media",g)}e.getElementsByTagName("head")[0].appendChild(h);i=e.styleSheets[e.styleSheets.length-1];return i};MadCap.Utilities.AsyncForeachParallel=function(e,h,f){var g=0;if(e.length===0){f()}var k=e.length;for(var j=0;j<k;j++){h(e[j],function(){g++;if(g===e.length){f()}})}};MadCap.Utilities.FixLink=function(f,j,i,e){var h=f;var g=new MadCap.Utilities.Url(f);if(!g.IsAbsolute&&g.Fragment!=g.FullPath){g=j.CombinePath(g);h=g.FullPath;if(!MadCap.String.IsNullOrEmpty(i)&&e!=null){g=g.ToRelative(e);h=i+g.FullPath}}return h};MadCap.Utilities.FixLinks=function(i,k,h,f){var j=["href","src","cite","data","data-mc-topics","poster"];var g=["href","data-mc-topics"];var l="["+j.join("],[")+"]";var e=$(i);e.find(l).each(function(){var m=$(this).hasClass("MCPopupThumbnailPopup")||$(this).hasClass("MCPopupThumbnailHover")||$(this).hasClass("MCTopicPopup");var o=!m;var n=false;$.each(this.attributes,function(r,p){var t=o&&g.indexOf(p.name)>-1?h:"";if(p.name==="data-mc-topics"){var w=p.value;var v=w?w.split("||"):null;if(v){for(var s=0;s<v.length;s++){var u=v[s].split("|");u[1]=MadCap.Utilities.FixLink(u[1],k,t,f);v[s]=u.join("|")}p.value=v.join("||")}}else{if(j.indexOf(p.name)>-1){var q=MadCap.Utilities.FixLink(p.value,k,t,f);if(q!==p.value){p.value=q;n=true}}}});if(n){$(this).attr("data-mc-processed-link",true)}});return e};MadCap.Utilities.IsRTL=function(){return $("html").css("direction")==="rtl"};MadCap.Utilities.IsTouchDevice=function(){var e=false;(function(f){if(/(android|bb\d+|meego).+mobile|avantgo|bada\/|blackberry|blazer|compal|elaine|fennec|hiptop|iemobile|ip(hone|od)|iris|kindle|lge |maemo|midp|mmp|mobile.+firefox|netfront|opera m(ob|in)i|palm( os)?|phone|p(ixi|re)\/|plucker|pocket|psp|series(4|6)0|symbian|treo|up\.(browser|link)|vodafone|wap|windows ce|xda|xiino|android|ipad|playbook|silk/i.test(f)||/1207|6310|6590|3gso|4thp|50[1-6]i|770s|802s|a wa|abac|ac(er|oo|s\-)|ai(ko|rn)|al(av|ca|co)|amoi|an(ex|ny|yw)|aptu|ar(ch|go)|as(te|us)|attw|au(di|\-m|r |s )|avan|be(ck|ll|nq)|bi(lb|rd)|bl(ac|az)|br(e|v)w|bumb|bw\-(n|u)|c55\/|capi|ccwa|cdm\-|cell|chtm|cldc|cmd\-|co(mp|nd)|craw|da(it|ll|ng)|dbte|dc\-s|devi|dica|dmob|do(c|p)o|ds(12|\-d)|el(49|ai)|em(l2|ul)|er(ic|k0)|esl8|ez([4-7]0|os|wa|ze)|fetc|fly(\-|_)|g1 u|g560|gene|gf\-5|g\-mo|go(\.w|od)|gr(ad|un)|haie|hcit|hd\-(m|p|t)|hei\-|hi(pt|ta)|hp( i|ip)|hs\-c|ht(c(\-| |_|a|g|p|s|t)|tp)|hu(aw|tc)|i\-(20|go|ma)|i230|iac( |\-|\/)|ibro|idea|ig01|ikom|im1k|inno|ipaq|iris|ja(t|v)a|jbro|jemu|jigs|kddi|keji|kgt( |\/)|klon|kpt |kwc\-|kyo(c|k)|le(no|xi)|lg( g|\/(k|l|u)|50|54|\-[a-w])|libw|lynx|m1\-w|m3ga|m50\/|ma(te|ui|xo)|mc(01|21|ca)|m\-cr|me(rc|ri)|mi(o8|oa|ts)|mmef|mo(01|02|bi|de|do|t(\-| |o|v)|zz)|mt(50|p1|v )|mwbp|mywa|n10[0-2]|n20[2-3]|n30(0|2)|n50(0|2|5)|n7(0(0|1)|10)|ne((c|m)\-|on|tf|wf|wg|wt)|nok(6|i)|nzph|o2im|op(ti|wv)|oran|owg1|p800|pan(a|d|t)|pdxg|pg(13|\-([1-8]|c))|phil|pire|pl(ay|uc)|pn\-2|po(ck|rt|se)|prox|psio|pt\-g|qa\-a|qc(07|12|21|32|60|\-[2-7]|i\-)|qtek|r380|r600|raks|rim9|ro(ve|zo)|s55\/|sa(ge|ma|mm|ms|ny|va)|sc(01|h\-|oo|p\-)|sdk\/|se(c(\-|0|1)|47|mc|nd|ri)|sgh\-|shar|sie(\-|m)|sk\-0|sl(45|id)|sm(al|ar|b3|it|t5)|so(ft|ny)|sp(01|h\-|v\-|v )|sy(01|mb)|t2(18|50)|t6(00|10|18)|ta(gt|lk)|tcl\-|tdg\-|tel(i|m)|tim\-|t\-mo|to(pl|sh)|ts(70|m\-|m3|m5)|tx\-9|up(\.b|g1|si)|utst|v400|v750|veri|vi(rg|te)|vk(40|5[0-3]|\-v)|vm40|voda|vulc|vx(52|53|60|61|70|80|81|83|85|98)|w3c(\-| )|webc|whit|wi(g |nc|nw)|wmlb|wonu|x700|yas\-|your|zeto|zte\-/i.test(f.substr(0,4))){e=true}})(navigator.userAgent||navigator.vendor||window.opera);return e};MadCap.Utilities.IsIE=function(){var e=window.navigator.userAgent;return e.indexOf("MSIE ")>0||e.indexOf("Trident/")>0};MadCap.Utilities.IsMicroContentTopic=function(){return $("meta[value='micro-content']").length>0};MadCap.Utilities.ToggleButtonState=function(f){var e=$(f);var g=e.attr("data-current-state")||"1";var h=g=="1"?2:1;MadCap.Utilities.SetButtonState(f,h)};MadCap.Utilities.SetButtonState=function(g,l){var e=$(g);var h=l==1?2:1;var m=e.attr("data-state"+l+"-class");var i=e.attr("data-state"+h+"-class");e.attr("data-current-state",l);e.removeClass(i).addClass(m);e.attr("title",e.attr("data-state"+l+"-title"));var f=e.children("img");f.attr("alt",f.attr("data-state"+l+"-alt"));if(MadCap.Utilities.HasRuntimeFileType("SkinPreview")){var k=e.attr("data-mc-style2");if(k){var j=e.attr("data-mc-style1");if(!j){j=e.attr("data-mc-style");e.attr("data-mc-style1",MadCap.Utilities.EncodeHtml(j))}e.attr("data-mc-style",l==1?j:k)}}};MadCap.Utilities.LoadHandlers=Object.create(null);MadCap.Utilities.InitContent=function(e){for(var f in MadCap.Utilities.LoadHandlers){MadCap.Utilities.LoadHandlers[f](e)}};MadCap.Utilities.LoadScript=function(g,f,e){var h=document.createElement("script");h.src=g;h.type="text/javascript";if(h.addEventListener){$(h).on("error",e);$(h).on("load",f)}else{if(h.readyState){h.onreadystatechange=function(){if(h.readyState=="loaded"||h.readyState=="complete"){f()}}}}document.getElementsByTagName("head")[0].appendChild(h);return h};MadCap.Utilities.LoadRegisteredScript=function(k,j,i,e){var f=false;var l;$("script").each(function(m,n){var o=$(n).attr("src");if(!MadCap.String.IsNullOrEmpty(o)&&o.toLowerCase()==k.toLowerCase()){f=true;l=n}});if(f){var h=new MadCap.Utilities.Url(k).Name;var g=MadCap.Utilities.LoadHandlers[h];if(g){g(e)}j()}};MadCap.Utilities.LoadScripts=function(h,g,f,e){MadCap.Utilities.AsyncForeach(h,function(j,i){if(!MadCap.String.IsNullOrEmpty(j)){MadCap.Utilities.LoadRegisteredScript(j,i,f,e)}else{i()}},g)};MadCap.Utilities.DynamicStylesheets=Object.create(null);MadCap.Utilities.LoadStylesheets=function(f,e){$.each(f,function(h,g){if(!MadCap.String.IsNullOrEmpty(g)){MadCap.Utilities.LoadStylesheet(g,e)}})};MadCap.Utilities.LoadStylesheet=function(g,h){var e=false;$("link").each(function(k,l){var m=$(l).attr("href");if(!MadCap.String.IsNullOrEmpty(m)&&m.toLowerCase()===g.toLowerCase()){e=true}});if(!e){var i='<link rel="stylesheet" type="text/css" href="{0}" data-mc-dynamic="true" />';i=i.replace("{0}",g);var f=$("head")[0];var j=h?$(i).insertAfter(h):$(i).appendTo(f);MadCap.Utilities.DynamicStylesheets[g]=j}};MadCap.Utilities.UpdateDynamicStylesheets=function(e){MadCap.Utilities.RemoveDynamicStylesheets();for(var f=0;f<e.length;f++){MadCap.Utilities.LoadStylesheet(e[f])}};MadCap.Utilities.RemoveDynamicStylesheets=function(){$.each(MadCap.Utilities.DynamicStylesheets,function(e,f){$(f).remove()});MadCap.Utilities.DynamicStylesheets=Object.create(null)};MadCap.Utilities.CombineRelevancy=function(g,h){var e=MadCap.Utilities.CapNumber(g,h,16,0,2);for(var f=2;f<7;f++){e=MadCap.Utilities.CapNumber(e,h,16,f,1)}e=MadCap.Utilities.CapNumber(e,h,16,7,1,7);return e};MadCap.Utilities.CalculateScore=function(g,e,f){return(Math.log(g)/Math.log(2147483647)*f)+(e*(1-f))};MadCap.Utilities.CapNumber=function(k,l,e,m,g,h){if(!h){h=Math.pow(e,g)-1}var f=Math.pow(e,m);var j=f*Math.pow(e,g);var n=~~(k%j/f);var o=~~(l%j/f);var i=Math.min(n+o,h);return k+((i-n)*f)};MadCap.Utilities.Require=function(h,i){if(!MadCap.Utilities._requireCache){MadCap.Utilities._requireCache=Object.create(null)}var e=MadCap.Utilities._requireCache;var g=h[0];var f=e[g];if(f&&f.data){i(f.data)}else{if(f&&f.callbacks){f.callbacks.push(i)}else{e[g]={callbacks:[i]};require([g],function(j){f=e[g];f.data=j;for(var k=0;k<f.callbacks.length;k++){f.callbacks[k](j)}f.callbacks=null;require.undef(g)})}}};MadCap.Utilities.GetChunkId=function(e,j,g){for(var h=0;h<e.length;h++){var k=e[h];var f=g(j,k);if(f===0){return h}else{if(f===-1){return h-1}}}return e.length-1};MadCap.Utilities.GetChunkIds=function(f,l,h){var e=[];var j=false;for(var k=0;k<f.length;k++){var m=f[k];var g=h(l,m);if(g===-1&&k===0){return e}if(g===0){if(k>0&&!j){e.push(k-1)}e.push(k);j=true}else{if(g===-1){if(k>0&&!j){e.push(k-1)}break}}}if(e.length===0){e.push(f.length-1)}return e};MadCap.Utilities.ClearRequireCache=function(){MadCap.Utilities._requireCache=null};MadCap.Utilities.StopWords=Array("a","an","the","to","of","is","for","and","or","do","be","by","he","she","on","in","at","it","not","no","are","as","but","her","his","its","non","only","than","that","then","they","this","we","were","which","with","you","into","about","after","all","also","been","can","come","from","had","has","have","me","made","many","may","more","most","near","over","some","such","their","there","these","under","use","was","when","where","against","among","became","because","between","during","each","early","found","however","include","late","later","med","other","several","through","until","who","your");MadCap.Utilities.Store=(function(){try{if(window.localStorage){return window.localStorage}}catch(g){if(console&&console.log){console.log("window.localStorage not available")}}var i="MadCap";var f=document.createElement("div");f.style.display="none";document.getElementsByTagName("head")[0].appendChild(f);if(typeof f.addBehavior=="function"){f.addBehavior("#default#userdata");f.load(i);return{getItem:function(e){return f.XMLDocument.documentElement.getAttribute(e)},setItem:function(e,j){f.XMLDocument.documentElement.setAttribute(e,j);f.save(i)},removeItem:function(e){f.removeAttribute(e);f.save(i)}}}var h="data-"+i+"-";return{getItem:function(e){var j=f.getAttribute(h+e);return j?decodeURIComponent(j):j},setItem:function(e,j){f.setAttribute(h+e,j?encodeURIComponent(j):null)},removeItem:function(e){f.removeAttribute(h+e)}}})();MadCap.Utilities.SanitizeHtml=function(e){return DOMPurify.sanitize(e,{SAFE_FOR_JQUERY:true,ALLOWED_URI_REGEXP:/^(?:(?:(?:f|ht)tps?|mailto|file):|[^a-z]|[a-z+.\-]+(?:[^a-z+.\-:]|$))/i,ADD_TAGS:["embed","iframe","object","param","madcap:conditionaltext"],ADD_ATTR:["abbr","accesskey","allowfullscreen","autoplay","classid","codebase","data","dirname","form","frameborder","kind","longdesc","muted","pluginspage","rules","sandbox","sorted","target","translate","wmode"]})}})();Array.prototype.Remove=function(a){if(a<0||a>this.length){throw"Index out of bounds."}this.splice(a,1)};Array.prototype.RemoveValue=function(b){for(var a=this.length-1;a>=0;a--){if(this[a]==b){this.Remove(a)}}};Array.prototype.Union=function(c){var a=[].concat(this);if(c){for(var b=0;b<c.length;b++){if(this.indexOf(c[b])===-1){a.push(c[b])}}}return a};Array.prototype.Intersect=function(c){var a=[];for(var b=0;b<c.length;b++){if(this.indexOf(c[b])!==-1){a.push(c[b])}}return a};/*
 * Copyright MadCap Software
 * http://www.madcapsoftware.com/
 * Unlicensed use is strictly prohibited
 *
 * v16.0.7426.25547
 */
(function(){MadCap.Utilities.Xhr=function(b,d,c){var e=this;this._XmlDoc=null;this._XmlHttp=null;this._Args=b;this._LoadFunc=d;this._LoadContextObj=c;this.OnreadystatechangeLocal=function(){if(e._XmlDoc.readyState==4){e._XmlDoc.onreadystatechange=a._Noop;var f=null;if(e._XmlDoc.documentElement!=null){f=e._XmlDoc}if(e._LoadContextObj==null){e._LoadFunc(f,e._Args)}else{e._LoadFunc.call(e._LoadContextObj,f,e._Args)}}};this.OnreadystatechangeRemote=function(){if(e._XmlHttp.readyState==4){e._XmlHttp.onreadystatechange=a._Noop;var f=null;if(e._XmlHttp.responseXML!=null&&e._XmlHttp.responseXML.documentElement!=null){f=e._XmlHttp.responseXML}if(e._LoadContextObj==null){e._LoadFunc(f,e._Args)}else{e._LoadFunc.call(e._LoadContextObj,f,e._Args)}}}};var a=MadCap.Utilities.Xhr;a.prototype._LoadLocal=function(d,b){if(window.ActiveXObject){this._XmlDoc=a._GetMicrosoftXmlDomObject();this._XmlDoc.async=b;if(this._LoadFunc){this._XmlDoc.onreadystatechange=this.OnreadystatechangeLocal}try{if(!this._XmlDoc.load(d)){this._XmlDoc=null}}catch(c){this._XmlDoc=null}}else{if(window.XMLHttpRequest){this._LoadRemote(d,b)}}return this._XmlDoc};a.prototype._LoadRemote=function(d,b){this._XmlHttp=a._GetXhrObject();if(this._LoadFunc){this._XmlHttp.onreadystatechange=this.OnreadystatechangeRemote}try{this._XmlHttp.open("GET",d,b);this._XmlHttp.send(null);if(!b&&(this._XmlHttp.status==0||this._XmlHttp.status==200)){this._XmlDoc=this._XmlHttp.responseXML}}catch(c){this._XmlHttp.abort();if(this._LoadFunc){if(this._LoadContextObj==null){this._LoadFunc(null,this._Args)}else{this._LoadFunc.call(this._LoadContextObj,null,this._Args)}}}return this._XmlDoc};a.prototype.Load=function(e,b){var d=null;var c=document.location.protocol;if(c=="file:"||c=="mk:"||c=="ms-its:"||c=="app:"){d=this._LoadLocal(e,b)}else{if(c=="http:"||c=="https:"){d=this._LoadRemote(e,b)}}return d};a.LoadXmlString=function(d){var c=null;if(window.ActiveXObject){c=a._GetMicrosoftXmlDomObject();c.async=false;c.loadXML(d)}else{if(DOMParser){var b=new DOMParser();c=b.parseFromString(d,"text/xml")}}return c};a.CreateXmlDocument=function(b){var c="<"+b+" />";var d=a.LoadXmlString(c);return d};a.GetOuterXml=function(d){var c=null;if(window.ActiveXObject){c=d.xml}else{if(window.XMLSerializer){var b=new XMLSerializer();c=b.serializeToString(d)}}return c};a.ImportNode=function(b,c){if(typeof(b.importNode)=="function"){return b.importNode(c,true)}return c.cloneNode(true)};a.CallWebService=function(e,b,d,c){var g=new a(c,d,null);var f=g.Load(e,b);return f};a._MicrosoftXmlDomProgIDs=["Msxml2.DOMDocument.6.0","Msxml2.DOMDocument","Microsoft.XMLDOM"];a._MicrosoftXmlHttpProgIDs=["Msxml2.XMLHTTP.6.0","Msxml2.XMLHTTP","Microsoft.XMLHTTP"];a._MicrosoftXmlDomProgID=null;a._MicrosoftXmlHttpProgID=null;a._FilePathToXmlStringMap=new MadCap.Utilities.Dictionary();a._LoadingFilesPathMap=new MadCap.Utilities.Dictionary();a._LoadingFromQueue=false;a.ForceUseJS=false;a.Load=function(m,c,g,b,f){function i(){a._LoadingFilesPathMap.Remove(e.FullPath);var n=a._FilePathToXmlStringMap.GetItem(e.Name);if(n!=null){a._FilePathToXmlStringMap.Remove(e.Name);j=a.LoadXmlString(n)}a._LoadingFilesPathMap.ForEach(function(o,r){var q=new MadCap.Utilities.Url(o);var p=r;if(q.Name==d&&q.FullPath!=e.FullPath){a._LoadingFilesPathMap.Remove(q.FullPath);a._LoadingFromQueue=true;a.Load(q.FullPath,p.async,p.LoadFunc,p.args,p.loadContextObj);return false}return true});if(f==null){g(j,b)}else{g.call(f,j,b)}}var j=null;if(a.ForceUseJS||(Boolean(!window.ActiveXObject)&&MadCap.String.StartsWith(document.location.protocol,"file"))){var k=new MadCap.Utilities.Url(m);var e=k.ToExtension("js");var d=e.Name;a._LoadingFilesPathMap.Add(e.FullPath,{async:c,LoadFunc:g,args:b,loadContextObj:f});var h=false;a._LoadingFilesPathMap.ForEach(function(n,q){var p=new MadCap.Utilities.Url(n);var o=q;if(p.Name==d&&p.FullPath!=e.FullPath){h=true;return false}return true});if(a._LoadingFromQueue||!h){a._LoadingFromQueue=false;MadCap.Utilities.LoadScript(e.FullPath,i,i)}}else{var l=new a(b,g,f);j=l.Load(m,c)}return j};a._Noop=function(){};a._GetMicrosoftXmlDomObject=function(){var d=null;if(a._MicrosoftXmlDomProgID==null){for(var c=0;c<a._MicrosoftXmlDomProgIDs.length;c++){var e=a._MicrosoftXmlDomProgIDs[c];try{d=new ActiveXObject(e);a._MicrosoftXmlDomProgID=e;break}catch(b){}}}else{d=new ActiveXObject(a._MicrosoftXmlDomProgID)}return d};a._GetXhrObject=function(){if(window.XMLHttpRequest){return function(){return new window.XMLHttpRequest()}}else{if(window.ActiveXObject){return function(){var e=null;if(a._MicrosoftXmlHttpProgID==null){for(var c=0;c<a._MicrosoftXmlHttpProgIDs.length;c++){var d=a._MicrosoftXmlHttpProgIDs[c];try{e=new ActiveXObject(d);a._MicrosoftXmlHttpProgID=d;break}catch(b){}}}else{e=new ActiveXObject(a._MicrosoftXmlHttpProgID)}return e}}}}()})();/*
 * Copyright MadCap Software
 * http://www.madcapsoftware.com/
 * Unlicensed use is strictly prohibited
 *
 * v16.0.7426.25547
 */
MadCap.WebHelp=MadCap.CreateNamespace("WebHelp");MadCap.WebHelp.AliasFile=function(i,c,h){var g=null;var d=c;var f=null;var e=null;(function(){})();this.Load=function(j){MadCap.Utilities.Xhr.Load(i,true,function k(l){if(l){g=l.documentElement}j()})};this.GetIDs=function(){var j=new Array();a();e.ForEach(function(k,l){j[j.length]=k;return true});return j};this.GetNames=function(){var j=new Array();a();f.ForEach(function(k,l){j[j.length]=k;return true});return j};this.LookupID=function(k){var j=false;var o=null;var n=null;if(k){if(typeof(k)=="string"&&k.indexOf(".")!=-1){var m=k.indexOf("|");if(m!=-1){o=k.substring(0,m);n=k.substring(m+1)}else{o=k}j=true}else{var l=b(k);if(l!=null){j=true;o=l.Topic;n=l.Skin}}}else{j=true}if(o){o=d.ContentFolder+o}return{Found:j,Topic:o,Skin:n}};function b(j){var k=null;a();if(f!=null){if(typeof(j)=="string"){k=f.GetItem(j);if(k==null){k=e.GetItem(j)}}else{if(typeof(j)=="number"){k=e.GetItem(j.toString())}}}return k}function a(){if(f==null){if(g){f=new MadCap.Utilities.Dictionary(true);e=new MadCap.Utilities.Dictionary();var l=g.getElementsByTagName("Map");for(var k=0;k<l.length;k++){var p=l[k].getAttribute("Link");var o=l[k].getAttribute("Skin");var j={Topic:p,Skin:o};var m=l[k].getAttribute("Name");if(m!=null){f.Add(m,j)}var n=l[k].getAttribute("ResolvedId");if(n!=null){e.Add(n,j)}}}}}};/*
 * Copyright MadCap Software
 * http://www.madcapsoftware.com/
 * Unlicensed use is strictly prohibited
 *
 * v16.0.7426.25547
 */
MadCap.WebHelp=MadCap.CreateNamespace("WebHelp");MadCap.WebHelp.HelpSystem=function(G,F,J,I,a){var z=this;var x=G;var y=new MadCap.Utilities.Url(J).ToFolder().ToFolder().FullPath;var j=null;var B=new Array();var D=I;var m=a;var t=null;var u=[];var v=new MadCap.Utilities.Dictionary();var n=null;var E=new MadCap.Utilities.Dictionary();var s=false;var k=new MadCap.WebHelp.AliasFile(y+"Data/Alias.xml",this);var C=new MadCap.WebHelp.TocFile(this,MadCap.WebHelp.TocFile.TocType.Toc);var w=null;var l=new MadCap.WebHelp.TocFile(this,MadCap.WebHelp.TocFile.TocType.BrowseSequence);var A=new MadCap.Utilities.Dictionary();this.TargetType=null;this.DefaultStartTopic=null;this.InPreviewMode=null;this.LiveHelpOutputId=null;this.LiveHelpServer=null;this.LiveHelpEnabled=false;this.IsWebHelpPlus=false;this.ContentFolder=null;this.UseCustomTopicFileExtension=false;this.CustomTopicFileExtension=null;this.IsMultilingual=false;this.GlossaryUrl=null;this.SearchFilterSetUrl=null;this.SyncTOC=null;this.IndexPartialWordSearch=true;this.GlossaryPartialWordSearch=true;this.DefaultSkin=null;this.IsAutoMerged=false;this.LanguageUrl=null;this.BreakpointsUrl=null;this.PreventExternalUrls=false;this.IsResponsive=false;this.SearchUrl=null;this.PulsePage=null;this.ScriptsFolderPath=null;this.LanguageCode=null;this.LanguageName=null;this.IncludeCSHRuntime=null;this.ShowMadCapBacklink=false;this.LiveHelpServerType=null;this.OutputAnalyticsServer=null;this.OutputAnalyticsId=null;this.IsCentralHosted=false;this.CentralLogoutLink=null;this.CentralSettingsLink=null;(function(){})();this.Load=function(K){MadCap.Utilities.Xhr.Load(J,true,function(ab){var P=0;function S(){P++;if(P==B.length){K()}}function Q(ae,ad){if(B.length>0){for(var ac=0;ac<B.length;ac++){B[ac].Load(ae)}}else{ad()}}s=ab!=null;if(!s){K();return}this.LanguageCode=ab.documentElement.getAttribute("xml:lang");this.LanguageName=ab.documentElement.getAttribute("LanguageName");this.TargetType=ab.documentElement.getAttribute("TargetType");this.DefaultStartTopic=ab.documentElement.getAttribute("DefaultUrl");this.InPreviewMode=MadCap.Dom.GetAttributeBool(ab.documentElement,"InPreviewMode",false);this.LiveHelpOutputId=ab.documentElement.getAttribute("LiveHelpOutputId");this.LiveHelpServer=ab.documentElement.getAttribute("LiveHelpServer");this.LiveHelpServerType=ab.documentElement.getAttribute("LiveHelpServerType");this.OutputAnalyticsServer=ab.documentElement.getAttribute("OutputAnalyticsServer");this.OutputAnalyticsId=ab.documentElement.getAttribute("OutputAnalyticsId");this.IsCentralHosted=MadCap.Dom.GetAttributeBool(ab.documentElement,"IsCentralHosted",false);this.CentralLogoutLink=ab.documentElement.getAttribute("CentralLogoutLink");this.CentralSettingsLink=ab.documentElement.getAttribute("CentralSettingsLink");if(this.LiveHelpServerType=="Central"){this.LiveHelpEnabled=this.OutputAnalyticsServer!=null}else{this.LiveHelpEnabled=this.LiveHelpOutputId!=null}this.MoveContentToRoot=MadCap.Dom.GetAttributeBool(ab.documentElement,"MoveOutputContentToRoot",false);this.ReplaceReservedCharacters=MadCap.Dom.GetAttributeBool(ab.documentElement,"ReplaceReservedCharacters",false);this.MakeFileLowerCase=MadCap.Dom.GetAttributeBool(ab.documentElement,"MakeFileLowerCase",false);this.PreventExternalUrls=MadCap.Dom.GetAttributeBool(ab.documentElement,"PreventExternalUrls",false);this.IsResponsive=MadCap.Dom.GetAttributeBool(ab.documentElement,"EnableResponsiveOutput",false);this.IncludeGlossarySearchResults=MadCap.Dom.GetAttributeBool(ab.documentElement,"IncludeGlossarySearchResults",true);this.ResultsPerPage=MadCap.Dom.GetAttributeInt(ab.documentElement,"ResultsPerPage",20);this.SearchEngine=MadCap.Dom.GetAttribute(ab.documentElement,"SearchEngine");this.IncludeCSHRuntime=MadCap.Dom.GetAttributeBool(ab.documentElement,"IncludeCSHRuntime",true);this.DebugMode=MadCap.Dom.GetAttributeBool(ab.documentElement,"DebugMode",false);if(this.SearchEngine=="Elasticsearch"){var N=ab.documentElement.getElementsByTagName("Elasticsearch");this.Elasticsearch=N.item(0)}var T=MadCap.Dom.GetAttributeBool(ab.documentElement,"ServerEnabled",false);this.IsWebHelpPlus=(this.TargetType=="WebHelpPlus"||T)&&MadCap.String.StartsWith(document.location.protocol,"http",false);var M="";if(!this.MoveContentToRoot){M="Content/"}if(this.MakeFileLowerCase){M=M.toLowerCase()}var R="MicroContent/";if(this.MakeFileLowerCase){R=R.toLowerCase()}this.ContentFolder=M;this.MicroContentFolder=R;this.UseCustomTopicFileExtension=MadCap.Dom.GetAttributeBool(ab.documentElement,"UseCustomTopicFileExtension",false);this.CustomTopicFileExtension=MadCap.Dom.GetAttribute(ab.documentElement,"CustomTopicFileExtension");this.IsMultilingual=MadCap.Dom.GetAttributeBool(ab.documentElement,"Multilingual",false);this.ShowMadCapBacklink=MadCap.Dom.GetAttributeBool(ab.documentElement,"ShowMadCapBacklink",false);this.GlossaryUrl=f(ab,"Glossary");this.TocUrl=f(ab,"Toc");this.SearchUrl=f(ab,"SearchUrl");this.PulsePage=f(ab,"PulsePage");this.BrowseSequencesUrl=f(ab,"BrowseSequence");this.IndexUrl=f(ab,"Index");this.SearchFilterSetUrl=f(ab,"SearchFilterSet");this.LanguageUrl=y+"Data/Language.js";this.BreakpointsUrl=y+"Data/Breakpoints.js";this.ScriptsFolderPath=ab.documentElement.getAttribute("PathToScriptsFolder");this.HasBrowseSequences=ab.documentElement.getAttribute("BrowseSequence")!=null;this.HasToc=ab.documentElement.getAttribute("Toc")!=null;this.TopNavTocPath=ab.documentElement.getAttribute("TopNavTocPath")=="true";this.LiveHelpServerType=ab.documentElement.getAttribute("LiveHelpServerType");this.OutputAnalyticsServer=ab.documentElement.getAttribute("OutputAnalyticsServer");b.call(this,ab);this.DefaultSkin=this.GetSkin($(ab.documentElement).attr("SkinID"));this.SyncTOC=this.DefaultSkin!=null&&MadCap.String.ToBool(this.DefaultSkin.AutoSyncTOC,false);this.IndexPartialWordSearch=this.DefaultSkin==null||MadCap.String.ToBool(this.DefaultSkin.IndexPartialWordSearch,true);this.GlossaryPartialWordSearch=this.DefaultSkin==null||MadCap.String.ToBool(this.DefaultSkin.GlossaryPartialWordSearch,true);this.DisplayCommunitySearchResults=this.DefaultSkin==null||MadCap.String.ToBool(this.DefaultSkin.DisplayCommunitySearchResults,true);this.CommunitySearchResultsCount=3;if(this.DefaultSkin!=null){this.CommunitySearchResultsCount=MadCap.String.ToInt(this.DefaultSkin.CommunitySearchResultsCount,3)}var W=ab.getElementsByTagName("Subsystems");if(W.length>0&&W[0].getElementsByTagName("Url").length>0){var aa=ab.getElementsByTagName("Subsystems")[0].getElementsByTagName("Url");for(var O=0;O<aa.length;O++){var Z=aa[O];if(!Z){continue}var Y=Z.getAttribute("Source");var V=Y.substring(0,Y.lastIndexOf("/")+1);var X=Z.getAttribute("TocPath");var L=Z.getAttribute("BrowseSequencePath");var U=new MadCap.WebHelp.HelpSystem(this,y+V,y+V+"Data/HelpSystem.xml",X,L);B.push(U)}}this.LoadBreakpoints(function(){z.LoadLanguage(function(){if(!z.IsAutoMerged&&z.IsWebHelpPlus){MadCap.Utilities.Xhr.CallWebService(z.GetPath()+"Service/Service.asmx/GetSubsystems",true,function(ad,ac){if(ad){$.each(ad.documentElement.childNodes,function(ae,af){if(af.nodeName=="Subsystems"){$.each(af.childNodes,function(ag,ah){if(ah.nodeName=="Url"){var ak=ah.getAttribute("Source");var aj=ak.substring(0,ak.lastIndexOf("/")+1);if(aj){var ai=new MadCap.WebHelp.HelpSystem(z,y+aj,y+aj+"Data/HelpSystem.xml",null,null);ai.IsAutoMerged=true;B.push(ai)}}})}})}Q(S,K)})}else{Q(S,K)}})})},null,this)};this.GetExists=function(){return s};this.GetMasterHelpSystem=function(){var L=this;for(var K=L.GetParentSubsystem();K!=null;K=K.GetParentSubsystem()){L=K}return L};this.GetParentSubsystem=function(){return x};this.GetPath=function(){return y};this.GetCurrentTopicPath=function(){return MadCap.Utilities.Url.GetDocumentUrl().ToRelative(MadCap.Utilities.Url.GetAbsolutePath(y)).FullPath};this.GetAbsolutePath=function(){if(j==null){var K=new MadCap.Utilities.Url(y);j=K.IsAbsolute?K.FullPath:new MadCap.Utilities.Url(document.location.href).Path}return j};this.GetContentPath=function(){return y+this.ContentFolder};this.GetSkin=function(K){return A.GetItem(K)};this.GetSkinByName=function(L){var N=this.GetSkins();for(var K=0;K<N.length;K++){var M=N[K];if(M.Name==L){return M}}return null};this.GetCurrentSkin=function(){var O=MadCap.Utilities.Url.GetDocumentUrl();var N=O.QueryMap.GetItem("skinName")||O.HashMap.GetItem("skinName");if(N){var M=this.GetSkin(N);if(!M){M=this.GetSkinByName(N)}return M}var K=O.QueryMap.GetItem("cshid");if(K){var L=k.LookupID(K);if(L.Skin){var M=this.GetSkin(L.Skin);if(!M){M=this.GetSkinByName(L.Skin)}return M}}return this.DefaultSkin};this.GetTocPath=function(K){return K=="toc"?D:m};this.GetFullTocPath=function(N,L){var M=this.GetHelpSystem(L);if(M==null){return null}var K=new Object();K.tocPath=this.GetTocPath(N);M.ComputeTocPath(N,K);return K.tocPath};this.GetTopicPath=function(N,M){var P=this.GetPath();var O=this.GetMasterHelpSystem();var L=(new MadCap.Utilities.Url(document.location.href)).ToPath();var K=L.CombinePath(P+"Data/").CombinePath(N);var Q=K.ToRelative(L);if(!M&&MadCap.Utilities.HasRuntimeFileType("TriPane")&&!O.MoveContentToRoot){Q=Q.ToRelative(O.ContentFolder)}return Q};this.GetTransparentImagePath=function(){var K=this.GetPath()+"Skins/Default/Stylesheets/Images/transparent.gif";return K};this.GetPatchedPath=function(K){if(this.ReplaceReservedCharacters){K=MadCap.Utilities.Url.ReplaceReservedCharacters(K,"_")}if(this.MakeFileLowerCase){K=K.toLowerCase()}if(this.UseCustomTopicFileExtension){K=new MadCap.Utilities.Url(K).ToExtension(this.CustomTopicFileExtension).FullPath}return K};this.GetAbsoluteTopicPath=function(M){var L=new MadCap.Utilities.Url(M);var K=(new MadCap.Utilities.Url(document.location.href)).ToPlainPath();return K.CombinePath(this.GetTopicPath("../"+L.FullPath).FullPath)};this.ComputeTocPath=function(M,L){if(x){var K=this.GetTocPath(M);if(!MadCap.String.IsNullOrEmpty(K)){L.tocPath=L.tocPath?K+"|"+L.tocPath:K}x.ComputeTocPath(M,L)}};this.GetHelpSystem=function(M){var K=null;for(var L=0;L<B.length;L++){K=B[L].GetHelpSystem(M);if(K!=null){return K}}if(MadCap.String.StartsWith(M,y,false)){return this}return null};this.GetSubsystem=function(K){return B[K]};this.GetMergedAliasIDs=function(K){k.Load(function(){function Q(S){for(var R=0,T=S.length;R<T;R++){P[P.length]=S[R]}L++;if(L==O+1){K(P)}}var P=new Array();var O=B.length;var L=0;var N=k.GetIDs();Q(N);for(var M=0;M<O;M++){B[M].GetMergedAliasIDs(Q)}})};this.GetMergedAliasNames=function(K){k.Load(function(){function Q(T){for(var R=0,S=T.length;R<S;R++){O[O.length]=T[R]}L++;if(L==N+1){K(O)}}var O=new Array();var N=B.length;var L=0;var P=k.GetNames();Q(P);for(var M=0,N=B.length;M<N;M++){B[M].GetMergedAliasNames(Q)}})};this.LookupCSHID=function(K,L){k.Load(function(){function R(S){if(O){return}M++;if(S.Found){O=true;L(S);return}if(M==Q){L(N)}}var N=k.LookupID(K);if(N.Found){N.Topic=z.GetPath()+N.Topic;L(N);return}if(B.length==0){L(N);return}var O=false;var M=0;for(var P=0,Q=B.length;P<Q;P++){B[P].LookupCSHID(K,R)}})};this.GetTocFile=function(){return C};this.GetBrowseSequenceFile=function(){return l};this.IsMerged=function(){return(B.length>0)};this.IsRoot=function(){return x==null};this.IsTabletLayout=function(K){return this.isGivenLayout("Tablet",K)};this.getLayout=function(K){if(this.isGivenLayout("Mobile",K)){return"Mobile"}else{if(this.isGivenLayout("Tablet",K)){return"Tablet"}else{return"Web"}}};this.isGivenLayout=function(L,N){if(this.IsResponsive&&this.Breakpoints){var K=this.Breakpoints.mediums[L];var M=this.Breakpoints.prop;if(M=="max-width"){if(!N){N=window.innerWidth}return N<=K}else{return window.matchMedia("("+M+": "+K+"px)").matches}}return false};this.ProcessMicroContentXhtml=function(M,Q){var P=MadCap.Utilities.SanitizeHtml("<div>"+M+"</div>");var O=new MadCap.Utilities.Url(Q).ToFolder();var N=MadCap.Utilities.HasRuntimeFileType("TriPane");var L=N?"#":"";var K=MadCap.Utilities.FixLinks(P,O,L,this.ContentFolder);return K};this.LoadLanguage=function(L,K){var M=this;require([this.LanguageUrl],function(N){M.Language=N;L.call(K,N)})};this.LoadBreakpoints=function(L,K){if(this.IsResponsive&&this.IsRoot()){var M=this;require([this.BreakpointsUrl],function(N){M.Breakpoints=N;L.call(K,N)})}else{L.call(K,null)}};this.LoadConcepts=function(){var K=$.Deferred();require([y+"Data/Concepts.js"],function(L){n=L;K.resolve(n)});return K.promise()};this.LoadAllConcepts=function(N){function O(){K++;if(K==M+1){N()}}var K=0;var M=B.length;this.LoadConcepts().then(O);for(var L=0;L<M;L++){var P=B[L];if(!P.GetExists()){O();continue}P.LoadAllConcepts(O)}};this.GetConceptsLinks=function(L){var M=$.Deferred();var P=[];if(this.IsWebHelpPlus){function Q(aa,T){var X=aa.documentElement.getElementsByTagName("Url");var W=X.length;for(var U=0;U<W;U++){var V=X[U];var Y=V.getAttribute("Title");var Z=V.getAttribute("Source");Z=y+((Z.charAt(0)=="/")?Z.substring(1,Z.length):Z);P[P.length]={Title:Y,Link:Z}}M.resolve(P)}MadCap.Utilities.Xhr.CallWebService(y+"Service/Service.asmx/GetTopicsForConcepts?Concepts="+L,true,Q)}else{function S(T){P=P.Union(T)}L=L.replace("\\;","%%%%%");if(L==""){M.resolve(P)}else{var K=L.split(";");var N=[];N.push(this.GetConceptsLinksLocal(K).then(S));for(var O=0;O<B.length;O++){var R=B[O];if(R.GetExists()){N.push(R.GetConceptsLinks(L).then(S))}}$.when.apply(this,N).done(function(){M.resolve(P)})}}return M.promise()};this.GetConceptsLinksLocal=function(L){var P=[];var N=[];for(var O=0;O<L.length;O++){var K=L[O];K=K.replace("%%%%%",";");N.push(this.GetConceptLinks(K).then(function(Q){P=P.concat(Q)}))}var M=$.Deferred();$.when.apply(this,N).done(function(){M.resolve(P)});return M.promise()};this.LoadTopicChunk=function(K){var L=$.Deferred();MadCap.Utilities.Require([y+"Data/SearchTopic_Chunk"+K+".js"],function(M){L.resolve(M)});return L.promise()};this.GetSearchChunkIds=function(L){var K=$.Deferred();MadCap.Utilities.Require([y+"Data/Search.js"],function(M){var P=M.t;var O=[];for(var N=0;N<L.length;N++){O.push(MadCap.Utilities.GetChunkId(P,L[N],function(Q,R){if(Q<R){return -1}else{if(Q===R){return 0}else{return 1}}}))}K.resolve(O)});return K.promise()};this.GetConceptLinks=function(K){var L=$.Deferred();var M=this;this.LoadConcepts().done(function(){var N=[];var O=n[K];if(!O){L.resolve(N)}else{M.GetSearchChunkIds(O).then(function(Q){var R=[];for(var S=0;S<Q.length;S++){var P=Q[S];R.push(M.LoadTopicChunk(P).then(function(T){for(var U=0;U<O.length;U++){var V=T[O[U]];if(V){V.Url=M.GetTopicPath(V.u);N.push(V)}}}))}$.when.apply(this,R).done(function(){L.resolve(N)})})}});return L.promise()};this.LoadToc=MadCap.Utilities.Memoize(function(L){var K=$.Deferred();var M=L[0];var N=L[1];this.GetToc(M,N,function(O){K.resolve(O)});return K.promise()});this.GetToc=function(N,M,K){var L=this;var O=this[N+"Url"];if(M){O=e(M)}require([O],function(X){if(typeof X=="undefined"||(L[N]&&X.chunks)){K(X);return}L[N]=X;X.type=N;X.helpSystem=L;X.chunks=[];X.entries=[];X.nodes={};var Q=new MadCap.Utilities.Url(O).ToFolder();for(var P=0;P<X.numchunks;P++){X.chunks[P]={path:Q.AddFile(X.prefix+P+".js").FullPath,loaded:false}}var V=X.tree;var T={};X.automerge=X.tree;while(V!=null){V.toc=X;V.childrenLoaded=false;X.nodes[V.i]=V;if(typeof V.m!=="undefined"){T[V.m]=V}if(typeof V.a!=="undefined"){X.automerge=V}if(typeof V.n!=="undefined"){for(var S=0;S<V.n.length;S++){V.n[S].parent=V;if(S<V.n.length-1){V.n[S].next=V.n[S+1]}if(S>0){V.n[S].previous=V.n[S-1]}}}V=g(V)}var U=[];var R=false;for(var S=0;S<B.length;S++){var W=B[S];if(W.GetExists()){if(!W.IsAutoMerged){W.MergeNode=T[S]}else{R=true}if(W.IsAutoMerged||typeof W.MergeNode!=="undefined"){U.push(W)}}else{H(T[S])}}if(!R&&X.automerge.a=="replace"){H(X.automerge)}if(U.length==0){K(X);return}MadCap.Utilities.AsyncForeach(U,function(Z,Y){r(X,Z,Y)},function(){K(X)})})};function H(M){var N=M.parent;var O=M.previous;var L=M.next;if(O){O.next=L;M.previous=null}if(L){L.previous=O;M.next=null}if(N){var K=M.parent.n.indexOf(M);N.n.splice(K,1);M.parent=null}}function g(L){var K=null;if(typeof L.n!="undefined"){K=L.n[0]}else{if(typeof L.next!="undefined"){K=L.next}else{K=L;while(typeof K.parent!="undefined"){if(typeof K.parent.next!="undefined"){K=K.parent.next;break}else{K=K.parent}}if(typeof K.parent=="undefined"){K=null}}}return K}function h(K){var L=null;if(typeof K.previous!="undefined"){L=K.previous;while(typeof L.n!=="undefined"&&L.n.length>0){L=L.n[L.n.length-1]}}else{if(typeof K.parent!="undefined"){L=K.parent}}return L}function i(P,M){var Q="";var O=-1;var K=null;if(P.n&&P.n.length>0){Q=P.toc.entries[P.i].title;if(M){Q=encodeURIComponent(Q)}O=0}else{O=P.parent.n.indexOf(P)+1}if(Q.length>0){Q+="|"}Q+=("_____"+O);for(var L=P.parent;L&&typeof L.i!=="undefined";L=L.parent){if(Q==null){Q=""}if(Q.length>0){Q="|"+Q}var N=L.toc.entries[L.i];if(N){var R=N.title;if(M){R=encodeURIComponent(R)}Q=R+Q}}return Q}function r(M,L,K){L.GetToc(M.type,null,function(X){if(typeof X=="undefined"){K();return}var U=L.IsAutoMerged?M.automerge:L.MergeNode;var T=X.tree;if(T.n!==undefined&&U!==undefined){var W=U.r==1||(L.IsAutoMerged&&U.a=="replace");var P=W||(L.IsAutoMerged&&(U.a=="before-head"||U.a=="after-head"));var Q=W||(L.IsAutoMerged&&(U.a=="before-head"||U.a=="after-tail"));var V=Q?U.parent:U;if(typeof V.n=="undefined"){V.n=[]}var N=Q?V.n.indexOf(U)+(P?0:1):P?0:V.n.length;var S=T.n.length;for(var O=0;O<S;O++){T.n[O].parent=V;V.n.splice(N+O,0,T.n[O])}if(W){V.n.splice(N+S,1)}if(N>0){V.n[N].previous=V.n[N-1];V.n[N-1].next=V.n[N]}var R=N+S-(W?1:0)-1;if(R>=0&&R+1<V.n.length){V.n[R].next=V.n[R+1];V.n[R+1].previous=V.n[R]}if(L.IsAutoMerged){M.automerge=V.n[N+S-1];M.automerge.a="after-tail"}}K()})}this.LoadTocChunk=function(M,K){var L=$.Deferred();require([M.chunks[K].path],function(N){if(!M.chunks[K].loaded){for(var P in N){for(var O=0;O<N[P].i.length;O++){M.entries[N[P].i[O]]={link:P,title:N[P].t[O],bookmark:N[P].b[O]}}}M.chunks[K].loaded=true}return L.resolve(N)});return L.promise()};this.GetTocEntryHref=function(M,Y,aa,K){var Q=null;var W=M.toc;var L=W.entries[M.i];if(L){var T=L.link+L.bookmark;if(typeof M.m=="undefined"&&T!="___"){var Z=null;var U=new MadCap.Utilities.Url(T);var O=W.helpSystem;var P=O.GetPath();var V=O.GetMasterHelpSystem().GetContentPath();var N=typeof M.f!="undefined";if(!U.IsAbsolute){if(!MadCap.String.IsNullOrEmpty(P)){U=new MadCap.Utilities.Url(P).CombinePath(T);Z=U.ToRelative(V)}else{U=U.ToRelative("/"+V);Z=U}}else{Z=U}if(N||!aa){if(Z.IsAbsolute){Q=Z.FullPath}else{Q=V+Z.FullPath}}else{if(MadCap.Utilities.HasRuntimeFileType("TriPane")){Q="#"+Z.FullPath}else{Q=U.FullPath}}}}if(Q!=null&&Y&&K){var S=window.name=="topic"&&!MadCap.Utilities.HasRuntimeFileType("Default");var X=i(M,true);if(MadCap.Utilities.HasRuntimeFileType("TriPane")){Q+=encodeURIComponent("?"+Y+"Path="+X)}else{var R=new MadCap.Utilities.Url(Q);if(S){Q=R.PlainPath+encodeURIComponent("?"+Y+"Path="+X)+R.Fragment}else{Q=R.PlainPath+"?"+(Y+"Path="+X)+R.Fragment}}}return Q};this.GetTocData=function(L){var S=null,R=null,K=null;var O=MadCap.Utilities.HasRuntimeFileType("TriPane");if(O&&!MadCap.String.IsNullOrEmpty(L.Fragment)&&L.Fragment.length>1||!O){var Q=(O&&!(L.QueryMap.GetItem("TocPath")||L.QueryMap.GetItem("BrowseSequencesPath"))&&!MadCap.String.IsNullOrEmpty(L.Fragment))?new MadCap.Utilities.Url(L.Fragment):L;R=Q.QueryMap.GetItem("TocPath");if(R!=null){S="Toc"}else{K=Q.QueryMap.GetItem("BrowseSequencesPath");if(K!=null){S="BrowseSequences"}}if(L.HashMap.GetItem("cshid")==null){var M=L.Query.indexOf("?");var N=L.Query.lastIndexOf("?");var P="";if(M!=N){P=L.Query.substr(M,N)}if(O){L=new MadCap.Utilities.Url(L.Fragment.substr(1))}if(!MadCap.String.IsNullOrEmpty(P)){L.Query=P}}}else{L=new MadCap.Utilities.Url(this.DefaultStartTopic).ToRelative(this.GetContentPath())}return{TocType:S,TocPath:R,BrowseSequencesPath:K,Href:L}};this.FindTocNode=function(M,K,L,N){z.FindNode("Toc",M,K,L,N)};this.FindBrowseSequenceNode=function(M,K,L){z.FindNode("BrowseSequences",M,K,L)};this.FindNode=function(N,M,K,L,O){z.FindNodeInToc(N,M,K,L,O,true)};this.FindNodeInToc=function(O,N,K,M,P,L){z.LoadToc([O,P]).then(function(U){var T=new MadCap.Utilities.Url(z.GetMasterHelpSystem().GetContentPath());var V=K;var Q=0;var R;if(!K.IsAbsolute){var V=!MadCap.String.IsNullOrEmpty(T.FullPath)?T.CombinePath(K):K;V=V.ToRelative(z.GetPath());V=new MadCap.Utilities.Url("/"+V.FullPath)}for(var S=1;S<U.chunkstart.length;S++){if(U.chunkstart[S]<=decodeURIComponent(V.PlainPath)){Q++}}z.LoadTocChunk(U,Q).then(function(W){var X=W[decodeURIComponent(V.PlainPath)];if(typeof X!=="undefined"){var Z=[];if(!R){R=U.nodes[X.i[0]]}if(N){for(var Y=0;Y<X.i.length;Y++){if(i(U.nodes[X.i[Y]],false)==N){Z.push(X.i[Y])}}}else{for(var Y=0;Y<X.i.length;Y++){if(X.b[Y].toLowerCase()==decodeURIComponent(V.Fragment).toLowerCase()){Z.push(X.i[Y])}}}if(Z.length){M(U.nodes[Z.pop()]);return}}if(B.length>0&&L){MadCap.Utilities.AsyncForeach(B,function(ab,aa){ab.FindNode(O,N,K,function(ac){if(typeof ac!=="undefined"){M(ac);return}aa()})},function(){M(R)})}else{M(R)}})})};this.NodeDepth=function(L){var K=1;while(L.parent&&L.c!==undefined){K++;L=L.parent}return K};this.LoadGlossary=function(L,K){if(typeof this.Glossary!="undefined"){L.call(K,this.Glossary);return}var M=this;this.GetGlossary(function(N){if(N&&N.terms){N.termMap=Object.create(null);for(var O=0;O<N.terms.length;O++){var P=N.terms[O];N.termMap[P.t.toLowerCase()]=P}}M.Glossary=N;L.call(K,N)})};this.GetGlossary=function(K){var L=this;require([this.GlossaryUrl],function(P){function S(){N++;if(N==R){K(P)}}if(typeof P=="undefined"){K(P);return}var N=0;var R=0;P.chunks=[];var O=new MadCap.Utilities.Url(z.GlossaryUrl).ToFolder();for(var M=0;M<P.numchunks;M++){P.chunks.push({helpSystem:L,path:O.AddFile(P.prefix+M+".js").FullPath})}for(var Q=0;Q<B.length;Q++){var T=B[Q];if(!T.GetExists()){continue}R++}if(R==0){K(P);return}for(var Q=0;Q<B.length;Q++){var T=B[Q];if(!T.GetExists()){continue}p(P,T,S)}})};this.SearchGlossary=function(L){var K=$.Deferred();var M=this;this.LoadGlossary(function(P){var O=false;if(P&&P.termMap){var Q=P.termMap[L.toLowerCase()];O=typeof Q!="undefined";if(O){var N=P.chunks[Q.c];require([N.path],function(R){var S={term:Q.t,definition:R[Q.t].d,link:R[Q.t].l};if(S.link){var T=N.helpSystem;var U=(new MadCap.Utilities.Url("../")).CombinePath(S.link).FullPath;S.link=T.GetTopicPath(U).FullPath;T.SearchDB.LoadTopicByUrl(U).done(function(W,V){if(V){S.abstractText=V.a}K.resolve(S)})}else{K.resolve(S)}})}}if(!O){K.resolve()}},this);return K.promise()};this.LoadIndex=function(L,K){if(typeof this.Index!=="undefined"){L.call(K,this.Index);return}var M=this;this.GetIndex(function(N){M.Index=N;L.call(K,N)})};this.GetIndex=function(K){var L=this;require([this.IndexUrl],function(Q){function S(){N++;if(N==R){K(Q)}}if(typeof Q=="undefined"){K(Q);return}var N=0;var R=0;Q.chunks=[];var O=new MadCap.Utilities.Url(z.IndexUrl).ToFolder();for(var M=0;M<Q.numchunks;M++){Q.chunks.push({helpSystem:L,path:O.AddFile(Q.prefix+M+".js").FullPath})}for(var P=0;P<B.length;P++){var T=B[P];if(!T.GetExists()){continue}R++}if(R==0){K(Q);return}for(var P=0;P<B.length;P++){var T=B[P];if(!T.GetExists()){continue}q(Q,T,S)}})};this.LoadRootIndexEntry=function(L,K){if(L.loaded){if(K){K(L)}return}this.LoadIndex(function(N){var M=typeof L.c=="number"?[L.c]:L.c;MadCap.Utilities.AsyncForeach(M,function(O,P){var Q=N.chunks[O];require([Q.path],function(R){var S=R[L.t];z.SetIndexEntryHelpSystem(S,Q.helpSystem);z.MergeIndexEntries(L,S);P()})},function(){z.LoadIndexEntry(L);if(K){K(L)}})})};this.SetIndexEntryHelpSystem=function(K,L){if(K.l){$.each(K.l,function(M,N){N.helpSystem=L})}if(K.e){$.each(K.e,function(N,M){z.SetIndexEntryHelpSystem(M,L)})}};this.LoadIndexEntry=function(K){if(K.l){var L=[];$.each(K.l,function(M,N){var O={Title:N.t,Link:N.helpSystem.GetTopicPath(".."+N.u).FullPath};L[L.length]=O});K.linkList=z.SortLinkList(L)}if(K.e){$.each(K.e,function(N,M){z.LoadIndexEntry(M)})}K.loaded=true};this.MergeIndexEntries=function(K,L){if(L.l){if(typeof K.l=="undefined"){K.l=L.l}else{K.l=K.l.concat(L.l)}}if(L.r){if(typeof K.r=="undefined"){K.r=L.r}else{if(K.r=="SeeAlso"||L.r=="SeeAlso"){K.r="SeeAlso"}}if(typeof K.f=="undefined"){K.f=L.f}else{var M=K.f.split(";");var N=L.f.split(";");$.each(N,function(O,P){if($.inArray(M,P)){M.push(P)}});M.sort(function(Q,R){var O=Q.toLowerCase();var P=R.toLowerCase();return O<P?-1:O>P?1:0});K.f=M.join("; ")}}if(L.e){if(typeof K.e=="undefined"){K.e={}}$.each(L.e,function(P,O){if(typeof K.e[P]!=="undefined"){z.MergeIndexEntries(K.e[P],O)}else{K.e[P]=O}})}};this.FindIndexEntry=function(L,K){z.LoadIndex(function(M){if(!M.entries){M.entries={};$.each(M.terms,function(R,Q){M.entries[Q.t]=Q})}var P=L.split(":");var O=P.length;var N=M.entries[P[0]];if(N){z.LoadRootIndexEntry(N,function(S){var Q=S;for(var R=1;R<O;R++){Q=Q.e[P[R]];if(!Q){break}}if(K){K(S,Q)}})}else{if(K){K()}}})};this.SortLinkList=function(K){K.sort(function(L,M){var N=L.Title.toLowerCase();var O=M.Title.toLowerCase();return N<O?-1:N>O?1:0});return K};this.GetSearchDBs=function(K){var L=new Array();var M=this;require([y+"Data/Search.js"],function(P){function Q(T){if(T!=null){for(var S=0;S<T.length;S++){L[L.length]=T[S]}}N++;if(N==O){K(L)}}var N=0;var O=B.length;var R=new MadCap.WebHelp.Search.SearchDB(M);M.SearchDB=R;L[L.length]=R;R.Load(P,function(){var T=P.pm;if(T||O==0){K(L)}else{for(var S=0;S<O;S++){var U=B[S];if(!U.GetExists()){Q(null);continue}U.GetSearchDBs(Q)}}})})};this.GetConcepts=function(){return n};this.GetSearchFilters=function(){return t.map};this.ParseSearchFilterDoc=function(Q){filterMap=Object.create(null);if(Q!=null){var M=Q.getElementsByTagName("SearchFilter");for(var N=0;N<M.length;N++){var L=M[N];var O=L.getAttribute("Name");var P=L.getAttribute("Order");var K=L.getAttribute("Concepts");if(!K){continue}filterMap[O]={c:K,o:P,group:0}}}return filterMap};this.LoadSearchFiltersLocal=function(){var K=$.Deferred();require([this.SearchFilterSetUrl],function(L){var M=null;if(L){M={map:L,count:1}}K.resolve(M)});return K.promise()};this.LoadSearchFilters=function(){var K=$.Deferred();if(!this.IsWebHelpPlus){function O(W){if(W){if(!N){N=W;for(var V in W.map){W.map[V].group=0}}else{for(var V in W.map){if(!N.map[V]){N.map[V]=W.map[V];N.map[V].group+=N.count}else{var T=N.map[V];var U=W.map[V];var R=T.c.split(";");var S=U.c.split(";");T.c=R.Union(S).join(";");if(MadCap.String.IsNullOrEmpty(T.cm)){T.cm=U.cm}}}N.count+=W.count}}}var N;var L=[];L.push(this.LoadSearchFiltersLocal().then(O));for(var M=0;M<B.length;M++){var Q=B[M];if(Q.GetExists()){L.push(Q.LoadSearchFilters().then(O))}}$.when.apply(this,L).done(function(){t=N;K.resolve(N)})}else{var P=this;MadCap.Utilities.Xhr.CallWebService(y+"Service/Service.asmx/GetSearchFilters",true,function(T,R){var S=P.ParseSearchFilterDoc(T);K.resolve({map:S})})}return K.promise()};this.AdvanceTopic=function(Q,O,P,K,N,L){var M=null;z.FindNode(Q,P,N,function(S){if(S){function R(U,T){U=T=="next"?g(U):h(U);if(U&&typeof U.i!=="undefined"){z.LoadTocChunk(U.toc,U.c).then(function(V){var W=U.toc.entries[U.i];var X=z.GetTocEntryHref(U,Q,true,K);if(X){if(MadCap.String.StartsWith(X,"#")){X=X.substring(1)}L(X)}else{R(U,T)}})}}R(S,O)}})};this.SetBrowseSequencePath=function(L,M){var K=$(".current-topic-index-button");if(L!=null){this.FindBrowseSequenceNode(L,M,function(N){if(N&&N.parent){K.removeClass("disabled");$(".sequence-index").text(N.parent.n.indexOf(N)+1);$(".sequence-total").text(N.parent.n.length)}else{K.addClass("disabled")}})}else{K.addClass("disabled")}};this.GetSkins=function(){var K=[];A.ForEach(function(L,M){K.push(M)});return K};this.IsCentralLiveHelpServerType=function(){return this.LiveHelpServerType=="Central"};function f(M,K){var L=M.documentElement.getAttribute(K);return e(L)}function e(L){if(L==null){return null}var K=new MadCap.Utilities.Url(y);if(!K.IsAbsolute){return y+L}return K.AddFile(L).ToRelative(document.location.href).FullPath}function b(aa){var Z=$("CatapultSkin",aa.documentElement);for(var O=0,R=Z.length;O<R;O++){var Y=Z[O];var K=$(Y);var X=K.attr("SkinID");var W={};for(var P=0,S=Y.attributes.length;P<S;P++){var L=Y.attributes[P];W[L.name]=L.value}var N=K.children();for(var P=0,S=N.length;P<S;P++){var M=N[P];var U=M.nodeName;var V={};W[U]=V;for(var Q=0,T=M.attributes.length;Q<T;Q++){var L=M.attributes[Q];V[L.name]=L.value}}A.Add(X,W)}}function c(N,P){if(N.nodeName.toLowerCase()=="madcap:glossarychunkref"){var K=$(N);var O=K.attr("src");if(!MadCap.String.IsNullOrEmpty(O)){var Q=new MadCap.Utilities.Url(P).CombinePath("../../Data/").CombinePath(O);var L=MadCap.Utilities.EncodeHtml("../"+Q.FullPath);K.attr("src",L)}}else{var M=N.getElementsByTagName("a")[0];var O=$(M).attr("href");if(!MadCap.String.IsNullOrEmpty(O)){var Q=new MadCap.Utilities.Url(P).CombinePath("../../Content/").CombinePath(O);var L=MadCap.Utilities.EncodeHtml("../"+Q.FullPath);$(M).attr("href",L)}}}function d(M){for(var L=0;L<M.childNodes.length;L++){var K=M.childNodes[L];if(K.nodeName=="Entries"){for(var N=0;N<K.childNodes.length;N++){d(K.childNodes[N])}}else{if(K.nodeName=="Links"){for(var N=0;N<K.childNodes.length;N++){if(K.childNodes[N].nodeType==1){var O=MadCap.Dom.GetAttribute(K.childNodes[N],"Link");O=y+((O.charAt(0)=="/")?O.substring(1,O.length):O);K.childNodes[N].setAttribute("Link",O)}}}}}}function o(L,M){if(!M){return}for(var K=0;K<M.length;K++){L[L.length]=M[K]}}function p(K,M,L){M.GetGlossary(function(Q){if(typeof Q=="undefined"){L();return}K.chunks=K.chunks.concat(Q.chunks);for(var R=0,S=0;R<K.terms.length&&S<Q.terms.length;){var O=K.terms[R];var P=Q.terms[S];var T=O.t;var U=P.t;if(T.toLowerCase()==U.toLowerCase()){R++;S++}else{if(T.toLowerCase()>U.toLowerCase()){P.c+=K.numchunks;K.terms.splice(R,0,P);S++}else{R++}}}for(;S<Q.terms.length;S++){var N=Q.terms[S];N.c+=K.numchunks;K.terms.push(N)}K.numchunks=K.chunks.length;L()})}function q(K,M,L){M.GetIndex(function(S){if(typeof S=="undefined"){L();return}K.chunks=K.chunks.concat(S.chunks);for(var R=0,T=0;R<K.terms.length&&T<S.terms.length;){var P=K.terms[R];var Q=S.terms[T];var U=P.s||P.t;var V=Q.s||Q.t;if(U==V&&P.t==Q.t){if(typeof P.c=="number"){P.c=[P.c]}var N=Q.c;if(typeof Q.c=="number"){N=[Q.c]}$.each(N,function(X,W){P.c.push(W+K.numchunks)});P.$=(P.$===1&&Q.$===1)?1:0;R++;T++}else{if(U.toLowerCase()>V.toLowerCase()||(U.toLowerCase()==V.toLowerCase()&&P.t.toLowerCase()>Q.t.toLowerCase())){Q.c+=K.numchunks;K.terms.splice(R,0,Q);T++}else{R++}}}for(;T<S.terms.length;T++){var O=S.terms[T];O.c+=K.numchunks;K.terms.push(O)}K.numchunks=K.chunks.length;L()})}};(function(){MadCap.WebHelp.HelpSystem.LoadHelpSystem=MadCap.Utilities.Memoize(function(c){var a=$.Deferred();var b=new MadCap.WebHelp.HelpSystem(null,null,c,null,null);b.Load(function(){a.resolve(b)});return a.promise()});MadCap.WebHelp.HelpSystem.LoadHelpSystemDefault=function(){var b=$(document.documentElement).attr("data-mc-path-to-help-system");var a="Data/HelpSystem.xml";if(b){a=b+a}return MadCap.WebHelp.HelpSystem.LoadHelpSystem(a)}})();MadCap.WebHelp.TocFile=function(h,s){var o=this;var j=h;var r=s;var k=false;var n=null;var l=new Array();var q=null;var p=null;var m=new Array();(function(){})();this.Init=function(u){if(k){if(u!=null){u()}return}if(u!=null){l.push(u)}var t=null;if(s==MadCap.WebHelp.TocFile.TocType.Toc){t="Toc.xml"}else{if(s==MadCap.WebHelp.TocFile.TocType.BrowseSequence){t="BrowseSequences.xml"}}this.LoadToc(j.GetPath()+"Data/"+t,v);function v(w){k=true;n=w.documentElement;i()}};this.LoadToc=function(v,t){if(r==MadCap.WebHelp.TocFile.TocType.Toc&&j.IsWebHelpPlus){MadCap.Utilities.Xhr.CallWebService(j.GetPath()+"Service/Service.asmx/GetToc",true,u,null)}else{if(r==MadCap.WebHelp.TocFile.TocType.BrowseSequence&&j.IsWebHelpPlus){MadCap.Utilities.Xhr.CallWebService(j.GetPath()+"Service/Service.asmx/GetBrowseSequences",true,u,null)}else{var w=(v.indexOf("/")==-1)?j.GetPath()+"Data/"+v:v;MadCap.Utilities.Xhr.Load(w,false,u,null,null)}}function u(y,x){if(!y||!y.documentElement){if(t!=null){t(y)}return}if(t!=null){t(y)}}};this.LoadChunk=function(v,w,t){var x=(w.indexOf("/")==-1)?j.GetPath()+"Data/"+w:w;MadCap.Utilities.Xhr.Load(w,true,u,null,null);function u(E,y){if(!E||!E.documentElement){if(t!=null){t(v)}return}v.removeAttribute("Chunk");var D=E.documentElement;for(var A=0,C=D.childNodes.length;A<C;A++){var z=D.childNodes[A];if(z.nodeType!=1){continue}var B=null;if(typeof(E.importNode)=="function"){B=E.importNode(z,true)}else{B=z.cloneNode(true)}v.appendChild(B)}if(t!=null){t(v)}}};this.LoadMerge=function(x,u){var t=MadCap.Dom.GetAttributeInt(x,"MergeHint",-1);if(t==-1){u(x,false,null,null);return}x.removeAttribute("MergeHint");var w=f(x);var z=w.GetSubsystem(t);var y=MadCap.Dom.GetAttributeBool(x,"ReplaceMergeNode",false);if(!y){x.setAttribute("ownerHelpSystemIndex",m.length)}m[m.length]=z;var B=z.GetPath()+"Data/"+(r==MadCap.WebHelp.TocFile.TocType.Toc?"Toc.xml":"BrowseSequences.xml");var A=MadCap.Utilities.Xhr.Load(B,true,v);function v(N,C){if(!N||!N.documentElement){if(u!=null){u(x,false,null,null)}return}var M=N.documentElement;var E=null;var I=true;var F=null;var J=null;var L=x.ownerDocument;for(var G=0,K=M.childNodes.length;G<K;G++){var D=M.childNodes[G];if(D.nodeType!=1){continue}var H=null;if(typeof(L.importNode)=="function"){H=L.importNode(D,true)}else{H=D.cloneNode(true)}if(y){H.setAttribute("ownerHelpSystemIndex",m.length-1);if(I){I=false;x.parentNode.replaceChild(H,x);F=H;J=F}else{E.parentNode.insertBefore(H,E.nextSibling);J=H}E=H}else{x.appendChild(H)}}if(u!=null){u(x,y,F,J)}}};this.AdvanceTopic=function(v,x,u,t){this.GetTocNode(x,u,w);function w(A){if(A==null){t(null);return}var y=null;e(v,A,z);function z(D){var B=null;if(D!=null){B=MadCap.Dom.GetAttribute(D,"Link");B=B.substring("/".length);var C=new MadCap.Utilities.Url(B);var F=null;if(r==MadCap.WebHelp.TocFile.TocType.Toc){F="TocPath"}else{if(r==MadCap.WebHelp.TocFile.TocType.BrowseSequence){F="BrowseSequencePath"}}var H=g(D,false);var E=C.ToQuery(F+"="+encodeURIComponent(H));B=E.FullPath;var G=f(D);B=G.GetPath()+B;t(B)}else{t(B)}}}};this.GetRootNode=function(t){this.Init(u);function u(){t(n)}};this.GetTocNode=function(y,v,w){this.Init(x);function x(){q=y;p=v;var G=(y=="")?new Array(0):y.split("|");var D=-1;if(G.length>0){var B=G[G.length-1];if(MadCap.String.StartsWith(B,"_____")){D=parseInt(B.substring("_____".length));G.splice(G.length-1,1)}}var H=n;for(var A=0,C=G.length;A<C;A++){if(t(H)){return}if(u(H)){return}H=b(H,decodeURIComponent(G[A]))}if(H==null){w(null);return}if(t(H)){return}if(u(H)){return}if(D>=0){if(D==0){z=H}else{z=$(H).children("TocEntry")[D-1]}}else{var E=f(H);var F=v.ToRelative(new MadCap.Utilities.Url(E.GetPath()));var z=c(H,F.FullPath.toLowerCase(),true);if(!z){z=c(H,F.PlainPath.toLowerCase(),false)}}q=null;p=null;w(z)}function t(A){var z=MadCap.Dom.GetAttribute(A,"Chunk");if(z!=null){o.LoadChunk(A,z,function(B){o.GetTocNode(q,p,w)});return true}return false}function u(A){var z=$(A).attr("MergeHint")||-1;if(z>=0){o.LoadMerge(A,function(B){o.GetTocNode(q,p,w)});return true}return false}};this.GetEntrySequenceIndex=function(w,t,u){this.GetTocNode(w,t,v);function v(y){var x=-1;if(y!=null){x=a(y)}u(x)}};this.GetIndexTotalForEntry=function(w,t,u){this.GetTocNode(w,t,v);function v(y){var z=-1;if(y!=null){var x=y;while(x.parentNode!=n){x=x.parentNode}z=MadCap.Dom.GetAttributeInt(x,"DescendantCount",-1)}u(z)}};function i(){for(var t=0,u=l.length;t<u;t++){l[t]()}}function b(w,v){var t=null;for(var u=0;u<w.childNodes.length;u++){if(w.childNodes[u].nodeName=="TocEntry"&&MadCap.Dom.GetAttribute(w.childNodes[u],"Title")==v){t=w.childNodes[u];break}}return t}function c(B,t,x){var y=null;var u=MadCap.Dom.GetAttribute(B,"Link");if(u!=null){u=u.substring("/".length);u=u.replace(/%20/g," ");u=u.toLowerCase()}if(u==t){y=B}else{for(var A=0;A<B.childNodes.length;A++){var v=B.childNodes[A];if(v.nodeType!=1){continue}var w=MadCap.Dom.GetAttribute(v,"Link");if(w==null){continue}w=w.substring("/".length);w=w.replace(/%20/g," ");w=w.toLowerCase();if(!x){var z=w.indexOf("#");if(z!=-1){w=w.substring(0,z)}var C=w.indexOf("?");if(C!=-1){w=w.substring(0,C)}}if(w==t){y=v;break}}}return y}function e(x,A,y){if(x=="previous"){w(A)}else{if(x=="next"){v(A)}}function z(F){var G=null;if(F!=null){var C=MadCap.Dom.GetAttribute(F,"Link");if(C==null){e(x,F,y);return}var D=new MadCap.Utilities.Url(C);var B=D.Extension.toLowerCase();var E=j.GetMasterHelpSystem();if(E.UseCustomTopicFileExtension){if(B!=E.CustomTopicFileExtension){e(x,F,y);return}}else{if(B!="htm"&&B!="html"){e(x,F,y);return}}G=F}y(G)}function w(F){function C(H){var G=d(H,"TocEntry");if(G==null){E=H}else{E=G;if(t(G,C)){return}if(u(G,D)){return}}z(E)}function D(J,I,G,H){if(I){C(H)}else{C(J)}}var E=null;for(var B=F.previousSibling;B!=null;B=B.previousSibling){if(B.nodeName=="TocEntry"){E=B;break}}if(E!=null){if(t(E,C)){return}if(u(E,D)){return}C(E);return}else{if(F.parentNode.nodeType==1){E=F.parentNode}}z(E)}function v(E){function C(H){var G=$(H).children("TocEntry")[0];for(var F=H;F!=null&&G==null;F=F.parentNode){G=$(F).next("TocEntry")[0]}z(G)}function D(I,H,F,G){if(H){z(F);return}C(I)}var B=null;if(t(E,C)){return}if(u(E,D)){return}C(E)}function t(D,C){var B=MadCap.Dom.GetAttribute(D,"Chunk");if(B!=null){o.LoadChunk(D,B,C);return true}return false}function u(D,C){var B=$(D).attr("MergeHint")||-1;if(B>=0){o.LoadMerge(D,C);return true}return false}}function d(w,v){var t=$(w).children(v+":last")[0];if(t!=null){var u=d(t,v);if(u!=null){return u}return t}return null}function f(w){var u=null;var t=w;while(true){if(t==t.ownerDocument.documentElement){u=j;break}var v=MadCap.Dom.GetAttributeInt(t,"ownerHelpSystemIndex",-1);if(v>=0){u=m[v];break}t=t.parentNode}return u}function g(w){var x="";var v=-1;var t=$(w).children("TocEntry")[0];if(t!=null){x=encodeURIComponent(MadCap.Dom.GetAttribute(w,"Title"));v=0}else{v=$(w).index()+1}if(x.length>0){x+="|"}x+=("_____"+v);for(var u=w.parentNode;u!=null&&u.parentNode.nodeType==1;u=u.parentNode){if(x==null){x=""}if(x.length>0){x="|"+x}x=encodeURIComponent(MadCap.Dom.GetAttribute(u,"Title"))+x}return x}function a(z){if(z.parentNode==z.ownerDocument.documentElement){return 0}var y=0;var w=MadCap.Dom.GetAttribute(z,"Link");if(w!=null){y++}for(var t=z.previousSibling;t!=null;t=t.previousSibling){if(t.nodeType!=1){continue}var u=MadCap.Dom.GetAttributeInt(t,"DescendantCount",0);y+=u;var w=MadCap.Dom.GetAttribute(t,"Link");if(w!=null){var x=new MadCap.Utilities.Url(w);var v=x.Extension.toLowerCase();if(v=="htm"||v=="html"){y++}}}return y+a(z.parentNode)}};MadCap.WebHelp.TocFile.TocType={Toc:0,BrowseSequence:1};MadCap.WebHelp.IndexEntry=function(b,e){var d=MadCap.Dom.GetChildNodeByTagName(b,"Links",0).childNodes;var g=d.length;var f=0;this.Term=MadCap.Dom.GetAttribute(b,"Term");this.IndexLinks=new Array();this.Level=e;this.GeneratedReferenceType=MadCap.Dom.GetAttribute(b,"GeneratedReferenceType");for(var a=0;a<g;a++){var c=d[a];if(c.nodeType!=1){continue}this.IndexLinks[f]=new MadCap.WebHelp.IndexLink(c);f++}};MadCap.WebHelp.IndexLink=function(a){this.Title=MadCap.Dom.GetAttribute(a,"Title");this.Link=MadCap.Dom.GetAttribute(a,"Link")};

//    Syntax:
//    function MadCap.OpenHelp(id, skinName, searchQuery, firstPick)
//
//    id          - Identifier that was created in Flare. This can be either the identifier name or value. The topic and skin
//                  that is associated with the id will be used. If no skin is associated with the id, skinName will be used.
//                  Alternatively, id may contain a topic path. In this case, the specified topic will be loaded with the skin
//                  that is specified in skinName. Specify null to use the help system's default starting topic.
//    skinName    - This is a string indicating the name of the skin to use when opening the help system. Specify null to use
//                  the default skin or to use the skin that is associated with id. If a skin is associated with id AND a skin
//                  is specified in skinName, skinName will take precedence.
//    searchQuery - This is a string indicating the search query used when opening the help system. If a search query is specified,
//                  the help system will start with the search pane open and the search query executed. Specify null to open
//                  the help system without a search query.
//    firstPick   - This is a boolean indicating whether to automatically open the topic from the first search result that is
//                  returned by the search query (see searchQuery parameter). Use null if no search query was specified.
//
//    Examples:
//
//    In the following example, topic and skin associated with "FILE_NEW" will be used:
//    MadCap.OpenHelp('FILE_NEW', null, null, null);
//
//    In the following example, topic associated with "FILE_NEW" will be used. "BlueSkin" will override the skin associated with "FILE_NEW":
//    MadCap.OpenHelp('FILE_NEW', 'BlueSkin', null, null);
//
//    In the following example, topic and skin associated with identifier value 1 will be used:
//    MadCap.OpenHelp(1, null, null, null);
//
//    In the following example, topic associated with identifier value 1 will be used. "BlueSkin" will override the skin associated with identifier value 1:
//    MadCap.OpenHelp(1, 'BlueSkin', null, null);
//
//    In the following example, "Company/Employees.htm" will be used with the default skin:
//    MadCap.OpenHelp('Company/Employees.htm', null, null, null);
//
//    In the following example, both the default topic and skin will be used:
//    MadCap.OpenHelp(null, null, null, null);
//
//    In the following example, the default topic will be used with "BlueSkin":
//    MadCap.OpenHelp(null, 'BlueSkin', null, null);
//
//    In the following example, both the default topic and skin will be used. The help system will be started with the search pane
//    displaying the search results for the query 'quarterly report'. The topic from the first result will not be opened:
//    MadCap.OpenHelp(null, null, 'quarterly report', false);
//
//    In the following example, both the default topic and skin will be used. The help system will be started with the search pane
//    displaying the search results for the query 'quarterly report'. The topic from the first result will be opened:
//    MadCap.OpenHelp(null, null, 'quarterly report', true);

(function ()
{
var helpSystemName = "Webhelp-PR.htm";

    MadCap.OpenHelp = function (id, skinName, searchQuery, firstPick, pathToHelpSystem)
    {
        var cshFileName = helpSystemName.substring(0, helpSystemName.lastIndexOf(".")) + ".js";
        var webHelpPath = null;
        var webHelpFile = null;
        var cshFileUrl = new MadCap.Utilities.Url(helpSystemName);

        if (pathToHelpSystem == null)
        {
            var scriptNodes = document.getElementsByTagName("script");
            var found = false;

            for (var i = 0; i < scriptNodes.length; i++)
            {
                var src = scriptNodes[i].src;
                var srcUrl = new MadCap.Utilities.Url(MadCap.String.Trim(src));

                if (srcUrl.NameWithExtension.toLowerCase() == cshFileName.toLowerCase())
                {
                    var locUrl = new MadCap.Utilities.Url(document.location.href).ToFolder();

                    webHelpPath = locUrl.AddFile(srcUrl);
                    webHelpPath = webHelpPath.ToFolder();

                    found = true;

                    break;
                }
            }

            if (!found)
                throw "CSH failed: could not find MadCap CSH script in page.";
        }
        else
        {
            webHelpPath = new MadCap.Utilities.Url(pathToHelpSystem);
        }

        webHelpFile = webHelpPath.AddFile(cshFileUrl);

        var webHelpPath = webHelpFile.ToFolder().FullPath;
        var helpSystemFile = webHelpPath + "Data/HelpSystem.xml";
        var helpSystem = new MadCap.WebHelp.HelpSystem(null, null, helpSystemFile, null, null);

        helpSystem.Load(function ()
        {
            helpSystem.LookupCSHID(id, function (idInfo)
            {
                function OnGetSkinComplete()
                {
                    var cshString = webHelpFile.FullPath;

                    if (id)
                        cshString += "#cshid=" + id;

                    if (skinName)
                    {
                        if (cshString.indexOf("#") != -1)
                            cshString += "&";
                        else
                            cshString += "#";

                        cshString += "skinName=" + skinName;
                    }

                    if (searchQuery)
                    {
                        if (cshString.indexOf("#") != -1)
                            cshString += "&";
                        else
                            cshString += "#";

                        cshString += "searchQuery=" + searchQuery;

                        if (firstPick)
                            cshString += "&firstPick=true";
                    }

                    var win = window.open(cshString, "_MCWebHelpCSH", browserOptions + size);

                    // Bug 32051: Windows 7 64-bit is returning null from the call to window.open().
                    if (win != null)
                        win.focus();
                }

                skinName = skinName || idInfo.Skin;

                // Browser setup options

                var browserOptions = "";
                var size = "";

                if (skinName)
                {
                    var skin = helpSystem.GetSkin(skinName);

                    if (skin)
                    {
                        var useDefault = MadCap.String.ToBool(skin.UseDefaultBrowserSetup, true);

                        if (!useDefault)
                        {
                            var toolbar = "no";
                            var menu = "no";
                            var locationBar = "no";
                            var statusBar = "no";
                            var resizable = "no";
                            var setup = skin.BrowserSetup;

                            if (setup)
                            {
                                toolbar = (setup.indexOf("Toolbar") > -1) ? "yes" : "no";
                                menu = (setup.indexOf("Menu") > -1) ? "yes" : "no";
                                locationBar = (setup.indexOf("LocationBar") > -1) ? "yes" : "no";
                                statusBar = (setup.indexOf("StatusBar") > -1) ? "yes" : "no";
                                resizable = (setup.indexOf("Resizable") > -1) ? "yes" : "no";
                            }

                            browserOptions = "toolbar=" + toolbar + ", menubar=" + menu + ", location=" + locationBar + ", status=" + statusBar + ", resizable=" + resizable;
                        }

                        var windowSize = LoadSize(skin);

                        if (windowSize)
                            size = ", top=" + windowSize.topPx + ", left=" + windowSize.leftPx + ", width=" + windowSize.widthPx + ", height=" + windowSize.heightPx;
                    }

                    OnGetSkinComplete();
                }
                else
                {
                    OnGetSkinComplete();
                }
            });
        });
    }

    function LoadSize(skin)
    {
        var useDefaultSize = MadCap.String.ToBool(skin.UseBrowserDefaultSize, true);

        if (useDefaultSize)
            return null;

        var topPx = MadCap.String.ToInt(skin.Top, 0);
        var leftPx = MadCap.String.ToInt(skin.Left, 0);
        var bottomPx = MadCap.String.ToInt(skin.Bottom, 0);
        var rightPx = MadCap.String.ToInt(skin.Right, 0);
        var widthPx = MadCap.String.ToInt(skin.Width, 800);
        var heightPx = MadCap.String.ToInt(skin.Height, 600);

        var anchors = skin.Anchors;

        if (anchors)
        {
            var aTop = (anchors.indexOf("Top") > -1) ? true : false;
            var aLeft = (anchors.indexOf("Left") > -1) ? true : false;
            var aBottom = (anchors.indexOf("Bottom") > -1) ? true : false;
            var aRight = (anchors.indexOf("Right") > -1) ? true : false;
            var aWidth = (anchors.indexOf("Width") > -1) ? true : false;
            var aHeight = (anchors.indexOf("Height") > -1) ? true : false;
        }

        if (aLeft && aRight)
            widthPx = screen.width - (leftPx + rightPx);
        else if (!aLeft && aRight)
            leftPx = screen.width - (widthPx + rightPx);
        else if (aWidth)
            leftPx = (screen.width / 2) - (widthPx / 2);

        if (aTop && aBottom)
            heightPx = screen.height - (topPx + bottomPx);
        else if (!aTop && aBottom)
            topPx = screen.height - (heightPx + bottomPx);
        else if (aHeight)
            topPx = (screen.height / 2) - (heightPx / 2);

        //

        var windowSize = {};
        windowSize.topPx = topPx;
        windowSize.leftPx = leftPx;
        windowSize.widthPx = widthPx;
        windowSize.heightPx = heightPx;

        return windowSize;
    }
})();
